
//  (C) Copyright Edward Diener 2011-2015
//  Use, modification and distribution are subject to the Boost Software License,
//  Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at
//  http://www.boost.org/LICENSE_1_0.txt).

#if !defined(BOOST_VMD_DETAIL_IS_NUMBER_REGISTRATION_HPP)
#define BOOST_VMD_DETAIL_IS_NUMBER_REGISTRATION_HPP

#include <boost/preprocessor/config/limits.hpp>

#define BOOST_VMD_REGISTER_0 (0)
#define BOOST_VMD_REGISTER_1 (1)
#define BOOST_VMD_REGISTER_2 (2)
#define BOOST_VMD_REGISTER_3 (3)
#define BOOST_VMD_REGISTER_4 (4)
#define BOOST_VMD_REGISTER_5 (5)
#define BOOST_VMD_REGISTER_6 (6)
#define BOOST_VMD_REGISTER_7 (7)
#define BOOST_VMD_REGISTER_8 (8)
#define BOOST_VMD_REGISTER_9 (9)
#define BOOST_VMD_REGISTER_10 (10)
#define BOOST_VMD_REGISTER_11 (11)
#define BOOST_VMD_REGISTER_12 (12)
#define BOOST_VMD_REGISTER_13 (13)
#define BOOST_VMD_REGISTER_14 (14)
#define BOOST_VMD_REGISTER_15 (15)
#define BOOST_VMD_REGISTER_16 (16)
#define BOOST_VMD_REGISTER_17 (17)
#define BOOST_VMD_REGISTER_18 (18)
#define BOOST_VMD_REGISTER_19 (19)
#define BOOST_VMD_REGISTER_20 (20)
#define BOOST_VMD_REGISTER_21 (21)
#define BOOST_VMD_REGISTER_22 (22)
#define BOOST_VMD_REGISTER_23 (23)
#define BOOST_VMD_REGISTER_24 (24)
#define BOOST_VMD_REGISTER_25 (25)
#define BOOST_VMD_REGISTER_26 (26)
#define BOOST_VMD_REGISTER_27 (27)
#define BOOST_VMD_REGISTER_28 (28)
#define BOOST_VMD_REGISTER_29 (29)
#define BOOST_VMD_REGISTER_30 (30)
#define BOOST_VMD_REGISTER_31 (31)
#define BOOST_VMD_REGISTER_32 (32)
#define BOOST_VMD_REGISTER_33 (33)
#define BOOST_VMD_REGISTER_34 (34)
#define BOOST_VMD_REGISTER_35 (35)
#define BOOST_VMD_REGISTER_36 (36)
#define BOOST_VMD_REGISTER_37 (37)
#define BOOST_VMD_REGISTER_38 (38)
#define BOOST_VMD_REGISTER_39 (39)
#define BOOST_VMD_REGISTER_40 (40)
#define BOOST_VMD_REGISTER_41 (41)
#define BOOST_VMD_REGISTER_42 (42)
#define BOOST_VMD_REGISTER_43 (43)
#define BOOST_VMD_REGISTER_44 (44)
#define BOOST_VMD_REGISTER_45 (45)
#define BOOST_VMD_REGISTER_46 (46)
#define BOOST_VMD_REGISTER_47 (47)
#define BOOST_VMD_REGISTER_48 (48)
#define BOOST_VMD_REGISTER_49 (49)
#define BOOST_VMD_REGISTER_50 (50)
#define BOOST_VMD_REGISTER_51 (51)
#define BOOST_VMD_REGISTER_52 (52)
#define BOOST_VMD_REGISTER_53 (53)
#define BOOST_VMD_REGISTER_54 (54)
#define BOOST_VMD_REGISTER_55 (55)
#define BOOST_VMD_REGISTER_56 (56)
#define BOOST_VMD_REGISTER_57 (57)
#define BOOST_VMD_REGISTER_58 (58)
#define BOOST_VMD_REGISTER_59 (59)
#define BOOST_VMD_REGISTER_60 (60)
#define BOOST_VMD_REGISTER_61 (61)
#define BOOST_VMD_REGISTER_62 (62)
#define BOOST_VMD_REGISTER_63 (63)
#define BOOST_VMD_REGISTER_64 (64)
#define BOOST_VMD_REGISTER_65 (65)
#define BOOST_VMD_REGISTER_66 (66)
#define BOOST_VMD_REGISTER_67 (67)
#define BOOST_VMD_REGISTER_68 (68)
#define BOOST_VMD_REGISTER_69 (69)
#define BOOST_VMD_REGISTER_70 (70)
#define BOOST_VMD_REGISTER_71 (71)
#define BOOST_VMD_REGISTER_72 (72)
#define BOOST_VMD_REGISTER_73 (73)
#define BOOST_VMD_REGISTER_74 (74)
#define BOOST_VMD_REGISTER_75 (75)
#define BOOST_VMD_REGISTER_76 (76)
#define BOOST_VMD_REGISTER_77 (77)
#define BOOST_VMD_REGISTER_78 (78)
#define BOOST_VMD_REGISTER_79 (79)
#define BOOST_VMD_REGISTER_80 (80)
#define BOOST_VMD_REGISTER_81 (81)
#define BOOST_VMD_REGISTER_82 (82)
#define BOOST_VMD_REGISTER_83 (83)
#define BOOST_VMD_REGISTER_84 (84)
#define BOOST_VMD_REGISTER_85 (85)
#define BOOST_VMD_REGISTER_86 (86)
#define BOOST_VMD_REGISTER_87 (87)
#define BOOST_VMD_REGISTER_88 (88)
#define BOOST_VMD_REGISTER_89 (89)
#define BOOST_VMD_REGISTER_90 (90)
#define BOOST_VMD_REGISTER_91 (91)
#define BOOST_VMD_REGISTER_92 (92)
#define BOOST_VMD_REGISTER_93 (93)
#define BOOST_VMD_REGISTER_94 (94)
#define BOOST_VMD_REGISTER_95 (95)
#define BOOST_VMD_REGISTER_96 (96)
#define BOOST_VMD_REGISTER_97 (97)
#define BOOST_VMD_REGISTER_98 (98)
#define BOOST_VMD_REGISTER_99 (99)
#define BOOST_VMD_REGISTER_100 (100)
#define BOOST_VMD_REGISTER_101 (101)
#define BOOST_VMD_REGISTER_102 (102)
#define BOOST_VMD_REGISTER_103 (103)
#define BOOST_VMD_REGISTER_104 (104)
#define BOOST_VMD_REGISTER_105 (105)
#define BOOST_VMD_REGISTER_106 (106)
#define BOOST_VMD_REGISTER_107 (107)
#define BOOST_VMD_REGISTER_108 (108)
#define BOOST_VMD_REGISTER_109 (109)
#define BOOST_VMD_REGISTER_110 (110)
#define BOOST_VMD_REGISTER_111 (111)
#define BOOST_VMD_REGISTER_112 (112)
#define BOOST_VMD_REGISTER_113 (113)
#define BOOST_VMD_REGISTER_114 (114)
#define BOOST_VMD_REGISTER_115 (115)
#define BOOST_VMD_REGISTER_116 (116)
#define BOOST_VMD_REGISTER_117 (117)
#define BOOST_VMD_REGISTER_118 (118)
#define BOOST_VMD_REGISTER_119 (119)
#define BOOST_VMD_REGISTER_120 (120)
#define BOOST_VMD_REGISTER_121 (121)
#define BOOST_VMD_REGISTER_122 (122)
#define BOOST_VMD_REGISTER_123 (123)
#define BOOST_VMD_REGISTER_124 (124)
#define BOOST_VMD_REGISTER_125 (125)
#define BOOST_VMD_REGISTER_126 (126)
#define BOOST_VMD_REGISTER_127 (127)
#define BOOST_VMD_REGISTER_128 (128)
#define BOOST_VMD_REGISTER_129 (129)
#define BOOST_VMD_REGISTER_130 (130)
#define BOOST_VMD_REGISTER_131 (131)
#define BOOST_VMD_REGISTER_132 (132)
#define BOOST_VMD_REGISTER_133 (133)
#define BOOST_VMD_REGISTER_134 (134)
#define BOOST_VMD_REGISTER_135 (135)
#define BOOST_VMD_REGISTER_136 (136)
#define BOOST_VMD_REGISTER_137 (137)
#define BOOST_VMD_REGISTER_138 (138)
#define BOOST_VMD_REGISTER_139 (139)
#define BOOST_VMD_REGISTER_140 (140)
#define BOOST_VMD_REGISTER_141 (141)
#define BOOST_VMD_REGISTER_142 (142)
#define BOOST_VMD_REGISTER_143 (143)
#define BOOST_VMD_REGISTER_144 (144)
#define BOOST_VMD_REGISTER_145 (145)
#define BOOST_VMD_REGISTER_146 (146)
#define BOOST_VMD_REGISTER_147 (147)
#define BOOST_VMD_REGISTER_148 (148)
#define BOOST_VMD_REGISTER_149 (149)
#define BOOST_VMD_REGISTER_150 (150)
#define BOOST_VMD_REGISTER_151 (151)
#define BOOST_VMD_REGISTER_152 (152)
#define BOOST_VMD_REGISTER_153 (153)
#define BOOST_VMD_REGISTER_154 (154)
#define BOOST_VMD_REGISTER_155 (155)
#define BOOST_VMD_REGISTER_156 (156)
#define BOOST_VMD_REGISTER_157 (157)
#define BOOST_VMD_REGISTER_158 (158)
#define BOOST_VMD_REGISTER_159 (159)
#define BOOST_VMD_REGISTER_160 (160)
#define BOOST_VMD_REGISTER_161 (161)
#define BOOST_VMD_REGISTER_162 (162)
#define BOOST_VMD_REGISTER_163 (163)
#define BOOST_VMD_REGISTER_164 (164)
#define BOOST_VMD_REGISTER_165 (165)
#define BOOST_VMD_REGISTER_166 (166)
#define BOOST_VMD_REGISTER_167 (167)
#define BOOST_VMD_REGISTER_168 (168)
#define BOOST_VMD_REGISTER_169 (169)
#define BOOST_VMD_REGISTER_170 (170)
#define BOOST_VMD_REGISTER_171 (171)
#define BOOST_VMD_REGISTER_172 (172)
#define BOOST_VMD_REGISTER_173 (173)
#define BOOST_VMD_REGISTER_174 (174)
#define BOOST_VMD_REGISTER_175 (175)
#define BOOST_VMD_REGISTER_176 (176)
#define BOOST_VMD_REGISTER_177 (177)
#define BOOST_VMD_REGISTER_178 (178)
#define BOOST_VMD_REGISTER_179 (179)
#define BOOST_VMD_REGISTER_180 (180)
#define BOOST_VMD_REGISTER_181 (181)
#define BOOST_VMD_REGISTER_182 (182)
#define BOOST_VMD_REGISTER_183 (183)
#define BOOST_VMD_REGISTER_184 (184)
#define BOOST_VMD_REGISTER_185 (185)
#define BOOST_VMD_REGISTER_186 (186)
#define BOOST_VMD_REGISTER_187 (187)
#define BOOST_VMD_REGISTER_188 (188)
#define BOOST_VMD_REGISTER_189 (189)
#define BOOST_VMD_REGISTER_190 (190)
#define BOOST_VMD_REGISTER_191 (191)
#define BOOST_VMD_REGISTER_192 (192)
#define BOOST_VMD_REGISTER_193 (193)
#define BOOST_VMD_REGISTER_194 (194)
#define BOOST_VMD_REGISTER_195 (195)
#define BOOST_VMD_REGISTER_196 (196)
#define BOOST_VMD_REGISTER_197 (197)
#define BOOST_VMD_REGISTER_198 (198)
#define BOOST_VMD_REGISTER_199 (199)
#define BOOST_VMD_REGISTER_200 (200)
#define BOOST_VMD_REGISTER_201 (201)
#define BOOST_VMD_REGISTER_202 (202)
#define BOOST_VMD_REGISTER_203 (203)
#define BOOST_VMD_REGISTER_204 (204)
#define BOOST_VMD_REGISTER_205 (205)
#define BOOST_VMD_REGISTER_206 (206)
#define BOOST_VMD_REGISTER_207 (207)
#define BOOST_VMD_REGISTER_208 (208)
#define BOOST_VMD_REGISTER_209 (209)
#define BOOST_VMD_REGISTER_210 (210)
#define BOOST_VMD_REGISTER_211 (211)
#define BOOST_VMD_REGISTER_212 (212)
#define BOOST_VMD_REGISTER_213 (213)
#define BOOST_VMD_REGISTER_214 (214)
#define BOOST_VMD_REGISTER_215 (215)
#define BOOST_VMD_REGISTER_216 (216)
#define BOOST_VMD_REGISTER_217 (217)
#define BOOST_VMD_REGISTER_218 (218)
#define BOOST_VMD_REGISTER_219 (219)
#define BOOST_VMD_REGISTER_220 (220)
#define BOOST_VMD_REGISTER_221 (221)
#define BOOST_VMD_REGISTER_222 (222)
#define BOOST_VMD_REGISTER_223 (223)
#define BOOST_VMD_REGISTER_224 (224)
#define BOOST_VMD_REGISTER_225 (225)
#define BOOST_VMD_REGISTER_226 (226)
#define BOOST_VMD_REGISTER_227 (227)
#define BOOST_VMD_REGISTER_228 (228)
#define BOOST_VMD_REGISTER_229 (229)
#define BOOST_VMD_REGISTER_230 (230)
#define BOOST_VMD_REGISTER_231 (231)
#define BOOST_VMD_REGISTER_232 (232)
#define BOOST_VMD_REGISTER_233 (233)
#define BOOST_VMD_REGISTER_234 (234)
#define BOOST_VMD_REGISTER_235 (235)
#define BOOST_VMD_REGISTER_236 (236)
#define BOOST_VMD_REGISTER_237 (237)
#define BOOST_VMD_REGISTER_238 (238)
#define BOOST_VMD_REGISTER_239 (239)
#define BOOST_VMD_REGISTER_240 (240)
#define BOOST_VMD_REGISTER_241 (241)
#define BOOST_VMD_REGISTER_242 (242)
#define BOOST_VMD_REGISTER_243 (243)
#define BOOST_VMD_REGISTER_244 (244)
#define BOOST_VMD_REGISTER_245 (245)
#define BOOST_VMD_REGISTER_246 (246)
#define BOOST_VMD_REGISTER_247 (247)
#define BOOST_VMD_REGISTER_248 (248)
#define BOOST_VMD_REGISTER_249 (249)
#define BOOST_VMD_REGISTER_250 (250)
#define BOOST_VMD_REGISTER_251 (251)
#define BOOST_VMD_REGISTER_252 (252)
#define BOOST_VMD_REGISTER_253 (253)
#define BOOST_VMD_REGISTER_254 (254)
#define BOOST_VMD_REGISTER_255 (255)
#define BOOST_VMD_REGISTER_256 (256)

#if BOOST_PP_LIMIT_MAG > 256

#define BOOST_VMD_REGISTER_257 (257)
#define BOOST_VMD_REGISTER_258 (258)
#define BOOST_VMD_REGISTER_259 (259)
#define BOOST_VMD_REGISTER_260 (260)
#define BOOST_VMD_REGISTER_261 (261)
#define BOOST_VMD_REGISTER_262 (262)
#define BOOST_VMD_REGISTER_263 (263)
#define BOOST_VMD_REGISTER_264 (264)
#define BOOST_VMD_REGISTER_265 (265)
#define BOOST_VMD_REGISTER_266 (266)
#define BOOST_VMD_REGISTER_267 (267)
#define BOOST_VMD_REGISTER_268 (268)
#define BOOST_VMD_REGISTER_269 (269)
#define BOOST_VMD_REGISTER_270 (270)
#define BOOST_VMD_REGISTER_271 (271)
#define BOOST_VMD_REGISTER_272 (272)
#define BOOST_VMD_REGISTER_273 (273)
#define BOOST_VMD_REGISTER_274 (274)
#define BOOST_VMD_REGISTER_275 (275)
#define BOOST_VMD_REGISTER_276 (276)
#define BOOST_VMD_REGISTER_277 (277)
#define BOOST_VMD_REGISTER_278 (278)
#define BOOST_VMD_REGISTER_279 (279)
#define BOOST_VMD_REGISTER_280 (280)
#define BOOST_VMD_REGISTER_281 (281)
#define BOOST_VMD_REGISTER_282 (282)
#define BOOST_VMD_REGISTER_283 (283)
#define BOOST_VMD_REGISTER_284 (284)
#define BOOST_VMD_REGISTER_285 (285)
#define BOOST_VMD_REGISTER_286 (286)
#define BOOST_VMD_REGISTER_287 (287)
#define BOOST_VMD_REGISTER_288 (288)
#define BOOST_VMD_REGISTER_289 (289)
#define BOOST_VMD_REGISTER_290 (290)
#define BOOST_VMD_REGISTER_291 (291)
#define BOOST_VMD_REGISTER_292 (292)
#define BOOST_VMD_REGISTER_293 (293)
#define BOOST_VMD_REGISTER_294 (294)
#define BOOST_VMD_REGISTER_295 (295)
#define BOOST_VMD_REGISTER_296 (296)
#define BOOST_VMD_REGISTER_297 (297)
#define BOOST_VMD_REGISTER_298 (298)
#define BOOST_VMD_REGISTER_299 (299)
#define BOOST_VMD_REGISTER_300 (300)
#define BOOST_VMD_REGISTER_301 (301)
#define BOOST_VMD_REGISTER_302 (302)
#define BOOST_VMD_REGISTER_303 (303)
#define BOOST_VMD_REGISTER_304 (304)
#define BOOST_VMD_REGISTER_305 (305)
#define BOOST_VMD_REGISTER_306 (306)
#define BOOST_VMD_REGISTER_307 (307)
#define BOOST_VMD_REGISTER_308 (308)
#define BOOST_VMD_REGISTER_309 (309)
#define BOOST_VMD_REGISTER_310 (310)
#define BOOST_VMD_REGISTER_311 (311)
#define BOOST_VMD_REGISTER_312 (312)
#define BOOST_VMD_REGISTER_313 (313)
#define BOOST_VMD_REGISTER_314 (314)
#define BOOST_VMD_REGISTER_315 (315)
#define BOOST_VMD_REGISTER_316 (316)
#define BOOST_VMD_REGISTER_317 (317)
#define BOOST_VMD_REGISTER_318 (318)
#define BOOST_VMD_REGISTER_319 (319)
#define BOOST_VMD_REGISTER_320 (320)
#define BOOST_VMD_REGISTER_321 (321)
#define BOOST_VMD_REGISTER_322 (322)
#define BOOST_VMD_REGISTER_323 (323)
#define BOOST_VMD_REGISTER_324 (324)
#define BOOST_VMD_REGISTER_325 (325)
#define BOOST_VMD_REGISTER_326 (326)
#define BOOST_VMD_REGISTER_327 (327)
#define BOOST_VMD_REGISTER_328 (328)
#define BOOST_VMD_REGISTER_329 (329)
#define BOOST_VMD_REGISTER_330 (330)
#define BOOST_VMD_REGISTER_331 (331)
#define BOOST_VMD_REGISTER_332 (332)
#define BOOST_VMD_REGISTER_333 (333)
#define BOOST_VMD_REGISTER_334 (334)
#define BOOST_VMD_REGISTER_335 (335)
#define BOOST_VMD_REGISTER_336 (336)
#define BOOST_VMD_REGISTER_337 (337)
#define BOOST_VMD_REGISTER_338 (338)
#define BOOST_VMD_REGISTER_339 (339)
#define BOOST_VMD_REGISTER_340 (340)
#define BOOST_VMD_REGISTER_341 (341)
#define BOOST_VMD_REGISTER_342 (342)
#define BOOST_VMD_REGISTER_343 (343)
#define BOOST_VMD_REGISTER_344 (344)
#define BOOST_VMD_REGISTER_345 (345)
#define BOOST_VMD_REGISTER_346 (346)
#define BOOST_VMD_REGISTER_347 (347)
#define BOOST_VMD_REGISTER_348 (348)
#define BOOST_VMD_REGISTER_349 (349)
#define BOOST_VMD_REGISTER_350 (350)
#define BOOST_VMD_REGISTER_351 (351)
#define BOOST_VMD_REGISTER_352 (352)
#define BOOST_VMD_REGISTER_353 (353)
#define BOOST_VMD_REGISTER_354 (354)
#define BOOST_VMD_REGISTER_355 (355)
#define BOOST_VMD_REGISTER_356 (356)
#define BOOST_VMD_REGISTER_357 (357)
#define BOOST_VMD_REGISTER_358 (358)
#define BOOST_VMD_REGISTER_359 (359)
#define BOOST_VMD_REGISTER_360 (360)
#define BOOST_VMD_REGISTER_361 (361)
#define BOOST_VMD_REGISTER_362 (362)
#define BOOST_VMD_REGISTER_363 (363)
#define BOOST_VMD_REGISTER_364 (364)
#define BOOST_VMD_REGISTER_365 (365)
#define BOOST_VMD_REGISTER_366 (366)
#define BOOST_VMD_REGISTER_367 (367)
#define BOOST_VMD_REGISTER_368 (368)
#define BOOST_VMD_REGISTER_369 (369)
#define BOOST_VMD_REGISTER_370 (370)
#define BOOST_VMD_REGISTER_371 (371)
#define BOOST_VMD_REGISTER_372 (372)
#define BOOST_VMD_REGISTER_373 (373)
#define BOOST_VMD_REGISTER_374 (374)
#define BOOST_VMD_REGISTER_375 (375)
#define BOOST_VMD_REGISTER_376 (376)
#define BOOST_VMD_REGISTER_377 (377)
#define BOOST_VMD_REGISTER_378 (378)
#define BOOST_VMD_REGISTER_379 (379)
#define BOOST_VMD_REGISTER_380 (380)
#define BOOST_VMD_REGISTER_381 (381)
#define BOOST_VMD_REGISTER_382 (382)
#define BOOST_VMD_REGISTER_383 (383)
#define BOOST_VMD_REGISTER_384 (384)
#define BOOST_VMD_REGISTER_385 (385)
#define BOOST_VMD_REGISTER_386 (386)
#define BOOST_VMD_REGISTER_387 (387)
#define BOOST_VMD_REGISTER_388 (388)
#define BOOST_VMD_REGISTER_389 (389)
#define BOOST_VMD_REGISTER_390 (390)
#define BOOST_VMD_REGISTER_391 (391)
#define BOOST_VMD_REGISTER_392 (392)
#define BOOST_VMD_REGISTER_393 (393)
#define BOOST_VMD_REGISTER_394 (394)
#define BOOST_VMD_REGISTER_395 (395)
#define BOOST_VMD_REGISTER_396 (396)
#define BOOST_VMD_REGISTER_397 (397)
#define BOOST_VMD_REGISTER_398 (398)
#define BOOST_VMD_REGISTER_399 (399)
#define BOOST_VMD_REGISTER_400 (400)
#define BOOST_VMD_REGISTER_401 (401)
#define BOOST_VMD_REGISTER_402 (402)
#define BOOST_VMD_REGISTER_403 (403)
#define BOOST_VMD_REGISTER_404 (404)
#define BOOST_VMD_REGISTER_405 (405)
#define BOOST_VMD_REGISTER_406 (406)
#define BOOST_VMD_REGISTER_407 (407)
#define BOOST_VMD_REGISTER_408 (408)
#define BOOST_VMD_REGISTER_409 (409)
#define BOOST_VMD_REGISTER_410 (410)
#define BOOST_VMD_REGISTER_411 (411)
#define BOOST_VMD_REGISTER_412 (412)
#define BOOST_VMD_REGISTER_413 (413)
#define BOOST_VMD_REGISTER_414 (414)
#define BOOST_VMD_REGISTER_415 (415)
#define BOOST_VMD_REGISTER_416 (416)
#define BOOST_VMD_REGISTER_417 (417)
#define BOOST_VMD_REGISTER_418 (418)
#define BOOST_VMD_REGISTER_419 (419)
#define BOOST_VMD_REGISTER_420 (420)
#define BOOST_VMD_REGISTER_421 (421)
#define BOOST_VMD_REGISTER_422 (422)
#define BOOST_VMD_REGISTER_423 (423)
#define BOOST_VMD_REGISTER_424 (424)
#define BOOST_VMD_REGISTER_425 (425)
#define BOOST_VMD_REGISTER_426 (426)
#define BOOST_VMD_REGISTER_427 (427)
#define BOOST_VMD_REGISTER_428 (428)
#define BOOST_VMD_REGISTER_429 (429)
#define BOOST_VMD_REGISTER_430 (430)
#define BOOST_VMD_REGISTER_431 (431)
#define BOOST_VMD_REGISTER_432 (432)
#define BOOST_VMD_REGISTER_433 (433)
#define BOOST_VMD_REGISTER_434 (434)
#define BOOST_VMD_REGISTER_435 (435)
#define BOOST_VMD_REGISTER_436 (436)
#define BOOST_VMD_REGISTER_437 (437)
#define BOOST_VMD_REGISTER_438 (438)
#define BOOST_VMD_REGISTER_439 (439)
#define BOOST_VMD_REGISTER_440 (440)
#define BOOST_VMD_REGISTER_441 (441)
#define BOOST_VMD_REGISTER_442 (442)
#define BOOST_VMD_REGISTER_443 (443)
#define BOOST_VMD_REGISTER_444 (444)
#define BOOST_VMD_REGISTER_445 (445)
#define BOOST_VMD_REGISTER_446 (446)
#define BOOST_VMD_REGISTER_447 (447)
#define BOOST_VMD_REGISTER_448 (448)
#define BOOST_VMD_REGISTER_449 (449)
#define BOOST_VMD_REGISTER_450 (450)
#define BOOST_VMD_REGISTER_451 (451)
#define BOOST_VMD_REGISTER_452 (452)
#define BOOST_VMD_REGISTER_453 (453)
#define BOOST_VMD_REGISTER_454 (454)
#define BOOST_VMD_REGISTER_455 (455)
#define BOOST_VMD_REGISTER_456 (456)
#define BOOST_VMD_REGISTER_457 (457)
#define BOOST_VMD_REGISTER_458 (458)
#define BOOST_VMD_REGISTER_459 (459)
#define BOOST_VMD_REGISTER_460 (460)
#define BOOST_VMD_REGISTER_461 (461)
#define BOOST_VMD_REGISTER_462 (462)
#define BOOST_VMD_REGISTER_463 (463)
#define BOOST_VMD_REGISTER_464 (464)
#define BOOST_VMD_REGISTER_465 (465)
#define BOOST_VMD_REGISTER_466 (466)
#define BOOST_VMD_REGISTER_467 (467)
#define BOOST_VMD_REGISTER_468 (468)
#define BOOST_VMD_REGISTER_469 (469)
#define BOOST_VMD_REGISTER_470 (470)
#define BOOST_VMD_REGISTER_471 (471)
#define BOOST_VMD_REGISTER_472 (472)
#define BOOST_VMD_REGISTER_473 (473)
#define BOOST_VMD_REGISTER_474 (474)
#define BOOST_VMD_REGISTER_475 (475)
#define BOOST_VMD_REGISTER_476 (476)
#define BOOST_VMD_REGISTER_477 (477)
#define BOOST_VMD_REGISTER_478 (478)
#define BOOST_VMD_REGISTER_479 (479)
#define BOOST_VMD_REGISTER_480 (480)
#define BOOST_VMD_REGISTER_481 (481)
#define BOOST_VMD_REGISTER_482 (482)
#define BOOST_VMD_REGISTER_483 (483)
#define BOOST_VMD_REGISTER_484 (484)
#define BOOST_VMD_REGISTER_485 (485)
#define BOOST_VMD_REGISTER_486 (486)
#define BOOST_VMD_REGISTER_487 (487)
#define BOOST_VMD_REGISTER_488 (488)
#define BOOST_VMD_REGISTER_489 (489)
#define BOOST_VMD_REGISTER_490 (490)
#define BOOST_VMD_REGISTER_491 (491)
#define BOOST_VMD_REGISTER_492 (492)
#define BOOST_VMD_REGISTER_493 (493)
#define BOOST_VMD_REGISTER_494 (494)
#define BOOST_VMD_REGISTER_495 (495)
#define BOOST_VMD_REGISTER_496 (496)
#define BOOST_VMD_REGISTER_497 (497)
#define BOOST_VMD_REGISTER_498 (498)
#define BOOST_VMD_REGISTER_499 (499)
#define BOOST_VMD_REGISTER_500 (500)
#define BOOST_VMD_REGISTER_501 (501)
#define BOOST_VMD_REGISTER_502 (502)
#define BOOST_VMD_REGISTER_503 (503)
#define BOOST_VMD_REGISTER_504 (504)
#define BOOST_VMD_REGISTER_505 (505)
#define BOOST_VMD_REGISTER_506 (506)
#define BOOST_VMD_REGISTER_507 (507)
#define BOOST_VMD_REGISTER_508 (508)
#define BOOST_VMD_REGISTER_509 (509)
#define BOOST_VMD_REGISTER_510 (510)
#define BOOST_VMD_REGISTER_511 (511)
#define BOOST_VMD_REGISTER_512 (512)

#endif

#if BOOST_PP_LIMIT_MAG > 512

#define BOOST_VMD_REGISTER_513 (513)
#define BOOST_VMD_REGISTER_514 (514)
#define BOOST_VMD_REGISTER_515 (515)
#define BOOST_VMD_REGISTER_516 (516)
#define BOOST_VMD_REGISTER_517 (517)
#define BOOST_VMD_REGISTER_518 (518)
#define BOOST_VMD_REGISTER_519 (519)
#define BOOST_VMD_REGISTER_520 (520)
#define BOOST_VMD_REGISTER_521 (521)
#define BOOST_VMD_REGISTER_522 (522)
#define BOOST_VMD_REGISTER_523 (523)
#define BOOST_VMD_REGISTER_524 (524)
#define BOOST_VMD_REGISTER_525 (525)
#define BOOST_VMD_REGISTER_526 (526)
#define BOOST_VMD_REGISTER_527 (527)
#define BOOST_VMD_REGISTER_528 (528)
#define BOOST_VMD_REGISTER_529 (529)
#define BOOST_VMD_REGISTER_530 (530)
#define BOOST_VMD_REGISTER_531 (531)
#define BOOST_VMD_REGISTER_532 (532)
#define BOOST_VMD_REGISTER_533 (533)
#define BOOST_VMD_REGISTER_534 (534)
#define BOOST_VMD_REGISTER_535 (535)
#define BOOST_VMD_REGISTER_536 (536)
#define BOOST_VMD_REGISTER_537 (537)
#define BOOST_VMD_REGISTER_538 (538)
#define BOOST_VMD_REGISTER_539 (539)
#define BOOST_VMD_REGISTER_540 (540)
#define BOOST_VMD_REGISTER_541 (541)
#define BOOST_VMD_REGISTER_542 (542)
#define BOOST_VMD_REGISTER_543 (543)
#define BOOST_VMD_REGISTER_544 (544)
#define BOOST_VMD_REGISTER_545 (545)
#define BOOST_VMD_REGISTER_546 (546)
#define BOOST_VMD_REGISTER_547 (547)
#define BOOST_VMD_REGISTER_548 (548)
#define BOOST_VMD_REGISTER_549 (549)
#define BOOST_VMD_REGISTER_550 (550)
#define BOOST_VMD_REGISTER_551 (551)
#define BOOST_VMD_REGISTER_552 (552)
#define BOOST_VMD_REGISTER_553 (553)
#define BOOST_VMD_REGISTER_554 (554)
#define BOOST_VMD_REGISTER_555 (555)
#define BOOST_VMD_REGISTER_556 (556)
#define BOOST_VMD_REGISTER_557 (557)
#define BOOST_VMD_REGISTER_558 (558)
#define BOOST_VMD_REGISTER_559 (559)
#define BOOST_VMD_REGISTER_560 (560)
#define BOOST_VMD_REGISTER_561 (561)
#define BOOST_VMD_REGISTER_562 (562)
#define BOOST_VMD_REGISTER_563 (563)
#define BOOST_VMD_REGISTER_564 (564)
#define BOOST_VMD_REGISTER_565 (565)
#define BOOST_VMD_REGISTER_566 (566)
#define BOOST_VMD_REGISTER_567 (567)
#define BOOST_VMD_REGISTER_568 (568)
#define BOOST_VMD_REGISTER_569 (569)
#define BOOST_VMD_REGISTER_570 (570)
#define BOOST_VMD_REGISTER_571 (571)
#define BOOST_VMD_REGISTER_572 (572)
#define BOOST_VMD_REGISTER_573 (573)
#define BOOST_VMD_REGISTER_574 (574)
#define BOOST_VMD_REGISTER_575 (575)
#define BOOST_VMD_REGISTER_576 (576)
#define BOOST_VMD_REGISTER_577 (577)
#define BOOST_VMD_REGISTER_578 (578)
#define BOOST_VMD_REGISTER_579 (579)
#define BOOST_VMD_REGISTER_580 (580)
#define BOOST_VMD_REGISTER_581 (581)
#define BOOST_VMD_REGISTER_582 (582)
#define BOOST_VMD_REGISTER_583 (583)
#define BOOST_VMD_REGISTER_584 (584)
#define BOOST_VMD_REGISTER_585 (585)
#define BOOST_VMD_REGISTER_586 (586)
#define BOOST_VMD_REGISTER_587 (587)
#define BOOST_VMD_REGISTER_588 (588)
#define BOOST_VMD_REGISTER_589 (589)
#define BOOST_VMD_REGISTER_590 (590)
#define BOOST_VMD_REGISTER_591 (591)
#define BOOST_VMD_REGISTER_592 (592)
#define BOOST_VMD_REGISTER_593 (593)
#define BOOST_VMD_REGISTER_594 (594)
#define BOOST_VMD_REGISTER_595 (595)
#define BOOST_VMD_REGISTER_596 (596)
#define BOOST_VMD_REGISTER_597 (597)
#define BOOST_VMD_REGISTER_598 (598)
#define BOOST_VMD_REGISTER_599 (599)
#define BOOST_VMD_REGISTER_600 (600)
#define BOOST_VMD_REGISTER_601 (601)
#define BOOST_VMD_REGISTER_602 (602)
#define BOOST_VMD_REGISTER_603 (603)
#define BOOST_VMD_REGISTER_604 (604)
#define BOOST_VMD_REGISTER_605 (605)
#define BOOST_VMD_REGISTER_606 (606)
#define BOOST_VMD_REGISTER_607 (607)
#define BOOST_VMD_REGISTER_608 (608)
#define BOOST_VMD_REGISTER_609 (609)
#define BOOST_VMD_REGISTER_610 (610)
#define BOOST_VMD_REGISTER_611 (611)
#define BOOST_VMD_REGISTER_612 (612)
#define BOOST_VMD_REGISTER_613 (613)
#define BOOST_VMD_REGISTER_614 (614)
#define BOOST_VMD_REGISTER_615 (615)
#define BOOST_VMD_REGISTER_616 (616)
#define BOOST_VMD_REGISTER_617 (617)
#define BOOST_VMD_REGISTER_618 (618)
#define BOOST_VMD_REGISTER_619 (619)
#define BOOST_VMD_REGISTER_620 (620)
#define BOOST_VMD_REGISTER_621 (621)
#define BOOST_VMD_REGISTER_622 (622)
#define BOOST_VMD_REGISTER_623 (623)
#define BOOST_VMD_REGISTER_624 (624)
#define BOOST_VMD_REGISTER_625 (625)
#define BOOST_VMD_REGISTER_626 (626)
#define BOOST_VMD_REGISTER_627 (627)
#define BOOST_VMD_REGISTER_628 (628)
#define BOOST_VMD_REGISTER_629 (629)
#define BOOST_VMD_REGISTER_630 (630)
#define BOOST_VMD_REGISTER_631 (631)
#define BOOST_VMD_REGISTER_632 (632)
#define BOOST_VMD_REGISTER_633 (633)
#define BOOST_VMD_REGISTER_634 (634)
#define BOOST_VMD_REGISTER_635 (635)
#define BOOST_VMD_REGISTER_636 (636)
#define BOOST_VMD_REGISTER_637 (637)
#define BOOST_VMD_REGISTER_638 (638)
#define BOOST_VMD_REGISTER_639 (639)
#define BOOST_VMD_REGISTER_640 (640)
#define BOOST_VMD_REGISTER_641 (641)
#define BOOST_VMD_REGISTER_642 (642)
#define BOOST_VMD_REGISTER_643 (643)
#define BOOST_VMD_REGISTER_644 (644)
#define BOOST_VMD_REGISTER_645 (645)
#define BOOST_VMD_REGISTER_646 (646)
#define BOOST_VMD_REGISTER_647 (647)
#define BOOST_VMD_REGISTER_648 (648)
#define BOOST_VMD_REGISTER_649 (649)
#define BOOST_VMD_REGISTER_650 (650)
#define BOOST_VMD_REGISTER_651 (651)
#define BOOST_VMD_REGISTER_652 (652)
#define BOOST_VMD_REGISTER_653 (653)
#define BOOST_VMD_REGISTER_654 (654)
#define BOOST_VMD_REGISTER_655 (655)
#define BOOST_VMD_REGISTER_656 (656)
#define BOOST_VMD_REGISTER_657 (657)
#define BOOST_VMD_REGISTER_658 (658)
#define BOOST_VMD_REGISTER_659 (659)
#define BOOST_VMD_REGISTER_660 (660)
#define BOOST_VMD_REGISTER_661 (661)
#define BOOST_VMD_REGISTER_662 (662)
#define BOOST_VMD_REGISTER_663 (663)
#define BOOST_VMD_REGISTER_664 (664)
#define BOOST_VMD_REGISTER_665 (665)
#define BOOST_VMD_REGISTER_666 (666)
#define BOOST_VMD_REGISTER_667 (667)
#define BOOST_VMD_REGISTER_668 (668)
#define BOOST_VMD_REGISTER_669 (669)
#define BOOST_VMD_REGISTER_670 (670)
#define BOOST_VMD_REGISTER_671 (671)
#define BOOST_VMD_REGISTER_672 (672)
#define BOOST_VMD_REGISTER_673 (673)
#define BOOST_VMD_REGISTER_674 (674)
#define BOOST_VMD_REGISTER_675 (675)
#define BOOST_VMD_REGISTER_676 (676)
#define BOOST_VMD_REGISTER_677 (677)
#define BOOST_VMD_REGISTER_678 (678)
#define BOOST_VMD_REGISTER_679 (679)
#define BOOST_VMD_REGISTER_680 (680)
#define BOOST_VMD_REGISTER_681 (681)
#define BOOST_VMD_REGISTER_682 (682)
#define BOOST_VMD_REGISTER_683 (683)
#define BOOST_VMD_REGISTER_684 (684)
#define BOOST_VMD_REGISTER_685 (685)
#define BOOST_VMD_REGISTER_686 (686)
#define BOOST_VMD_REGISTER_687 (687)
#define BOOST_VMD_REGISTER_688 (688)
#define BOOST_VMD_REGISTER_689 (689)
#define BOOST_VMD_REGISTER_690 (690)
#define BOOST_VMD_REGISTER_691 (691)
#define BOOST_VMD_REGISTER_692 (692)
#define BOOST_VMD_REGISTER_693 (693)
#define BOOST_VMD_REGISTER_694 (694)
#define BOOST_VMD_REGISTER_695 (695)
#define BOOST_VMD_REGISTER_696 (696)
#define BOOST_VMD_REGISTER_697 (697)
#define BOOST_VMD_REGISTER_698 (698)
#define BOOST_VMD_REGISTER_699 (699)
#define BOOST_VMD_REGISTER_700 (700)
#define BOOST_VMD_REGISTER_701 (701)
#define BOOST_VMD_REGISTER_702 (702)
#define BOOST_VMD_REGISTER_703 (703)
#define BOOST_VMD_REGISTER_704 (704)
#define BOOST_VMD_REGISTER_705 (705)
#define BOOST_VMD_REGISTER_706 (706)
#define BOOST_VMD_REGISTER_707 (707)
#define BOOST_VMD_REGISTER_708 (708)
#define BOOST_VMD_REGISTER_709 (709)
#define BOOST_VMD_REGISTER_710 (710)
#define BOOST_VMD_REGISTER_711 (711)
#define BOOST_VMD_REGISTER_712 (712)
#define BOOST_VMD_REGISTER_713 (713)
#define BOOST_VMD_REGISTER_714 (714)
#define BOOST_VMD_REGISTER_715 (715)
#define BOOST_VMD_REGISTER_716 (716)
#define BOOST_VMD_REGISTER_717 (717)
#define BOOST_VMD_REGISTER_718 (718)
#define BOOST_VMD_REGISTER_719 (719)
#define BOOST_VMD_REGISTER_720 (720)
#define BOOST_VMD_REGISTER_721 (721)
#define BOOST_VMD_REGISTER_722 (722)
#define BOOST_VMD_REGISTER_723 (723)
#define BOOST_VMD_REGISTER_724 (724)
#define BOOST_VMD_REGISTER_725 (725)
#define BOOST_VMD_REGISTER_726 (726)
#define BOOST_VMD_REGISTER_727 (727)
#define BOOST_VMD_REGISTER_728 (728)
#define BOOST_VMD_REGISTER_729 (729)
#define BOOST_VMD_REGISTER_730 (730)
#define BOOST_VMD_REGISTER_731 (731)
#define BOOST_VMD_REGISTER_732 (732)
#define BOOST_VMD_REGISTER_733 (733)
#define BOOST_VMD_REGISTER_734 (734)
#define BOOST_VMD_REGISTER_735 (735)
#define BOOST_VMD_REGISTER_736 (736)
#define BOOST_VMD_REGISTER_737 (737)
#define BOOST_VMD_REGISTER_738 (738)
#define BOOST_VMD_REGISTER_739 (739)
#define BOOST_VMD_REGISTER_740 (740)
#define BOOST_VMD_REGISTER_741 (741)
#define BOOST_VMD_REGISTER_742 (742)
#define BOOST_VMD_REGISTER_743 (743)
#define BOOST_VMD_REGISTER_744 (744)
#define BOOST_VMD_REGISTER_745 (745)
#define BOOST_VMD_REGISTER_746 (746)
#define BOOST_VMD_REGISTER_747 (747)
#define BOOST_VMD_REGISTER_748 (748)
#define BOOST_VMD_REGISTER_749 (749)
#define BOOST_VMD_REGISTER_750 (750)
#define BOOST_VMD_REGISTER_751 (751)
#define BOOST_VMD_REGISTER_752 (752)
#define BOOST_VMD_REGISTER_753 (753)
#define BOOST_VMD_REGISTER_754 (754)
#define BOOST_VMD_REGISTER_755 (755)
#define BOOST_VMD_REGISTER_756 (756)
#define BOOST_VMD_REGISTER_757 (757)
#define BOOST_VMD_REGISTER_758 (758)
#define BOOST_VMD_REGISTER_759 (759)
#define BOOST_VMD_REGISTER_760 (760)
#define BOOST_VMD_REGISTER_761 (761)
#define BOOST_VMD_REGISTER_762 (762)
#define BOOST_VMD_REGISTER_763 (763)
#define BOOST_VMD_REGISTER_764 (764)
#define BOOST_VMD_REGISTER_765 (765)
#define BOOST_VMD_REGISTER_766 (766)
#define BOOST_VMD_REGISTER_767 (767)
#define BOOST_VMD_REGISTER_768 (768)
#define BOOST_VMD_REGISTER_769 (769)
#define BOOST_VMD_REGISTER_770 (770)
#define BOOST_VMD_REGISTER_771 (771)
#define BOOST_VMD_REGISTER_772 (772)
#define BOOST_VMD_REGISTER_773 (773)
#define BOOST_VMD_REGISTER_774 (774)
#define BOOST_VMD_REGISTER_775 (775)
#define BOOST_VMD_REGISTER_776 (776)
#define BOOST_VMD_REGISTER_777 (777)
#define BOOST_VMD_REGISTER_778 (778)
#define BOOST_VMD_REGISTER_779 (779)
#define BOOST_VMD_REGISTER_780 (780)
#define BOOST_VMD_REGISTER_781 (781)
#define BOOST_VMD_REGISTER_782 (782)
#define BOOST_VMD_REGISTER_783 (783)
#define BOOST_VMD_REGISTER_784 (784)
#define BOOST_VMD_REGISTER_785 (785)
#define BOOST_VMD_REGISTER_786 (786)
#define BOOST_VMD_REGISTER_787 (787)
#define BOOST_VMD_REGISTER_788 (788)
#define BOOST_VMD_REGISTER_789 (789)
#define BOOST_VMD_REGISTER_790 (790)
#define BOOST_VMD_REGISTER_791 (791)
#define BOOST_VMD_REGISTER_792 (792)
#define BOOST_VMD_REGISTER_793 (793)
#define BOOST_VMD_REGISTER_794 (794)
#define BOOST_VMD_REGISTER_795 (795)
#define BOOST_VMD_REGISTER_796 (796)
#define BOOST_VMD_REGISTER_797 (797)
#define BOOST_VMD_REGISTER_798 (798)
#define BOOST_VMD_REGISTER_799 (799)
#define BOOST_VMD_REGISTER_800 (800)
#define BOOST_VMD_REGISTER_801 (801)
#define BOOST_VMD_REGISTER_802 (802)
#define BOOST_VMD_REGISTER_803 (803)
#define BOOST_VMD_REGISTER_804 (804)
#define BOOST_VMD_REGISTER_805 (805)
#define BOOST_VMD_REGISTER_806 (806)
#define BOOST_VMD_REGISTER_807 (807)
#define BOOST_VMD_REGISTER_808 (808)
#define BOOST_VMD_REGISTER_809 (809)
#define BOOST_VMD_REGISTER_810 (810)
#define BOOST_VMD_REGISTER_811 (811)
#define BOOST_VMD_REGISTER_812 (812)
#define BOOST_VMD_REGISTER_813 (813)
#define BOOST_VMD_REGISTER_814 (814)
#define BOOST_VMD_REGISTER_815 (815)
#define BOOST_VMD_REGISTER_816 (816)
#define BOOST_VMD_REGISTER_817 (817)
#define BOOST_VMD_REGISTER_818 (818)
#define BOOST_VMD_REGISTER_819 (819)
#define BOOST_VMD_REGISTER_820 (820)
#define BOOST_VMD_REGISTER_821 (821)
#define BOOST_VMD_REGISTER_822 (822)
#define BOOST_VMD_REGISTER_823 (823)
#define BOOST_VMD_REGISTER_824 (824)
#define BOOST_VMD_REGISTER_825 (825)
#define BOOST_VMD_REGISTER_826 (826)
#define BOOST_VMD_REGISTER_827 (827)
#define BOOST_VMD_REGISTER_828 (828)
#define BOOST_VMD_REGISTER_829 (829)
#define BOOST_VMD_REGISTER_830 (830)
#define BOOST_VMD_REGISTER_831 (831)
#define BOOST_VMD_REGISTER_832 (832)
#define BOOST_VMD_REGISTER_833 (833)
#define BOOST_VMD_REGISTER_834 (834)
#define BOOST_VMD_REGISTER_835 (835)
#define BOOST_VMD_REGISTER_836 (836)
#define BOOST_VMD_REGISTER_837 (837)
#define BOOST_VMD_REGISTER_838 (838)
#define BOOST_VMD_REGISTER_839 (839)
#define BOOST_VMD_REGISTER_840 (840)
#define BOOST_VMD_REGISTER_841 (841)
#define BOOST_VMD_REGISTER_842 (842)
#define BOOST_VMD_REGISTER_843 (843)
#define BOOST_VMD_REGISTER_844 (844)
#define BOOST_VMD_REGISTER_845 (845)
#define BOOST_VMD_REGISTER_846 (846)
#define BOOST_VMD_REGISTER_847 (847)
#define BOOST_VMD_REGISTER_848 (848)
#define BOOST_VMD_REGISTER_849 (849)
#define BOOST_VMD_REGISTER_850 (850)
#define BOOST_VMD_REGISTER_851 (851)
#define BOOST_VMD_REGISTER_852 (852)
#define BOOST_VMD_REGISTER_853 (853)
#define BOOST_VMD_REGISTER_854 (854)
#define BOOST_VMD_REGISTER_855 (855)
#define BOOST_VMD_REGISTER_856 (856)
#define BOOST_VMD_REGISTER_857 (857)
#define BOOST_VMD_REGISTER_858 (858)
#define BOOST_VMD_REGISTER_859 (859)
#define BOOST_VMD_REGISTER_860 (860)
#define BOOST_VMD_REGISTER_861 (861)
#define BOOST_VMD_REGISTER_862 (862)
#define BOOST_VMD_REGISTER_863 (863)
#define BOOST_VMD_REGISTER_864 (864)
#define BOOST_VMD_REGISTER_865 (865)
#define BOOST_VMD_REGISTER_866 (866)
#define BOOST_VMD_REGISTER_867 (867)
#define BOOST_VMD_REGISTER_868 (868)
#define BOOST_VMD_REGISTER_869 (869)
#define BOOST_VMD_REGISTER_870 (870)
#define BOOST_VMD_REGISTER_871 (871)
#define BOOST_VMD_REGISTER_872 (872)
#define BOOST_VMD_REGISTER_873 (873)
#define BOOST_VMD_REGISTER_874 (874)
#define BOOST_VMD_REGISTER_875 (875)
#define BOOST_VMD_REGISTER_876 (876)
#define BOOST_VMD_REGISTER_877 (877)
#define BOOST_VMD_REGISTER_878 (878)
#define BOOST_VMD_REGISTER_879 (879)
#define BOOST_VMD_REGISTER_880 (880)
#define BOOST_VMD_REGISTER_881 (881)
#define BOOST_VMD_REGISTER_882 (882)
#define BOOST_VMD_REGISTER_883 (883)
#define BOOST_VMD_REGISTER_884 (884)
#define BOOST_VMD_REGISTER_885 (885)
#define BOOST_VMD_REGISTER_886 (886)
#define BOOST_VMD_REGISTER_887 (887)
#define BOOST_VMD_REGISTER_888 (888)
#define BOOST_VMD_REGISTER_889 (889)
#define BOOST_VMD_REGISTER_890 (890)
#define BOOST_VMD_REGISTER_891 (891)
#define BOOST_VMD_REGISTER_892 (892)
#define BOOST_VMD_REGISTER_893 (893)
#define BOOST_VMD_REGISTER_894 (894)
#define BOOST_VMD_REGISTER_895 (895)
#define BOOST_VMD_REGISTER_896 (896)
#define BOOST_VMD_REGISTER_897 (897)
#define BOOST_VMD_REGISTER_898 (898)
#define BOOST_VMD_REGISTER_899 (899)
#define BOOST_VMD_REGISTER_900 (900)
#define BOOST_VMD_REGISTER_901 (901)
#define BOOST_VMD_REGISTER_902 (902)
#define BOOST_VMD_REGISTER_903 (903)
#define BOOST_VMD_REGISTER_904 (904)
#define BOOST_VMD_REGISTER_905 (905)
#define BOOST_VMD_REGISTER_906 (906)
#define BOOST_VMD_REGISTER_907 (907)
#define BOOST_VMD_REGISTER_908 (908)
#define BOOST_VMD_REGISTER_909 (909)
#define BOOST_VMD_REGISTER_910 (910)
#define BOOST_VMD_REGISTER_911 (911)
#define BOOST_VMD_REGISTER_912 (912)
#define BOOST_VMD_REGISTER_913 (913)
#define BOOST_VMD_REGISTER_914 (914)
#define BOOST_VMD_REGISTER_915 (915)
#define BOOST_VMD_REGISTER_916 (916)
#define BOOST_VMD_REGISTER_917 (917)
#define BOOST_VMD_REGISTER_918 (918)
#define BOOST_VMD_REGISTER_919 (919)
#define BOOST_VMD_REGISTER_920 (920)
#define BOOST_VMD_REGISTER_921 (921)
#define BOOST_VMD_REGISTER_922 (922)
#define BOOST_VMD_REGISTER_923 (923)
#define BOOST_VMD_REGISTER_924 (924)
#define BOOST_VMD_REGISTER_925 (925)
#define BOOST_VMD_REGISTER_926 (926)
#define BOOST_VMD_REGISTER_927 (927)
#define BOOST_VMD_REGISTER_928 (928)
#define BOOST_VMD_REGISTER_929 (929)
#define BOOST_VMD_REGISTER_930 (930)
#define BOOST_VMD_REGISTER_931 (931)
#define BOOST_VMD_REGISTER_932 (932)
#define BOOST_VMD_REGISTER_933 (933)
#define BOOST_VMD_REGISTER_934 (934)
#define BOOST_VMD_REGISTER_935 (935)
#define BOOST_VMD_REGISTER_936 (936)
#define BOOST_VMD_REGISTER_937 (937)
#define BOOST_VMD_REGISTER_938 (938)
#define BOOST_VMD_REGISTER_939 (939)
#define BOOST_VMD_REGISTER_940 (940)
#define BOOST_VMD_REGISTER_941 (941)
#define BOOST_VMD_REGISTER_942 (942)
#define BOOST_VMD_REGISTER_943 (943)
#define BOOST_VMD_REGISTER_944 (944)
#define BOOST_VMD_REGISTER_945 (945)
#define BOOST_VMD_REGISTER_946 (946)
#define BOOST_VMD_REGISTER_947 (947)
#define BOOST_VMD_REGISTER_948 (948)
#define BOOST_VMD_REGISTER_949 (949)
#define BOOST_VMD_REGISTER_950 (950)
#define BOOST_VMD_REGISTER_951 (951)
#define BOOST_VMD_REGISTER_952 (952)
#define BOOST_VMD_REGISTER_953 (953)
#define BOOST_VMD_REGISTER_954 (954)
#define BOOST_VMD_REGISTER_955 (955)
#define BOOST_VMD_REGISTER_956 (956)
#define BOOST_VMD_REGISTER_957 (957)
#define BOOST_VMD_REGISTER_958 (958)
#define BOOST_VMD_REGISTER_959 (959)
#define BOOST_VMD_REGISTER_960 (960)
#define BOOST_VMD_REGISTER_961 (961)
#define BOOST_VMD_REGISTER_962 (962)
#define BOOST_VMD_REGISTER_963 (963)
#define BOOST_VMD_REGISTER_964 (964)
#define BOOST_VMD_REGISTER_965 (965)
#define BOOST_VMD_REGISTER_966 (966)
#define BOOST_VMD_REGISTER_967 (967)
#define BOOST_VMD_REGISTER_968 (968)
#define BOOST_VMD_REGISTER_969 (969)
#define BOOST_VMD_REGISTER_970 (970)
#define BOOST_VMD_REGISTER_971 (971)
#define BOOST_VMD_REGISTER_972 (972)
#define BOOST_VMD_REGISTER_973 (973)
#define BOOST_VMD_REGISTER_974 (974)
#define BOOST_VMD_REGISTER_975 (975)
#define BOOST_VMD_REGISTER_976 (976)
#define BOOST_VMD_REGISTER_977 (977)
#define BOOST_VMD_REGISTER_978 (978)
#define BOOST_VMD_REGISTER_979 (979)
#define BOOST_VMD_REGISTER_980 (980)
#define BOOST_VMD_REGISTER_981 (981)
#define BOOST_VMD_REGISTER_982 (982)
#define BOOST_VMD_REGISTER_983 (983)
#define BOOST_VMD_REGISTER_984 (984)
#define BOOST_VMD_REGISTER_985 (985)
#define BOOST_VMD_REGISTER_986 (986)
#define BOOST_VMD_REGISTER_987 (987)
#define BOOST_VMD_REGISTER_988 (988)
#define BOOST_VMD_REGISTER_989 (989)
#define BOOST_VMD_REGISTER_990 (990)
#define BOOST_VMD_REGISTER_991 (991)
#define BOOST_VMD_REGISTER_992 (992)
#define BOOST_VMD_REGISTER_993 (993)
#define BOOST_VMD_REGISTER_994 (994)
#define BOOST_VMD_REGISTER_995 (995)
#define BOOST_VMD_REGISTER_996 (996)
#define BOOST_VMD_REGISTER_997 (997)
#define BOOST_VMD_REGISTER_998 (998)
#define BOOST_VMD_REGISTER_999 (999)
#define BOOST_VMD_REGISTER_1000 (1000)
#define BOOST_VMD_REGISTER_1001 (1001)
#define BOOST_VMD_REGISTER_1002 (1002)
#define BOOST_VMD_REGISTER_1003 (1003)
#define BOOST_VMD_REGISTER_1004 (1004)
#define BOOST_VMD_REGISTER_1005 (1005)
#define BOOST_VMD_REGISTER_1006 (1006)
#define BOOST_VMD_REGISTER_1007 (1007)
#define BOOST_VMD_REGISTER_1008 (1008)
#define BOOST_VMD_REGISTER_1009 (1009)
#define BOOST_VMD_REGISTER_1010 (1010)
#define BOOST_VMD_REGISTER_1011 (1011)
#define BOOST_VMD_REGISTER_1012 (1012)
#define BOOST_VMD_REGISTER_1013 (1013)
#define BOOST_VMD_REGISTER_1014 (1014)
#define BOOST_VMD_REGISTER_1015 (1015)
#define BOOST_VMD_REGISTER_1016 (1016)
#define BOOST_VMD_REGISTER_1017 (1017)
#define BOOST_VMD_REGISTER_1018 (1018)
#define BOOST_VMD_REGISTER_1019 (1019)
#define BOOST_VMD_REGISTER_1020 (1020)
#define BOOST_VMD_REGISTER_1021 (1021)
#define BOOST_VMD_REGISTER_1022 (1022)
#define BOOST_VMD_REGISTER_1023 (1023)
#define BOOST_VMD_REGISTER_1024 (1024)

#endif

#define BOOST_VMD_DETECT_0_0
#define BOOST_VMD_DETECT_1_1
#define BOOST_VMD_DETECT_2_2
#define BOOST_VMD_DETECT_3_3
#define BOOST_VMD_DETECT_4_4
#define BOOST_VMD_DETECT_5_5
#define BOOST_VMD_DETECT_6_6
#define BOOST_VMD_DETECT_7_7
#define BOOST_VMD_DETECT_8_8
#define BOOST_VMD_DETECT_9_9
#define BOOST_VMD_DETECT_10_10
#define BOOST_VMD_DETECT_11_11
#define BOOST_VMD_DETECT_12_12
#define BOOST_VMD_DETECT_13_13
#define BOOST_VMD_DETECT_14_14
#define BOOST_VMD_DETECT_15_15
#define BOOST_VMD_DETECT_16_16
#define BOOST_VMD_DETECT_17_17
#define BOOST_VMD_DETECT_18_18
#define BOOST_VMD_DETECT_19_19
#define BOOST_VMD_DETECT_20_20
#define BOOST_VMD_DETECT_21_21
#define BOOST_VMD_DETECT_22_22
#define BOOST_VMD_DETECT_23_23
#define BOOST_VMD_DETECT_24_24
#define BOOST_VMD_DETECT_25_25
#define BOOST_VMD_DETECT_26_26
#define BOOST_VMD_DETECT_27_27
#define BOOST_VMD_DETECT_28_28
#define BOOST_VMD_DETECT_29_29
#define BOOST_VMD_DETECT_30_30
#define BOOST_VMD_DETECT_31_31
#define BOOST_VMD_DETECT_32_32
#define BOOST_VMD_DETECT_33_33
#define BOOST_VMD_DETECT_34_34
#define BOOST_VMD_DETECT_35_35
#define BOOST_VMD_DETECT_36_36
#define BOOST_VMD_DETECT_37_37
#define BOOST_VMD_DETECT_38_38
#define BOOST_VMD_DETECT_39_39
#define BOOST_VMD_DETECT_40_40
#define BOOST_VMD_DETECT_41_41
#define BOOST_VMD_DETECT_42_42
#define BOOST_VMD_DETECT_43_43
#define BOOST_VMD_DETECT_44_44
#define BOOST_VMD_DETECT_45_45
#define BOOST_VMD_DETECT_46_46
#define BOOST_VMD_DETECT_47_47
#define BOOST_VMD_DETECT_48_48
#define BOOST_VMD_DETECT_49_49
#define BOOST_VMD_DETECT_50_50
#define BOOST_VMD_DETECT_51_51
#define BOOST_VMD_DETECT_52_52
#define BOOST_VMD_DETECT_53_53
#define BOOST_VMD_DETECT_54_54
#define BOOST_VMD_DETECT_55_55
#define BOOST_VMD_DETECT_56_56
#define BOOST_VMD_DETECT_57_57
#define BOOST_VMD_DETECT_58_58
#define BOOST_VMD_DETECT_59_59
#define BOOST_VMD_DETECT_60_60
#define BOOST_VMD_DETECT_61_61
#define BOOST_VMD_DETECT_62_62
#define BOOST_VMD_DETECT_63_63
#define BOOST_VMD_DETECT_64_64
#define BOOST_VMD_DETECT_65_65
#define BOOST_VMD_DETECT_66_66
#define BOOST_VMD_DETECT_67_67
#define BOOST_VMD_DETECT_68_68
#define BOOST_VMD_DETECT_69_69
#define BOOST_VMD_DETECT_70_70
#define BOOST_VMD_DETECT_71_71
#define BOOST_VMD_DETECT_72_72
#define BOOST_VMD_DETECT_73_73
#define BOOST_VMD_DETECT_74_74
#define BOOST_VMD_DETECT_75_75
#define BOOST_VMD_DETECT_76_76
#define BOOST_VMD_DETECT_77_77
#define BOOST_VMD_DETECT_78_78
#define BOOST_VMD_DETECT_79_79
#define BOOST_VMD_DETECT_80_80
#define BOOST_VMD_DETECT_81_81
#define BOOST_VMD_DETECT_82_82
#define BOOST_VMD_DETECT_83_83
#define BOOST_VMD_DETECT_84_84
#define BOOST_VMD_DETECT_85_85
#define BOOST_VMD_DETECT_86_86
#define BOOST_VMD_DETECT_87_87
#define BOOST_VMD_DETECT_88_88
#define BOOST_VMD_DETECT_89_89
#define BOOST_VMD_DETECT_90_90
#define BOOST_VMD_DETECT_91_91
#define BOOST_VMD_DETECT_92_92
#define BOOST_VMD_DETECT_93_93
#define BOOST_VMD_DETECT_94_94
#define BOOST_VMD_DETECT_95_95
#define BOOST_VMD_DETECT_96_96
#define BOOST_VMD_DETECT_97_97
#define BOOST_VMD_DETECT_98_98
#define BOOST_VMD_DETECT_99_99
#define BOOST_VMD_DETECT_100_100
#define BOOST_VMD_DETECT_101_101
#define BOOST_VMD_DETECT_102_102
#define BOOST_VMD_DETECT_103_103
#define BOOST_VMD_DETECT_104_104
#define BOOST_VMD_DETECT_105_105
#define BOOST_VMD_DETECT_106_106
#define BOOST_VMD_DETECT_107_107
#define BOOST_VMD_DETECT_108_108
#define BOOST_VMD_DETECT_109_109
#define BOOST_VMD_DETECT_110_110
#define BOOST_VMD_DETECT_111_111
#define BOOST_VMD_DETECT_112_112
#define BOOST_VMD_DETECT_113_113
#define BOOST_VMD_DETECT_114_114
#define BOOST_VMD_DETECT_115_115
#define BOOST_VMD_DETECT_116_116
#define BOOST_VMD_DETECT_117_117
#define BOOST_VMD_DETECT_118_118
#define BOOST_VMD_DETECT_119_119
#define BOOST_VMD_DETECT_120_120
#define BOOST_VMD_DETECT_121_121
#define BOOST_VMD_DETECT_122_122
#define BOOST_VMD_DETECT_123_123
#define BOOST_VMD_DETECT_124_124
#define BOOST_VMD_DETECT_125_125
#define BOOST_VMD_DETECT_126_126
#define BOOST_VMD_DETECT_127_127
#define BOOST_VMD_DETECT_128_128
#define BOOST_VMD_DETECT_129_129
#define BOOST_VMD_DETECT_130_130
#define BOOST_VMD_DETECT_131_131
#define BOOST_VMD_DETECT_132_132
#define BOOST_VMD_DETECT_133_133
#define BOOST_VMD_DETECT_134_134
#define BOOST_VMD_DETECT_135_135
#define BOOST_VMD_DETECT_136_136
#define BOOST_VMD_DETECT_137_137
#define BOOST_VMD_DETECT_138_138
#define BOOST_VMD_DETECT_139_139
#define BOOST_VMD_DETECT_140_140
#define BOOST_VMD_DETECT_141_141
#define BOOST_VMD_DETECT_142_142
#define BOOST_VMD_DETECT_143_143
#define BOOST_VMD_DETECT_144_144
#define BOOST_VMD_DETECT_145_145
#define BOOST_VMD_DETECT_146_146
#define BOOST_VMD_DETECT_147_147
#define BOOST_VMD_DETECT_148_148
#define BOOST_VMD_DETECT_149_149
#define BOOST_VMD_DETECT_150_150
#define BOOST_VMD_DETECT_151_151
#define BOOST_VMD_DETECT_152_152
#define BOOST_VMD_DETECT_153_153
#define BOOST_VMD_DETECT_154_154
#define BOOST_VMD_DETECT_155_155
#define BOOST_VMD_DETECT_156_156
#define BOOST_VMD_DETECT_157_157
#define BOOST_VMD_DETECT_158_158
#define BOOST_VMD_DETECT_159_159
#define BOOST_VMD_DETECT_160_160
#define BOOST_VMD_DETECT_161_161
#define BOOST_VMD_DETECT_162_162
#define BOOST_VMD_DETECT_163_163
#define BOOST_VMD_DETECT_164_164
#define BOOST_VMD_DETECT_165_165
#define BOOST_VMD_DETECT_166_166
#define BOOST_VMD_DETECT_167_167
#define BOOST_VMD_DETECT_168_168
#define BOOST_VMD_DETECT_169_169
#define BOOST_VMD_DETECT_170_170
#define BOOST_VMD_DETECT_171_171
#define BOOST_VMD_DETECT_172_172
#define BOOST_VMD_DETECT_173_173
#define BOOST_VMD_DETECT_174_174
#define BOOST_VMD_DETECT_175_175
#define BOOST_VMD_DETECT_176_176
#define BOOST_VMD_DETECT_177_177
#define BOOST_VMD_DETECT_178_178
#define BOOST_VMD_DETECT_179_179
#define BOOST_VMD_DETECT_180_180
#define BOOST_VMD_DETECT_181_181
#define BOOST_VMD_DETECT_182_182
#define BOOST_VMD_DETECT_183_183
#define BOOST_VMD_DETECT_184_184
#define BOOST_VMD_DETECT_185_185
#define BOOST_VMD_DETECT_186_186
#define BOOST_VMD_DETECT_187_187
#define BOOST_VMD_DETECT_188_188
#define BOOST_VMD_DETECT_189_189
#define BOOST_VMD_DETECT_190_190
#define BOOST_VMD_DETECT_191_191
#define BOOST_VMD_DETECT_192_192
#define BOOST_VMD_DETECT_193_193
#define BOOST_VMD_DETECT_194_194
#define BOOST_VMD_DETECT_195_195
#define BOOST_VMD_DETECT_196_196
#define BOOST_VMD_DETECT_197_197
#define BOOST_VMD_DETECT_198_198
#define BOOST_VMD_DETECT_199_199
#define BOOST_VMD_DETECT_200_200
#define BOOST_VMD_DETECT_201_201
#define BOOST_VMD_DETECT_202_202
#define BOOST_VMD_DETECT_203_203
#define BOOST_VMD_DETECT_204_204
#define BOOST_VMD_DETECT_205_205
#define BOOST_VMD_DETECT_206_206
#define BOOST_VMD_DETECT_207_207
#define BOOST_VMD_DETECT_208_208
#define BOOST_VMD_DETECT_209_209
#define BOOST_VMD_DETECT_210_210
#define BOOST_VMD_DETECT_211_211
#define BOOST_VMD_DETECT_212_212
#define BOOST_VMD_DETECT_213_213
#define BOOST_VMD_DETECT_214_214
#define BOOST_VMD_DETECT_215_215
#define BOOST_VMD_DETECT_216_216
#define BOOST_VMD_DETECT_217_217
#define BOOST_VMD_DETECT_218_218
#define BOOST_VMD_DETECT_219_219
#define BOOST_VMD_DETECT_220_220
#define BOOST_VMD_DETECT_221_221
#define BOOST_VMD_DETECT_222_222
#define BOOST_VMD_DETECT_223_223
#define BOOST_VMD_DETECT_224_224
#define BOOST_VMD_DETECT_225_225
#define BOOST_VMD_DETECT_226_226
#define BOOST_VMD_DETECT_227_227
#define BOOST_VMD_DETECT_228_228
#define BOOST_VMD_DETECT_229_229
#define BOOST_VMD_DETECT_230_230
#define BOOST_VMD_DETECT_231_231
#define BOOST_VMD_DETECT_232_232
#define BOOST_VMD_DETECT_233_233
#define BOOST_VMD_DETECT_234_234
#define BOOST_VMD_DETECT_235_235
#define BOOST_VMD_DETECT_236_236
#define BOOST_VMD_DETECT_237_237
#define BOOST_VMD_DETECT_238_238
#define BOOST_VMD_DETECT_239_239
#define BOOST_VMD_DETECT_240_240
#define BOOST_VMD_DETECT_241_241
#define BOOST_VMD_DETECT_242_242
#define BOOST_VMD_DETECT_243_243
#define BOOST_VMD_DETECT_244_244
#define BOOST_VMD_DETECT_245_245
#define BOOST_VMD_DETECT_246_246
#define BOOST_VMD_DETECT_247_247
#define BOOST_VMD_DETECT_248_248
#define BOOST_VMD_DETECT_249_249
#define BOOST_VMD_DETECT_250_250
#define BOOST_VMD_DETECT_251_251
#define BOOST_VMD_DETECT_252_252
#define BOOST_VMD_DETECT_253_253
#define BOOST_VMD_DETECT_254_254
#define BOOST_VMD_DETECT_255_255
#define BOOST_VMD_DETECT_256_256

#if BOOST_PP_LIMIT_MAG > 256

#define BOOST_VMD_DETECT_257_257
#define BOOST_VMD_DETECT_258_258
#define BOOST_VMD_DETECT_259_259
#define BOOST_VMD_DETECT_260_260
#define BOOST_VMD_DETECT_261_261
#define BOOST_VMD_DETECT_262_262
#define BOOST_VMD_DETECT_263_263
#define BOOST_VMD_DETECT_264_264
#define BOOST_VMD_DETECT_265_265
#define BOOST_VMD_DETECT_266_266
#define BOOST_VMD_DETECT_267_267
#define BOOST_VMD_DETECT_268_268
#define BOOST_VMD_DETECT_269_269
#define BOOST_VMD_DETECT_270_270
#define BOOST_VMD_DETECT_271_271
#define BOOST_VMD_DETECT_272_272
#define BOOST_VMD_DETECT_273_273
#define BOOST_VMD_DETECT_274_274
#define BOOST_VMD_DETECT_275_275
#define BOOST_VMD_DETECT_276_276
#define BOOST_VMD_DETECT_277_277
#define BOOST_VMD_DETECT_278_278
#define BOOST_VMD_DETECT_279_279
#define BOOST_VMD_DETECT_280_280
#define BOOST_VMD_DETECT_281_281
#define BOOST_VMD_DETECT_282_282
#define BOOST_VMD_DETECT_283_283
#define BOOST_VMD_DETECT_284_284
#define BOOST_VMD_DETECT_285_285
#define BOOST_VMD_DETECT_286_286
#define BOOST_VMD_DETECT_287_287
#define BOOST_VMD_DETECT_288_288
#define BOOST_VMD_DETECT_289_289
#define BOOST_VMD_DETECT_290_290
#define BOOST_VMD_DETECT_291_291
#define BOOST_VMD_DETECT_292_292
#define BOOST_VMD_DETECT_293_293
#define BOOST_VMD_DETECT_294_294
#define BOOST_VMD_DETECT_295_295
#define BOOST_VMD_DETECT_296_296
#define BOOST_VMD_DETECT_297_297
#define BOOST_VMD_DETECT_298_298
#define BOOST_VMD_DETECT_299_299
#define BOOST_VMD_DETECT_300_300
#define BOOST_VMD_DETECT_301_301
#define BOOST_VMD_DETECT_302_302
#define BOOST_VMD_DETECT_303_303
#define BOOST_VMD_DETECT_304_304
#define BOOST_VMD_DETECT_305_305
#define BOOST_VMD_DETECT_306_306
#define BOOST_VMD_DETECT_307_307
#define BOOST_VMD_DETECT_308_308
#define BOOST_VMD_DETECT_309_309
#define BOOST_VMD_DETECT_310_310
#define BOOST_VMD_DETECT_311_311
#define BOOST_VMD_DETECT_312_312
#define BOOST_VMD_DETECT_313_313
#define BOOST_VMD_DETECT_314_314
#define BOOST_VMD_DETECT_315_315
#define BOOST_VMD_DETECT_316_316
#define BOOST_VMD_DETECT_317_317
#define BOOST_VMD_DETECT_318_318
#define BOOST_VMD_DETECT_319_319
#define BOOST_VMD_DETECT_320_320
#define BOOST_VMD_DETECT_321_321
#define BOOST_VMD_DETECT_322_322
#define BOOST_VMD_DETECT_323_323
#define BOOST_VMD_DETECT_324_324
#define BOOST_VMD_DETECT_325_325
#define BOOST_VMD_DETECT_326_326
#define BOOST_VMD_DETECT_327_327
#define BOOST_VMD_DETECT_328_328
#define BOOST_VMD_DETECT_329_329
#define BOOST_VMD_DETECT_330_330
#define BOOST_VMD_DETECT_331_331
#define BOOST_VMD_DETECT_332_332
#define BOOST_VMD_DETECT_333_333
#define BOOST_VMD_DETECT_334_334
#define BOOST_VMD_DETECT_335_335
#define BOOST_VMD_DETECT_336_336
#define BOOST_VMD_DETECT_337_337
#define BOOST_VMD_DETECT_338_338
#define BOOST_VMD_DETECT_339_339
#define BOOST_VMD_DETECT_340_340
#define BOOST_VMD_DETECT_341_341
#define BOOST_VMD_DETECT_342_342
#define BOOST_VMD_DETECT_343_343
#define BOOST_VMD_DETECT_344_344
#define BOOST_VMD_DETECT_345_345
#define BOOST_VMD_DETECT_346_346
#define BOOST_VMD_DETECT_347_347
#define BOOST_VMD_DETECT_348_348
#define BOOST_VMD_DETECT_349_349
#define BOOST_VMD_DETECT_350_350
#define BOOST_VMD_DETECT_351_351
#define BOOST_VMD_DETECT_352_352
#define BOOST_VMD_DETECT_353_353
#define BOOST_VMD_DETECT_354_354
#define BOOST_VMD_DETECT_355_355
#define BOOST_VMD_DETECT_356_356
#define BOOST_VMD_DETECT_357_357
#define BOOST_VMD_DETECT_358_358
#define BOOST_VMD_DETECT_359_359
#define BOOST_VMD_DETECT_360_360
#define BOOST_VMD_DETECT_361_361
#define BOOST_VMD_DETECT_362_362
#define BOOST_VMD_DETECT_363_363
#define BOOST_VMD_DETECT_364_364
#define BOOST_VMD_DETECT_365_365
#define BOOST_VMD_DETECT_366_366
#define BOOST_VMD_DETECT_367_367
#define BOOST_VMD_DETECT_368_368
#define BOOST_VMD_DETECT_369_369
#define BOOST_VMD_DETECT_370_370
#define BOOST_VMD_DETECT_371_371
#define BOOST_VMD_DETECT_372_372
#define BOOST_VMD_DETECT_373_373
#define BOOST_VMD_DETECT_374_374
#define BOOST_VMD_DETECT_375_375
#define BOOST_VMD_DETECT_376_376
#define BOOST_VMD_DETECT_377_377
#define BOOST_VMD_DETECT_378_378
#define BOOST_VMD_DETECT_379_379
#define BOOST_VMD_DETECT_380_380
#define BOOST_VMD_DETECT_381_381
#define BOOST_VMD_DETECT_382_382
#define BOOST_VMD_DETECT_383_383
#define BOOST_VMD_DETECT_384_384
#define BOOST_VMD_DETECT_385_385
#define BOOST_VMD_DETECT_386_386
#define BOOST_VMD_DETECT_387_387
#define BOOST_VMD_DETECT_388_388
#define BOOST_VMD_DETECT_389_389
#define BOOST_VMD_DETECT_390_390
#define BOOST_VMD_DETECT_391_391
#define BOOST_VMD_DETECT_392_392
#define BOOST_VMD_DETECT_393_393
#define BOOST_VMD_DETECT_394_394
#define BOOST_VMD_DETECT_395_395
#define BOOST_VMD_DETECT_396_396
#define BOOST_VMD_DETECT_397_397
#define BOOST_VMD_DETECT_398_398
#define BOOST_VMD_DETECT_399_399
#define BOOST_VMD_DETECT_400_400
#define BOOST_VMD_DETECT_401_401
#define BOOST_VMD_DETECT_402_402
#define BOOST_VMD_DETECT_403_403
#define BOOST_VMD_DETECT_404_404
#define BOOST_VMD_DETECT_405_405
#define BOOST_VMD_DETECT_406_406
#define BOOST_VMD_DETECT_407_407
#define BOOST_VMD_DETECT_408_408
#define BOOST_VMD_DETECT_409_409
#define BOOST_VMD_DETECT_410_410
#define BOOST_VMD_DETECT_411_411
#define BOOST_VMD_DETECT_412_412
#define BOOST_VMD_DETECT_413_413
#define BOOST_VMD_DETECT_414_414
#define BOOST_VMD_DETECT_415_415
#define BOOST_VMD_DETECT_416_416
#define BOOST_VMD_DETECT_417_417
#define BOOST_VMD_DETECT_418_418
#define BOOST_VMD_DETECT_419_419
#define BOOST_VMD_DETECT_420_420
#define BOOST_VMD_DETECT_421_421
#define BOOST_VMD_DETECT_422_422
#define BOOST_VMD_DETECT_423_423
#define BOOST_VMD_DETECT_424_424
#define BOOST_VMD_DETECT_425_425
#define BOOST_VMD_DETECT_426_426
#define BOOST_VMD_DETECT_427_427
#define BOOST_VMD_DETECT_428_428
#define BOOST_VMD_DETECT_429_429
#define BOOST_VMD_DETECT_430_430
#define BOOST_VMD_DETECT_431_431
#define BOOST_VMD_DETECT_432_432
#define BOOST_VMD_DETECT_433_433
#define BOOST_VMD_DETECT_434_434
#define BOOST_VMD_DETECT_435_435
#define BOOST_VMD_DETECT_436_436
#define BOOST_VMD_DETECT_437_437
#define BOOST_VMD_DETECT_438_438
#define BOOST_VMD_DETECT_439_439
#define BOOST_VMD_DETECT_440_440
#define BOOST_VMD_DETECT_441_441
#define BOOST_VMD_DETECT_442_442
#define BOOST_VMD_DETECT_443_443
#define BOOST_VMD_DETECT_444_444
#define BOOST_VMD_DETECT_445_445
#define BOOST_VMD_DETECT_446_446
#define BOOST_VMD_DETECT_447_447
#define BOOST_VMD_DETECT_448_448
#define BOOST_VMD_DETECT_449_449
#define BOOST_VMD_DETECT_450_450
#define BOOST_VMD_DETECT_451_451
#define BOOST_VMD_DETECT_452_452
#define BOOST_VMD_DETECT_453_453
#define BOOST_VMD_DETECT_454_454
#define BOOST_VMD_DETECT_455_455
#define BOOST_VMD_DETECT_456_456
#define BOOST_VMD_DETECT_457_457
#define BOOST_VMD_DETECT_458_458
#define BOOST_VMD_DETECT_459_459
#define BOOST_VMD_DETECT_460_460
#define BOOST_VMD_DETECT_461_461
#define BOOST_VMD_DETECT_462_462
#define BOOST_VMD_DETECT_463_463
#define BOOST_VMD_DETECT_464_464
#define BOOST_VMD_DETECT_465_465
#define BOOST_VMD_DETECT_466_466
#define BOOST_VMD_DETECT_467_467
#define BOOST_VMD_DETECT_468_468
#define BOOST_VMD_DETECT_469_469
#define BOOST_VMD_DETECT_470_470
#define BOOST_VMD_DETECT_471_471
#define BOOST_VMD_DETECT_472_472
#define BOOST_VMD_DETECT_473_473
#define BOOST_VMD_DETECT_474_474
#define BOOST_VMD_DETECT_475_475
#define BOOST_VMD_DETECT_476_476
#define BOOST_VMD_DETECT_477_477
#define BOOST_VMD_DETECT_478_478
#define BOOST_VMD_DETECT_479_479
#define BOOST_VMD_DETECT_480_480
#define BOOST_VMD_DETECT_481_481
#define BOOST_VMD_DETECT_482_482
#define BOOST_VMD_DETECT_483_483
#define BOOST_VMD_DETECT_484_484
#define BOOST_VMD_DETECT_485_485
#define BOOST_VMD_DETECT_486_486
#define BOOST_VMD_DETECT_487_487
#define BOOST_VMD_DETECT_488_488
#define BOOST_VMD_DETECT_489_489
#define BOOST_VMD_DETECT_490_490
#define BOOST_VMD_DETECT_491_491
#define BOOST_VMD_DETECT_492_492
#define BOOST_VMD_DETECT_493_493
#define BOOST_VMD_DETECT_494_494
#define BOOST_VMD_DETECT_495_495
#define BOOST_VMD_DETECT_496_496
#define BOOST_VMD_DETECT_497_497
#define BOOST_VMD_DETECT_498_498
#define BOOST_VMD_DETECT_499_499
#define BOOST_VMD_DETECT_500_500
#define BOOST_VMD_DETECT_501_501
#define BOOST_VMD_DETECT_502_502
#define BOOST_VMD_DETECT_503_503
#define BOOST_VMD_DETECT_504_504
#define BOOST_VMD_DETECT_505_505
#define BOOST_VMD_DETECT_506_506
#define BOOST_VMD_DETECT_507_507
#define BOOST_VMD_DETECT_508_508
#define BOOST_VMD_DETECT_509_509
#define BOOST_VMD_DETECT_510_510
#define BOOST_VMD_DETECT_511_511
#define BOOST_VMD_DETECT_512_512

#endif

#if BOOST_PP_LIMIT_MAG > 512

#define BOOST_VMD_DETECT_513_513
#define BOOST_VMD_DETECT_514_514
#define BOOST_VMD_DETECT_515_515
#define BOOST_VMD_DETECT_516_516
#define BOOST_VMD_DETECT_517_517
#define BOOST_VMD_DETECT_518_518
#define BOOST_VMD_DETECT_519_519
#define BOOST_VMD_DETECT_520_520
#define BOOST_VMD_DETECT_521_521
#define BOOST_VMD_DETECT_522_522
#define BOOST_VMD_DETECT_523_523
#define BOOST_VMD_DETECT_524_524
#define BOOST_VMD_DETECT_525_525
#define BOOST_VMD_DETECT_526_526
#define BOOST_VMD_DETECT_527_527
#define BOOST_VMD_DETECT_528_528
#define BOOST_VMD_DETECT_529_529
#define BOOST_VMD_DETECT_530_530
#define BOOST_VMD_DETECT_531_531
#define BOOST_VMD_DETECT_532_532
#define BOOST_VMD_DETECT_533_533
#define BOOST_VMD_DETECT_534_534
#define BOOST_VMD_DETECT_535_535
#define BOOST_VMD_DETECT_536_536
#define BOOST_VMD_DETECT_537_537
#define BOOST_VMD_DETECT_538_538
#define BOOST_VMD_DETECT_539_539
#define BOOST_VMD_DETECT_540_540
#define BOOST_VMD_DETECT_541_541
#define BOOST_VMD_DETECT_542_542
#define BOOST_VMD_DETECT_543_543
#define BOOST_VMD_DETECT_544_544
#define BOOST_VMD_DETECT_545_545
#define BOOST_VMD_DETECT_546_546
#define BOOST_VMD_DETECT_547_547
#define BOOST_VMD_DETECT_548_548
#define BOOST_VMD_DETECT_549_549
#define BOOST_VMD_DETECT_550_550
#define BOOST_VMD_DETECT_551_551
#define BOOST_VMD_DETECT_552_552
#define BOOST_VMD_DETECT_553_553
#define BOOST_VMD_DETECT_554_554
#define BOOST_VMD_DETECT_555_555
#define BOOST_VMD_DETECT_556_556
#define BOOST_VMD_DETECT_557_557
#define BOOST_VMD_DETECT_558_558
#define BOOST_VMD_DETECT_559_559
#define BOOST_VMD_DETECT_560_560
#define BOOST_VMD_DETECT_561_561
#define BOOST_VMD_DETECT_562_562
#define BOOST_VMD_DETECT_563_563
#define BOOST_VMD_DETECT_564_564
#define BOOST_VMD_DETECT_565_565
#define BOOST_VMD_DETECT_566_566
#define BOOST_VMD_DETECT_567_567
#define BOOST_VMD_DETECT_568_568
#define BOOST_VMD_DETECT_569_569
#define BOOST_VMD_DETECT_570_570
#define BOOST_VMD_DETECT_571_571
#define BOOST_VMD_DETECT_572_572
#define BOOST_VMD_DETECT_573_573
#define BOOST_VMD_DETECT_574_574
#define BOOST_VMD_DETECT_575_575
#define BOOST_VMD_DETECT_576_576
#define BOOST_VMD_DETECT_577_577
#define BOOST_VMD_DETECT_578_578
#define BOOST_VMD_DETECT_579_579
#define BOOST_VMD_DETECT_580_580
#define BOOST_VMD_DETECT_581_581
#define BOOST_VMD_DETECT_582_582
#define BOOST_VMD_DETECT_583_583
#define BOOST_VMD_DETECT_584_584
#define BOOST_VMD_DETECT_585_585
#define BOOST_VMD_DETECT_586_586
#define BOOST_VMD_DETECT_587_587
#define BOOST_VMD_DETECT_588_588
#define BOOST_VMD_DETECT_589_589
#define BOOST_VMD_DETECT_590_590
#define BOOST_VMD_DETECT_591_591
#define BOOST_VMD_DETECT_592_592
#define BOOST_VMD_DETECT_593_593
#define BOOST_VMD_DETECT_594_594
#define BOOST_VMD_DETECT_595_595
#define BOOST_VMD_DETECT_596_596
#define BOOST_VMD_DETECT_597_597
#define BOOST_VMD_DETECT_598_598
#define BOOST_VMD_DETECT_599_599
#define BOOST_VMD_DETECT_600_600
#define BOOST_VMD_DETECT_601_601
#define BOOST_VMD_DETECT_602_602
#define BOOST_VMD_DETECT_603_603
#define BOOST_VMD_DETECT_604_604
#define BOOST_VMD_DETECT_605_605
#define BOOST_VMD_DETECT_606_606
#define BOOST_VMD_DETECT_607_607
#define BOOST_VMD_DETECT_608_608
#define BOOST_VMD_DETECT_609_609
#define BOOST_VMD_DETECT_610_610
#define BOOST_VMD_DETECT_611_611
#define BOOST_VMD_DETECT_612_612
#define BOOST_VMD_DETECT_613_613
#define BOOST_VMD_DETECT_614_614
#define BOOST_VMD_DETECT_615_615
#define BOOST_VMD_DETECT_616_616
#define BOOST_VMD_DETECT_617_617
#define BOOST_VMD_DETECT_618_618
#define BOOST_VMD_DETECT_619_619
#define BOOST_VMD_DETECT_620_620
#define BOOST_VMD_DETECT_621_621
#define BOOST_VMD_DETECT_622_622
#define BOOST_VMD_DETECT_623_623
#define BOOST_VMD_DETECT_624_624
#define BOOST_VMD_DETECT_625_625
#define BOOST_VMD_DETECT_626_626
#define BOOST_VMD_DETECT_627_627
#define BOOST_VMD_DETECT_628_628
#define BOOST_VMD_DETECT_629_629
#define BOOST_VMD_DETECT_630_630
#define BOOST_VMD_DETECT_631_631
#define BOOST_VMD_DETECT_632_632
#define BOOST_VMD_DETECT_633_633
#define BOOST_VMD_DETECT_634_634
#define BOOST_VMD_DETECT_635_635
#define BOOST_VMD_DETECT_636_636
#define BOOST_VMD_DETECT_637_637
#define BOOST_VMD_DETECT_638_638
#define BOOST_VMD_DETECT_639_639
#define BOOST_VMD_DETECT_640_640
#define BOOST_VMD_DETECT_641_641
#define BOOST_VMD_DETECT_642_642
#define BOOST_VMD_DETECT_643_643
#define BOOST_VMD_DETECT_644_644
#define BOOST_VMD_DETECT_645_645
#define BOOST_VMD_DETECT_646_646
#define BOOST_VMD_DETECT_647_647
#define BOOST_VMD_DETECT_648_648
#define BOOST_VMD_DETECT_649_649
#define BOOST_VMD_DETECT_650_650
#define BOOST_VMD_DETECT_651_651
#define BOOST_VMD_DETECT_652_652
#define BOOST_VMD_DETECT_653_653
#define BOOST_VMD_DETECT_654_654
#define BOOST_VMD_DETECT_655_655
#define BOOST_VMD_DETECT_656_656
#define BOOST_VMD_DETECT_657_657
#define BOOST_VMD_DETECT_658_658
#define BOOST_VMD_DETECT_659_659
#define BOOST_VMD_DETECT_660_660
#define BOOST_VMD_DETECT_661_661
#define BOOST_VMD_DETECT_662_662
#define BOOST_VMD_DETECT_663_663
#define BOOST_VMD_DETECT_664_664
#define BOOST_VMD_DETECT_665_665
#define BOOST_VMD_DETECT_666_666
#define BOOST_VMD_DETECT_667_667
#define BOOST_VMD_DETECT_668_668
#define BOOST_VMD_DETECT_669_669
#define BOOST_VMD_DETECT_670_670
#define BOOST_VMD_DETECT_671_671
#define BOOST_VMD_DETECT_672_672
#define BOOST_VMD_DETECT_673_673
#define BOOST_VMD_DETECT_674_674
#define BOOST_VMD_DETECT_675_675
#define BOOST_VMD_DETECT_676_676
#define BOOST_VMD_DETECT_677_677
#define BOOST_VMD_DETECT_678_678
#define BOOST_VMD_DETECT_679_679
#define BOOST_VMD_DETECT_680_680
#define BOOST_VMD_DETECT_681_681
#define BOOST_VMD_DETECT_682_682
#define BOOST_VMD_DETECT_683_683
#define BOOST_VMD_DETECT_684_684
#define BOOST_VMD_DETECT_685_685
#define BOOST_VMD_DETECT_686_686
#define BOOST_VMD_DETECT_687_687
#define BOOST_VMD_DETECT_688_688
#define BOOST_VMD_DETECT_689_689
#define BOOST_VMD_DETECT_690_690
#define BOOST_VMD_DETECT_691_691
#define BOOST_VMD_DETECT_692_692
#define BOOST_VMD_DETECT_693_693
#define BOOST_VMD_DETECT_694_694
#define BOOST_VMD_DETECT_695_695
#define BOOST_VMD_DETECT_696_696
#define BOOST_VMD_DETECT_697_697
#define BOOST_VMD_DETECT_698_698
#define BOOST_VMD_DETECT_699_699
#define BOOST_VMD_DETECT_700_700
#define BOOST_VMD_DETECT_701_701
#define BOOST_VMD_DETECT_702_702
#define BOOST_VMD_DETECT_703_703
#define BOOST_VMD_DETECT_704_704
#define BOOST_VMD_DETECT_705_705
#define BOOST_VMD_DETECT_706_706
#define BOOST_VMD_DETECT_707_707
#define BOOST_VMD_DETECT_708_708
#define BOOST_VMD_DETECT_709_709
#define BOOST_VMD_DETECT_710_710
#define BOOST_VMD_DETECT_711_711
#define BOOST_VMD_DETECT_712_712
#define BOOST_VMD_DETECT_713_713
#define BOOST_VMD_DETECT_714_714
#define BOOST_VMD_DETECT_715_715
#define BOOST_VMD_DETECT_716_716
#define BOOST_VMD_DETECT_717_717
#define BOOST_VMD_DETECT_718_718
#define BOOST_VMD_DETECT_719_719
#define BOOST_VMD_DETECT_720_720
#define BOOST_VMD_DETECT_721_721
#define BOOST_VMD_DETECT_722_722
#define BOOST_VMD_DETECT_723_723
#define BOOST_VMD_DETECT_724_724
#define BOOST_VMD_DETECT_725_725
#define BOOST_VMD_DETECT_726_726
#define BOOST_VMD_DETECT_727_727
#define BOOST_VMD_DETECT_728_728
#define BOOST_VMD_DETECT_729_729
#define BOOST_VMD_DETECT_730_730
#define BOOST_VMD_DETECT_731_731
#define BOOST_VMD_DETECT_732_732
#define BOOST_VMD_DETECT_733_733
#define BOOST_VMD_DETECT_734_734
#define BOOST_VMD_DETECT_735_735
#define BOOST_VMD_DETECT_736_736
#define BOOST_VMD_DETECT_737_737
#define BOOST_VMD_DETECT_738_738
#define BOOST_VMD_DETECT_739_739
#define BOOST_VMD_DETECT_740_740
#define BOOST_VMD_DETECT_741_741
#define BOOST_VMD_DETECT_742_742
#define BOOST_VMD_DETECT_743_743
#define BOOST_VMD_DETECT_744_744
#define BOOST_VMD_DETECT_745_745
#define BOOST_VMD_DETECT_746_746
#define BOOST_VMD_DETECT_747_747
#define BOOST_VMD_DETECT_748_748
#define BOOST_VMD_DETECT_749_749
#define BOOST_VMD_DETECT_750_750
#define BOOST_VMD_DETECT_751_751
#define BOOST_VMD_DETECT_752_752
#define BOOST_VMD_DETECT_753_753
#define BOOST_VMD_DETECT_754_754
#define BOOST_VMD_DETECT_755_755
#define BOOST_VMD_DETECT_756_756
#define BOOST_VMD_DETECT_757_757
#define BOOST_VMD_DETECT_758_758
#define BOOST_VMD_DETECT_759_759
#define BOOST_VMD_DETECT_760_760
#define BOOST_VMD_DETECT_761_761
#define BOOST_VMD_DETECT_762_762
#define BOOST_VMD_DETECT_763_763
#define BOOST_VMD_DETECT_764_764
#define BOOST_VMD_DETECT_765_765
#define BOOST_VMD_DETECT_766_766
#define BOOST_VMD_DETECT_767_767
#define BOOST_VMD_DETECT_768_768
#define BOOST_VMD_DETECT_769_769
#define BOOST_VMD_DETECT_770_770
#define BOOST_VMD_DETECT_771_771
#define BOOST_VMD_DETECT_772_772
#define BOOST_VMD_DETECT_773_773
#define BOOST_VMD_DETECT_774_774
#define BOOST_VMD_DETECT_775_775
#define BOOST_VMD_DETECT_776_776
#define BOOST_VMD_DETECT_777_777
#define BOOST_VMD_DETECT_778_778
#define BOOST_VMD_DETECT_779_779
#define BOOST_VMD_DETECT_780_780
#define BOOST_VMD_DETECT_781_781
#define BOOST_VMD_DETECT_782_782
#define BOOST_VMD_DETECT_783_783
#define BOOST_VMD_DETECT_784_784
#define BOOST_VMD_DETECT_785_785
#define BOOST_VMD_DETECT_786_786
#define BOOST_VMD_DETECT_787_787
#define BOOST_VMD_DETECT_788_788
#define BOOST_VMD_DETECT_789_789
#define BOOST_VMD_DETECT_790_790
#define BOOST_VMD_DETECT_791_791
#define BOOST_VMD_DETECT_792_792
#define BOOST_VMD_DETECT_793_793
#define BOOST_VMD_DETECT_794_794
#define BOOST_VMD_DETECT_795_795
#define BOOST_VMD_DETECT_796_796
#define BOOST_VMD_DETECT_797_797
#define BOOST_VMD_DETECT_798_798
#define BOOST_VMD_DETECT_799_799
#define BOOST_VMD_DETECT_800_800
#define BOOST_VMD_DETECT_801_801
#define BOOST_VMD_DETECT_802_802
#define BOOST_VMD_DETECT_803_803
#define BOOST_VMD_DETECT_804_804
#define BOOST_VMD_DETECT_805_805
#define BOOST_VMD_DETECT_806_806
#define BOOST_VMD_DETECT_807_807
#define BOOST_VMD_DETECT_808_808
#define BOOST_VMD_DETECT_809_809
#define BOOST_VMD_DETECT_810_810
#define BOOST_VMD_DETECT_811_811
#define BOOST_VMD_DETECT_812_812
#define BOOST_VMD_DETECT_813_813
#define BOOST_VMD_DETECT_814_814
#define BOOST_VMD_DETECT_815_815
#define BOOST_VMD_DETECT_816_816
#define BOOST_VMD_DETECT_817_817
#define BOOST_VMD_DETECT_818_818
#define BOOST_VMD_DETECT_819_819
#define BOOST_VMD_DETECT_820_820
#define BOOST_VMD_DETECT_821_821
#define BOOST_VMD_DETECT_822_822
#define BOOST_VMD_DETECT_823_823
#define BOOST_VMD_DETECT_824_824
#define BOOST_VMD_DETECT_825_825
#define BOOST_VMD_DETECT_826_826
#define BOOST_VMD_DETECT_827_827
#define BOOST_VMD_DETECT_828_828
#define BOOST_VMD_DETECT_829_829
#define BOOST_VMD_DETECT_830_830
#define BOOST_VMD_DETECT_831_831
#define BOOST_VMD_DETECT_832_832
#define BOOST_VMD_DETECT_833_833
#define BOOST_VMD_DETECT_834_834
#define BOOST_VMD_DETECT_835_835
#define BOOST_VMD_DETECT_836_836
#define BOOST_VMD_DETECT_837_837
#define BOOST_VMD_DETECT_838_838
#define BOOST_VMD_DETECT_839_839
#define BOOST_VMD_DETECT_840_840
#define BOOST_VMD_DETECT_841_841
#define BOOST_VMD_DETECT_842_842
#define BOOST_VMD_DETECT_843_843
#define BOOST_VMD_DETECT_844_844
#define BOOST_VMD_DETECT_845_845
#define BOOST_VMD_DETECT_846_846
#define BOOST_VMD_DETECT_847_847
#define BOOST_VMD_DETECT_848_848
#define BOOST_VMD_DETECT_849_849
#define BOOST_VMD_DETECT_850_850
#define BOOST_VMD_DETECT_851_851
#define BOOST_VMD_DETECT_852_852
#define BOOST_VMD_DETECT_853_853
#define BOOST_VMD_DETECT_854_854
#define BOOST_VMD_DETECT_855_855
#define BOOST_VMD_DETECT_856_856
#define BOOST_VMD_DETECT_857_857
#define BOOST_VMD_DETECT_858_858
#define BOOST_VMD_DETECT_859_859
#define BOOST_VMD_DETECT_860_860
#define BOOST_VMD_DETECT_861_861
#define BOOST_VMD_DETECT_862_862
#define BOOST_VMD_DETECT_863_863
#define BOOST_VMD_DETECT_864_864
#define BOOST_VMD_DETECT_865_865
#define BOOST_VMD_DETECT_866_866
#define BOOST_VMD_DETECT_867_867
#define BOOST_VMD_DETECT_868_868
#define BOOST_VMD_DETECT_869_869
#define BOOST_VMD_DETECT_870_870
#define BOOST_VMD_DETECT_871_871
#define BOOST_VMD_DETECT_872_872
#define BOOST_VMD_DETECT_873_873
#define BOOST_VMD_DETECT_874_874
#define BOOST_VMD_DETECT_875_875
#define BOOST_VMD_DETECT_876_876
#define BOOST_VMD_DETECT_877_877
#define BOOST_VMD_DETECT_878_878
#define BOOST_VMD_DETECT_879_879
#define BOOST_VMD_DETECT_880_880
#define BOOST_VMD_DETECT_881_881
#define BOOST_VMD_DETECT_882_882
#define BOOST_VMD_DETECT_883_883
#define BOOST_VMD_DETECT_884_884
#define BOOST_VMD_DETECT_885_885
#define BOOST_VMD_DETECT_886_886
#define BOOST_VMD_DETECT_887_887
#define BOOST_VMD_DETECT_888_888
#define BOOST_VMD_DETECT_889_889
#define BOOST_VMD_DETECT_890_890
#define BOOST_VMD_DETECT_891_891
#define BOOST_VMD_DETECT_892_892
#define BOOST_VMD_DETECT_893_893
#define BOOST_VMD_DETECT_894_894
#define BOOST_VMD_DETECT_895_895
#define BOOST_VMD_DETECT_896_896
#define BOOST_VMD_DETECT_897_897
#define BOOST_VMD_DETECT_898_898
#define BOOST_VMD_DETECT_899_899
#define BOOST_VMD_DETECT_900_900
#define BOOST_VMD_DETECT_901_901
#define BOOST_VMD_DETECT_902_902
#define BOOST_VMD_DETECT_903_903
#define BOOST_VMD_DETECT_904_904
#define BOOST_VMD_DETECT_905_905
#define BOOST_VMD_DETECT_906_906
#define BOOST_VMD_DETECT_907_907
#define BOOST_VMD_DETECT_908_908
#define BOOST_VMD_DETECT_909_909
#define BOOST_VMD_DETECT_910_910
#define BOOST_VMD_DETECT_911_911
#define BOOST_VMD_DETECT_912_912
#define BOOST_VMD_DETECT_913_913
#define BOOST_VMD_DETECT_914_914
#define BOOST_VMD_DETECT_915_915
#define BOOST_VMD_DETECT_916_916
#define BOOST_VMD_DETECT_917_917
#define BOOST_VMD_DETECT_918_918
#define BOOST_VMD_DETECT_919_919
#define BOOST_VMD_DETECT_920_920
#define BOOST_VMD_DETECT_921_921
#define BOOST_VMD_DETECT_922_922
#define BOOST_VMD_DETECT_923_923
#define BOOST_VMD_DETECT_924_924
#define BOOST_VMD_DETECT_925_925
#define BOOST_VMD_DETECT_926_926
#define BOOST_VMD_DETECT_927_927
#define BOOST_VMD_DETECT_928_928
#define BOOST_VMD_DETECT_929_929
#define BOOST_VMD_DETECT_930_930
#define BOOST_VMD_DETECT_931_931
#define BOOST_VMD_DETECT_932_932
#define BOOST_VMD_DETECT_933_933
#define BOOST_VMD_DETECT_934_934
#define BOOST_VMD_DETECT_935_935
#define BOOST_VMD_DETECT_936_936
#define BOOST_VMD_DETECT_937_937
#define BOOST_VMD_DETECT_938_938
#define BOOST_VMD_DETECT_939_939
#define BOOST_VMD_DETECT_940_940
#define BOOST_VMD_DETECT_941_941
#define BOOST_VMD_DETECT_942_942
#define BOOST_VMD_DETECT_943_943
#define BOOST_VMD_DETECT_944_944
#define BOOST_VMD_DETECT_945_945
#define BOOST_VMD_DETECT_946_946
#define BOOST_VMD_DETECT_947_947
#define BOOST_VMD_DETECT_948_948
#define BOOST_VMD_DETECT_949_949
#define BOOST_VMD_DETECT_950_950
#define BOOST_VMD_DETECT_951_951
#define BOOST_VMD_DETECT_952_952
#define BOOST_VMD_DETECT_953_953
#define BOOST_VMD_DETECT_954_954
#define BOOST_VMD_DETECT_955_955
#define BOOST_VMD_DETECT_956_956
#define BOOST_VMD_DETECT_957_957
#define BOOST_VMD_DETECT_958_958
#define BOOST_VMD_DETECT_959_959
#define BOOST_VMD_DETECT_960_960
#define BOOST_VMD_DETECT_961_961
#define BOOST_VMD_DETECT_962_962
#define BOOST_VMD_DETECT_963_963
#define BOOST_VMD_DETECT_964_964
#define BOOST_VMD_DETECT_965_965
#define BOOST_VMD_DETECT_966_966
#define BOOST_VMD_DETECT_967_967
#define BOOST_VMD_DETECT_968_968
#define BOOST_VMD_DETECT_969_969
#define BOOST_VMD_DETECT_970_970
#define BOOST_VMD_DETECT_971_971
#define BOOST_VMD_DETECT_972_972
#define BOOST_VMD_DETECT_973_973
#define BOOST_VMD_DETECT_974_974
#define BOOST_VMD_DETECT_975_975
#define BOOST_VMD_DETECT_976_976
#define BOOST_VMD_DETECT_977_977
#define BOOST_VMD_DETECT_978_978
#define BOOST_VMD_DETECT_979_979
#define BOOST_VMD_DETECT_980_980
#define BOOST_VMD_DETECT_981_981
#define BOOST_VMD_DETECT_982_982
#define BOOST_VMD_DETECT_983_983
#define BOOST_VMD_DETECT_984_984
#define BOOST_VMD_DETECT_985_985
#define BOOST_VMD_DETECT_986_986
#define BOOST_VMD_DETECT_987_987
#define BOOST_VMD_DETECT_988_988
#define BOOST_VMD_DETECT_989_989
#define BOOST_VMD_DETECT_990_990
#define BOOST_VMD_DETECT_991_991
#define BOOST_VMD_DETECT_992_992
#define BOOST_VMD_DETECT_993_993
#define BOOST_VMD_DETECT_994_994
#define BOOST_VMD_DETECT_995_995
#define BOOST_VMD_DETECT_996_996
#define BOOST_VMD_DETECT_997_997
#define BOOST_VMD_DETECT_998_998
#define BOOST_VMD_DETECT_999_999
#define BOOST_VMD_DETECT_1000_1000
#define BOOST_VMD_DETECT_1001_1001
#define BOOST_VMD_DETECT_1002_1002
#define BOOST_VMD_DETECT_1003_1003
#define BOOST_VMD_DETECT_1004_1004
#define BOOST_VMD_DETECT_1005_1005
#define BOOST_VMD_DETECT_1006_1006
#define BOOST_VMD_DETECT_1007_1007
#define BOOST_VMD_DETECT_1008_1008
#define BOOST_VMD_DETECT_1009_1009
#define BOOST_VMD_DETECT_1010_1010
#define BOOST_VMD_DETECT_1011_1011
#define BOOST_VMD_DETECT_1012_1012
#define BOOST_VMD_DETECT_1013_1013
#define BOOST_VMD_DETECT_1014_1014
#define BOOST_VMD_DETECT_1015_1015
#define BOOST_VMD_DETECT_1016_1016
#define BOOST_VMD_DETECT_1017_1017
#define BOOST_VMD_DETECT_1018_1018
#define BOOST_VMD_DETECT_1019_1019
#define BOOST_VMD_DETECT_1020_1020
#define BOOST_VMD_DETECT_1021_1021
#define BOOST_VMD_DETECT_1022_1022
#define BOOST_VMD_DETECT_1023_1023
#define BOOST_VMD_DETECT_1024_1024

#endif

#define BOOST_VMD_SUBTYPE_REGISTER_0 (BOOST_VMD_TYPE_NUMBER,0)
#define BOOST_VMD_SUBTYPE_REGISTER_1 (BOOST_VMD_TYPE_NUMBER,1)
#define BOOST_VMD_SUBTYPE_REGISTER_2 (BOOST_VMD_TYPE_NUMBER,2)
#define BOOST_VMD_SUBTYPE_REGISTER_3 (BOOST_VMD_TYPE_NUMBER,3)
#define BOOST_VMD_SUBTYPE_REGISTER_4 (BOOST_VMD_TYPE_NUMBER,4)
#define BOOST_VMD_SUBTYPE_REGISTER_5 (BOOST_VMD_TYPE_NUMBER,5)
#define BOOST_VMD_SUBTYPE_REGISTER_6 (BOOST_VMD_TYPE_NUMBER,6)
#define BOOST_VMD_SUBTYPE_REGISTER_7 (BOOST_VMD_TYPE_NUMBER,7)
#define BOOST_VMD_SUBTYPE_REGISTER_8 (BOOST_VMD_TYPE_NUMBER,8)
#define BOOST_VMD_SUBTYPE_REGISTER_9 (BOOST_VMD_TYPE_NUMBER,9)
#define BOOST_VMD_SUBTYPE_REGISTER_10 (BOOST_VMD_TYPE_NUMBER,10)
#define BOOST_VMD_SUBTYPE_REGISTER_11 (BOOST_VMD_TYPE_NUMBER,11)
#define BOOST_VMD_SUBTYPE_REGISTER_12 (BOOST_VMD_TYPE_NUMBER,12)
#define BOOST_VMD_SUBTYPE_REGISTER_13 (BOOST_VMD_TYPE_NUMBER,13)
#define BOOST_VMD_SUBTYPE_REGISTER_14 (BOOST_VMD_TYPE_NUMBER,14)
#define BOOST_VMD_SUBTYPE_REGISTER_15 (BOOST_VMD_TYPE_NUMBER,15)
#define BOOST_VMD_SUBTYPE_REGISTER_16 (BOOST_VMD_TYPE_NUMBER,16)
#define BOOST_VMD_SUBTYPE_REGISTER_17 (BOOST_VMD_TYPE_NUMBER,17)
#define BOOST_VMD_SUBTYPE_REGISTER_18 (BOOST_VMD_TYPE_NUMBER,18)
#define BOOST_VMD_SUBTYPE_REGISTER_19 (BOOST_VMD_TYPE_NUMBER,19)
#define BOOST_VMD_SUBTYPE_REGISTER_20 (BOOST_VMD_TYPE_NUMBER,20)
#define BOOST_VMD_SUBTYPE_REGISTER_21 (BOOST_VMD_TYPE_NUMBER,21)
#define BOOST_VMD_SUBTYPE_REGISTER_22 (BOOST_VMD_TYPE_NUMBER,22)
#define BOOST_VMD_SUBTYPE_REGISTER_23 (BOOST_VMD_TYPE_NUMBER,23)
#define BOOST_VMD_SUBTYPE_REGISTER_24 (BOOST_VMD_TYPE_NUMBER,24)
#define BOOST_VMD_SUBTYPE_REGISTER_25 (BOOST_VMD_TYPE_NUMBER,25)
#define BOOST_VMD_SUBTYPE_REGISTER_26 (BOOST_VMD_TYPE_NUMBER,26)
#define BOOST_VMD_SUBTYPE_REGISTER_27 (BOOST_VMD_TYPE_NUMBER,27)
#define BOOST_VMD_SUBTYPE_REGISTER_28 (BOOST_VMD_TYPE_NUMBER,28)
#define BOOST_VMD_SUBTYPE_REGISTER_29 (BOOST_VMD_TYPE_NUMBER,29)
#define BOOST_VMD_SUBTYPE_REGISTER_30 (BOOST_VMD_TYPE_NUMBER,30)
#define BOOST_VMD_SUBTYPE_REGISTER_31 (BOOST_VMD_TYPE_NUMBER,31)
#define BOOST_VMD_SUBTYPE_REGISTER_32 (BOOST_VMD_TYPE_NUMBER,32)
#define BOOST_VMD_SUBTYPE_REGISTER_33 (BOOST_VMD_TYPE_NUMBER,33)
#define BOOST_VMD_SUBTYPE_REGISTER_34 (BOOST_VMD_TYPE_NUMBER,34)
#define BOOST_VMD_SUBTYPE_REGISTER_35 (BOOST_VMD_TYPE_NUMBER,35)
#define BOOST_VMD_SUBTYPE_REGISTER_36 (BOOST_VMD_TYPE_NUMBER,36)
#define BOOST_VMD_SUBTYPE_REGISTER_37 (BOOST_VMD_TYPE_NUMBER,37)
#define BOOST_VMD_SUBTYPE_REGISTER_38 (BOOST_VMD_TYPE_NUMBER,38)
#define BOOST_VMD_SUBTYPE_REGISTER_39 (BOOST_VMD_TYPE_NUMBER,39)
#define BOOST_VMD_SUBTYPE_REGISTER_40 (BOOST_VMD_TYPE_NUMBER,40)
#define BOOST_VMD_SUBTYPE_REGISTER_41 (BOOST_VMD_TYPE_NUMBER,41)
#define BOOST_VMD_SUBTYPE_REGISTER_42 (BOOST_VMD_TYPE_NUMBER,42)
#define BOOST_VMD_SUBTYPE_REGISTER_43 (BOOST_VMD_TYPE_NUMBER,43)
#define BOOST_VMD_SUBTYPE_REGISTER_44 (BOOST_VMD_TYPE_NUMBER,44)
#define BOOST_VMD_SUBTYPE_REGISTER_45 (BOOST_VMD_TYPE_NUMBER,45)
#define BOOST_VMD_SUBTYPE_REGISTER_46 (BOOST_VMD_TYPE_NUMBER,46)
#define BOOST_VMD_SUBTYPE_REGISTER_47 (BOOST_VMD_TYPE_NUMBER,47)
#define BOOST_VMD_SUBTYPE_REGISTER_48 (BOOST_VMD_TYPE_NUMBER,48)
#define BOOST_VMD_SUBTYPE_REGISTER_49 (BOOST_VMD_TYPE_NUMBER,49)
#define BOOST_VMD_SUBTYPE_REGISTER_50 (BOOST_VMD_TYPE_NUMBER,50)
#define BOOST_VMD_SUBTYPE_REGISTER_51 (BOOST_VMD_TYPE_NUMBER,51)
#define BOOST_VMD_SUBTYPE_REGISTER_52 (BOOST_VMD_TYPE_NUMBER,52)
#define BOOST_VMD_SUBTYPE_REGISTER_53 (BOOST_VMD_TYPE_NUMBER,53)
#define BOOST_VMD_SUBTYPE_REGISTER_54 (BOOST_VMD_TYPE_NUMBER,54)
#define BOOST_VMD_SUBTYPE_REGISTER_55 (BOOST_VMD_TYPE_NUMBER,55)
#define BOOST_VMD_SUBTYPE_REGISTER_56 (BOOST_VMD_TYPE_NUMBER,56)
#define BOOST_VMD_SUBTYPE_REGISTER_57 (BOOST_VMD_TYPE_NUMBER,57)
#define BOOST_VMD_SUBTYPE_REGISTER_58 (BOOST_VMD_TYPE_NUMBER,58)
#define BOOST_VMD_SUBTYPE_REGISTER_59 (BOOST_VMD_TYPE_NUMBER,59)
#define BOOST_VMD_SUBTYPE_REGISTER_60 (BOOST_VMD_TYPE_NUMBER,60)
#define BOOST_VMD_SUBTYPE_REGISTER_61 (BOOST_VMD_TYPE_NUMBER,61)
#define BOOST_VMD_SUBTYPE_REGISTER_62 (BOOST_VMD_TYPE_NUMBER,62)
#define BOOST_VMD_SUBTYPE_REGISTER_63 (BOOST_VMD_TYPE_NUMBER,63)
#define BOOST_VMD_SUBTYPE_REGISTER_64 (BOOST_VMD_TYPE_NUMBER,64)
#define BOOST_VMD_SUBTYPE_REGISTER_65 (BOOST_VMD_TYPE_NUMBER,65)
#define BOOST_VMD_SUBTYPE_REGISTER_66 (BOOST_VMD_TYPE_NUMBER,66)
#define BOOST_VMD_SUBTYPE_REGISTER_67 (BOOST_VMD_TYPE_NUMBER,67)
#define BOOST_VMD_SUBTYPE_REGISTER_68 (BOOST_VMD_TYPE_NUMBER,68)
#define BOOST_VMD_SUBTYPE_REGISTER_69 (BOOST_VMD_TYPE_NUMBER,69)
#define BOOST_VMD_SUBTYPE_REGISTER_70 (BOOST_VMD_TYPE_NUMBER,70)
#define BOOST_VMD_SUBTYPE_REGISTER_71 (BOOST_VMD_TYPE_NUMBER,71)
#define BOOST_VMD_SUBTYPE_REGISTER_72 (BOOST_VMD_TYPE_NUMBER,72)
#define BOOST_VMD_SUBTYPE_REGISTER_73 (BOOST_VMD_TYPE_NUMBER,73)
#define BOOST_VMD_SUBTYPE_REGISTER_74 (BOOST_VMD_TYPE_NUMBER,74)
#define BOOST_VMD_SUBTYPE_REGISTER_75 (BOOST_VMD_TYPE_NUMBER,75)
#define BOOST_VMD_SUBTYPE_REGISTER_76 (BOOST_VMD_TYPE_NUMBER,76)
#define BOOST_VMD_SUBTYPE_REGISTER_77 (BOOST_VMD_TYPE_NUMBER,77)
#define BOOST_VMD_SUBTYPE_REGISTER_78 (BOOST_VMD_TYPE_NUMBER,78)
#define BOOST_VMD_SUBTYPE_REGISTER_79 (BOOST_VMD_TYPE_NUMBER,79)
#define BOOST_VMD_SUBTYPE_REGISTER_80 (BOOST_VMD_TYPE_NUMBER,80)
#define BOOST_VMD_SUBTYPE_REGISTER_81 (BOOST_VMD_TYPE_NUMBER,81)
#define BOOST_VMD_SUBTYPE_REGISTER_82 (BOOST_VMD_TYPE_NUMBER,82)
#define BOOST_VMD_SUBTYPE_REGISTER_83 (BOOST_VMD_TYPE_NUMBER,83)
#define BOOST_VMD_SUBTYPE_REGISTER_84 (BOOST_VMD_TYPE_NUMBER,84)
#define BOOST_VMD_SUBTYPE_REGISTER_85 (BOOST_VMD_TYPE_NUMBER,85)
#define BOOST_VMD_SUBTYPE_REGISTER_86 (BOOST_VMD_TYPE_NUMBER,86)
#define BOOST_VMD_SUBTYPE_REGISTER_87 (BOOST_VMD_TYPE_NUMBER,87)
#define BOOST_VMD_SUBTYPE_REGISTER_88 (BOOST_VMD_TYPE_NUMBER,88)
#define BOOST_VMD_SUBTYPE_REGISTER_89 (BOOST_VMD_TYPE_NUMBER,89)
#define BOOST_VMD_SUBTYPE_REGISTER_90 (BOOST_VMD_TYPE_NUMBER,90)
#define BOOST_VMD_SUBTYPE_REGISTER_91 (BOOST_VMD_TYPE_NUMBER,91)
#define BOOST_VMD_SUBTYPE_REGISTER_92 (BOOST_VMD_TYPE_NUMBER,92)
#define BOOST_VMD_SUBTYPE_REGISTER_93 (BOOST_VMD_TYPE_NUMBER,93)
#define BOOST_VMD_SUBTYPE_REGISTER_94 (BOOST_VMD_TYPE_NUMBER,94)
#define BOOST_VMD_SUBTYPE_REGISTER_95 (BOOST_VMD_TYPE_NUMBER,95)
#define BOOST_VMD_SUBTYPE_REGISTER_96 (BOOST_VMD_TYPE_NUMBER,96)
#define BOOST_VMD_SUBTYPE_REGISTER_97 (BOOST_VMD_TYPE_NUMBER,97)
#define BOOST_VMD_SUBTYPE_REGISTER_98 (BOOST_VMD_TYPE_NUMBER,98)
#define BOOST_VMD_SUBTYPE_REGISTER_99 (BOOST_VMD_TYPE_NUMBER,99)
#define BOOST_VMD_SUBTYPE_REGISTER_100 (BOOST_VMD_TYPE_NUMBER,100)
#define BOOST_VMD_SUBTYPE_REGISTER_101 (BOOST_VMD_TYPE_NUMBER,101)
#define BOOST_VMD_SUBTYPE_REGISTER_102 (BOOST_VMD_TYPE_NUMBER,102)
#define BOOST_VMD_SUBTYPE_REGISTER_103 (BOOST_VMD_TYPE_NUMBER,103)
#define BOOST_VMD_SUBTYPE_REGISTER_104 (BOOST_VMD_TYPE_NUMBER,104)
#define BOOST_VMD_SUBTYPE_REGISTER_105 (BOOST_VMD_TYPE_NUMBER,105)
#define BOOST_VMD_SUBTYPE_REGISTER_106 (BOOST_VMD_TYPE_NUMBER,106)
#define BOOST_VMD_SUBTYPE_REGISTER_107 (BOOST_VMD_TYPE_NUMBER,107)
#define BOOST_VMD_SUBTYPE_REGISTER_108 (BOOST_VMD_TYPE_NUMBER,108)
#define BOOST_VMD_SUBTYPE_REGISTER_109 (BOOST_VMD_TYPE_NUMBER,109)
#define BOOST_VMD_SUBTYPE_REGISTER_110 (BOOST_VMD_TYPE_NUMBER,110)
#define BOOST_VMD_SUBTYPE_REGISTER_111 (BOOST_VMD_TYPE_NUMBER,111)
#define BOOST_VMD_SUBTYPE_REGISTER_112 (BOOST_VMD_TYPE_NUMBER,112)
#define BOOST_VMD_SUBTYPE_REGISTER_113 (BOOST_VMD_TYPE_NUMBER,113)
#define BOOST_VMD_SUBTYPE_REGISTER_114 (BOOST_VMD_TYPE_NUMBER,114)
#define BOOST_VMD_SUBTYPE_REGISTER_115 (BOOST_VMD_TYPE_NUMBER,115)
#define BOOST_VMD_SUBTYPE_REGISTER_116 (BOOST_VMD_TYPE_NUMBER,116)
#define BOOST_VMD_SUBTYPE_REGISTER_117 (BOOST_VMD_TYPE_NUMBER,117)
#define BOOST_VMD_SUBTYPE_REGISTER_118 (BOOST_VMD_TYPE_NUMBER,118)
#define BOOST_VMD_SUBTYPE_REGISTER_119 (BOOST_VMD_TYPE_NUMBER,119)
#define BOOST_VMD_SUBTYPE_REGISTER_120 (BOOST_VMD_TYPE_NUMBER,120)
#define BOOST_VMD_SUBTYPE_REGISTER_121 (BOOST_VMD_TYPE_NUMBER,121)
#define BOOST_VMD_SUBTYPE_REGISTER_122 (BOOST_VMD_TYPE_NUMBER,122)
#define BOOST_VMD_SUBTYPE_REGISTER_123 (BOOST_VMD_TYPE_NUMBER,123)
#define BOOST_VMD_SUBTYPE_REGISTER_124 (BOOST_VMD_TYPE_NUMBER,124)
#define BOOST_VMD_SUBTYPE_REGISTER_125 (BOOST_VMD_TYPE_NUMBER,125)
#define BOOST_VMD_SUBTYPE_REGISTER_126 (BOOST_VMD_TYPE_NUMBER,126)
#define BOOST_VMD_SUBTYPE_REGISTER_127 (BOOST_VMD_TYPE_NUMBER,127)
#define BOOST_VMD_SUBTYPE_REGISTER_128 (BOOST_VMD_TYPE_NUMBER,128)
#define BOOST_VMD_SUBTYPE_REGISTER_129 (BOOST_VMD_TYPE_NUMBER,129)
#define BOOST_VMD_SUBTYPE_REGISTER_130 (BOOST_VMD_TYPE_NUMBER,130)
#define BOOST_VMD_SUBTYPE_REGISTER_131 (BOOST_VMD_TYPE_NUMBER,131)
#define BOOST_VMD_SUBTYPE_REGISTER_132 (BOOST_VMD_TYPE_NUMBER,132)
#define BOOST_VMD_SUBTYPE_REGISTER_133 (BOOST_VMD_TYPE_NUMBER,133)
#define BOOST_VMD_SUBTYPE_REGISTER_134 (BOOST_VMD_TYPE_NUMBER,134)
#define BOOST_VMD_SUBTYPE_REGISTER_135 (BOOST_VMD_TYPE_NUMBER,135)
#define BOOST_VMD_SUBTYPE_REGISTER_136 (BOOST_VMD_TYPE_NUMBER,136)
#define BOOST_VMD_SUBTYPE_REGISTER_137 (BOOST_VMD_TYPE_NUMBER,137)
#define BOOST_VMD_SUBTYPE_REGISTER_138 (BOOST_VMD_TYPE_NUMBER,138)
#define BOOST_VMD_SUBTYPE_REGISTER_139 (BOOST_VMD_TYPE_NUMBER,139)
#define BOOST_VMD_SUBTYPE_REGISTER_140 (BOOST_VMD_TYPE_NUMBER,140)
#define BOOST_VMD_SUBTYPE_REGISTER_141 (BOOST_VMD_TYPE_NUMBER,141)
#define BOOST_VMD_SUBTYPE_REGISTER_142 (BOOST_VMD_TYPE_NUMBER,142)
#define BOOST_VMD_SUBTYPE_REGISTER_143 (BOOST_VMD_TYPE_NUMBER,143)
#define BOOST_VMD_SUBTYPE_REGISTER_144 (BOOST_VMD_TYPE_NUMBER,144)
#define BOOST_VMD_SUBTYPE_REGISTER_145 (BOOST_VMD_TYPE_NUMBER,145)
#define BOOST_VMD_SUBTYPE_REGISTER_146 (BOOST_VMD_TYPE_NUMBER,146)
#define BOOST_VMD_SUBTYPE_REGISTER_147 (BOOST_VMD_TYPE_NUMBER,147)
#define BOOST_VMD_SUBTYPE_REGISTER_148 (BOOST_VMD_TYPE_NUMBER,148)
#define BOOST_VMD_SUBTYPE_REGISTER_149 (BOOST_VMD_TYPE_NUMBER,149)
#define BOOST_VMD_SUBTYPE_REGISTER_150 (BOOST_VMD_TYPE_NUMBER,150)
#define BOOST_VMD_SUBTYPE_REGISTER_151 (BOOST_VMD_TYPE_NUMBER,151)
#define BOOST_VMD_SUBTYPE_REGISTER_152 (BOOST_VMD_TYPE_NUMBER,152)
#define BOOST_VMD_SUBTYPE_REGISTER_153 (BOOST_VMD_TYPE_NUMBER,153)
#define BOOST_VMD_SUBTYPE_REGISTER_154 (BOOST_VMD_TYPE_NUMBER,154)
#define BOOST_VMD_SUBTYPE_REGISTER_155 (BOOST_VMD_TYPE_NUMBER,155)
#define BOOST_VMD_SUBTYPE_REGISTER_156 (BOOST_VMD_TYPE_NUMBER,156)
#define BOOST_VMD_SUBTYPE_REGISTER_157 (BOOST_VMD_TYPE_NUMBER,157)
#define BOOST_VMD_SUBTYPE_REGISTER_158 (BOOST_VMD_TYPE_NUMBER,158)
#define BOOST_VMD_SUBTYPE_REGISTER_159 (BOOST_VMD_TYPE_NUMBER,159)
#define BOOST_VMD_SUBTYPE_REGISTER_160 (BOOST_VMD_TYPE_NUMBER,160)
#define BOOST_VMD_SUBTYPE_REGISTER_161 (BOOST_VMD_TYPE_NUMBER,161)
#define BOOST_VMD_SUBTYPE_REGISTER_162 (BOOST_VMD_TYPE_NUMBER,162)
#define BOOST_VMD_SUBTYPE_REGISTER_163 (BOOST_VMD_TYPE_NUMBER,163)
#define BOOST_VMD_SUBTYPE_REGISTER_164 (BOOST_VMD_TYPE_NUMBER,164)
#define BOOST_VMD_SUBTYPE_REGISTER_165 (BOOST_VMD_TYPE_NUMBER,165)
#define BOOST_VMD_SUBTYPE_REGISTER_166 (BOOST_VMD_TYPE_NUMBER,166)
#define BOOST_VMD_SUBTYPE_REGISTER_167 (BOOST_VMD_TYPE_NUMBER,167)
#define BOOST_VMD_SUBTYPE_REGISTER_168 (BOOST_VMD_TYPE_NUMBER,168)
#define BOOST_VMD_SUBTYPE_REGISTER_169 (BOOST_VMD_TYPE_NUMBER,169)
#define BOOST_VMD_SUBTYPE_REGISTER_170 (BOOST_VMD_TYPE_NUMBER,170)
#define BOOST_VMD_SUBTYPE_REGISTER_171 (BOOST_VMD_TYPE_NUMBER,171)
#define BOOST_VMD_SUBTYPE_REGISTER_172 (BOOST_VMD_TYPE_NUMBER,172)
#define BOOST_VMD_SUBTYPE_REGISTER_173 (BOOST_VMD_TYPE_NUMBER,173)
#define BOOST_VMD_SUBTYPE_REGISTER_174 (BOOST_VMD_TYPE_NUMBER,174)
#define BOOST_VMD_SUBTYPE_REGISTER_175 (BOOST_VMD_TYPE_NUMBER,175)
#define BOOST_VMD_SUBTYPE_REGISTER_176 (BOOST_VMD_TYPE_NUMBER,176)
#define BOOST_VMD_SUBTYPE_REGISTER_177 (BOOST_VMD_TYPE_NUMBER,177)
#define BOOST_VMD_SUBTYPE_REGISTER_178 (BOOST_VMD_TYPE_NUMBER,178)
#define BOOST_VMD_SUBTYPE_REGISTER_179 (BOOST_VMD_TYPE_NUMBER,179)
#define BOOST_VMD_SUBTYPE_REGISTER_180 (BOOST_VMD_TYPE_NUMBER,180)
#define BOOST_VMD_SUBTYPE_REGISTER_181 (BOOST_VMD_TYPE_NUMBER,181)
#define BOOST_VMD_SUBTYPE_REGISTER_182 (BOOST_VMD_TYPE_NUMBER,182)
#define BOOST_VMD_SUBTYPE_REGISTER_183 (BOOST_VMD_TYPE_NUMBER,183)
#define BOOST_VMD_SUBTYPE_REGISTER_184 (BOOST_VMD_TYPE_NUMBER,184)
#define BOOST_VMD_SUBTYPE_REGISTER_185 (BOOST_VMD_TYPE_NUMBER,185)
#define BOOST_VMD_SUBTYPE_REGISTER_186 (BOOST_VMD_TYPE_NUMBER,186)
#define BOOST_VMD_SUBTYPE_REGISTER_187 (BOOST_VMD_TYPE_NUMBER,187)
#define BOOST_VMD_SUBTYPE_REGISTER_188 (BOOST_VMD_TYPE_NUMBER,188)
#define BOOST_VMD_SUBTYPE_REGISTER_189 (BOOST_VMD_TYPE_NUMBER,189)
#define BOOST_VMD_SUBTYPE_REGISTER_190 (BOOST_VMD_TYPE_NUMBER,190)
#define BOOST_VMD_SUBTYPE_REGISTER_191 (BOOST_VMD_TYPE_NUMBER,191)
#define BOOST_VMD_SUBTYPE_REGISTER_192 (BOOST_VMD_TYPE_NUMBER,192)
#define BOOST_VMD_SUBTYPE_REGISTER_193 (BOOST_VMD_TYPE_NUMBER,193)
#define BOOST_VMD_SUBTYPE_REGISTER_194 (BOOST_VMD_TYPE_NUMBER,194)
#define BOOST_VMD_SUBTYPE_REGISTER_195 (BOOST_VMD_TYPE_NUMBER,195)
#define BOOST_VMD_SUBTYPE_REGISTER_196 (BOOST_VMD_TYPE_NUMBER,196)
#define BOOST_VMD_SUBTYPE_REGISTER_197 (BOOST_VMD_TYPE_NUMBER,197)
#define BOOST_VMD_SUBTYPE_REGISTER_198 (BOOST_VMD_TYPE_NUMBER,198)
#define BOOST_VMD_SUBTYPE_REGISTER_199 (BOOST_VMD_TYPE_NUMBER,199)
#define BOOST_VMD_SUBTYPE_REGISTER_200 (BOOST_VMD_TYPE_NUMBER,200)
#define BOOST_VMD_SUBTYPE_REGISTER_201 (BOOST_VMD_TYPE_NUMBER,201)
#define BOOST_VMD_SUBTYPE_REGISTER_202 (BOOST_VMD_TYPE_NUMBER,202)
#define BOOST_VMD_SUBTYPE_REGISTER_203 (BOOST_VMD_TYPE_NUMBER,203)
#define BOOST_VMD_SUBTYPE_REGISTER_204 (BOOST_VMD_TYPE_NUMBER,204)
#define BOOST_VMD_SUBTYPE_REGISTER_205 (BOOST_VMD_TYPE_NUMBER,205)
#define BOOST_VMD_SUBTYPE_REGISTER_206 (BOOST_VMD_TYPE_NUMBER,206)
#define BOOST_VMD_SUBTYPE_REGISTER_207 (BOOST_VMD_TYPE_NUMBER,207)
#define BOOST_VMD_SUBTYPE_REGISTER_208 (BOOST_VMD_TYPE_NUMBER,208)
#define BOOST_VMD_SUBTYPE_REGISTER_209 (BOOST_VMD_TYPE_NUMBER,209)
#define BOOST_VMD_SUBTYPE_REGISTER_210 (BOOST_VMD_TYPE_NUMBER,210)
#define BOOST_VMD_SUBTYPE_REGISTER_211 (BOOST_VMD_TYPE_NUMBER,211)
#define BOOST_VMD_SUBTYPE_REGISTER_212 (BOOST_VMD_TYPE_NUMBER,212)
#define BOOST_VMD_SUBTYPE_REGISTER_213 (BOOST_VMD_TYPE_NUMBER,213)
#define BOOST_VMD_SUBTYPE_REGISTER_214 (BOOST_VMD_TYPE_NUMBER,214)
#define BOOST_VMD_SUBTYPE_REGISTER_215 (BOOST_VMD_TYPE_NUMBER,215)
#define BOOST_VMD_SUBTYPE_REGISTER_216 (BOOST_VMD_TYPE_NUMBER,216)
#define BOOST_VMD_SUBTYPE_REGISTER_217 (BOOST_VMD_TYPE_NUMBER,217)
#define BOOST_VMD_SUBTYPE_REGISTER_218 (BOOST_VMD_TYPE_NUMBER,218)
#define BOOST_VMD_SUBTYPE_REGISTER_219 (BOOST_VMD_TYPE_NUMBER,219)
#define BOOST_VMD_SUBTYPE_REGISTER_220 (BOOST_VMD_TYPE_NUMBER,220)
#define BOOST_VMD_SUBTYPE_REGISTER_221 (BOOST_VMD_TYPE_NUMBER,221)
#define BOOST_VMD_SUBTYPE_REGISTER_222 (BOOST_VMD_TYPE_NUMBER,222)
#define BOOST_VMD_SUBTYPE_REGISTER_223 (BOOST_VMD_TYPE_NUMBER,223)
#define BOOST_VMD_SUBTYPE_REGISTER_224 (BOOST_VMD_TYPE_NUMBER,224)
#define BOOST_VMD_SUBTYPE_REGISTER_225 (BOOST_VMD_TYPE_NUMBER,225)
#define BOOST_VMD_SUBTYPE_REGISTER_226 (BOOST_VMD_TYPE_NUMBER,226)
#define BOOST_VMD_SUBTYPE_REGISTER_227 (BOOST_VMD_TYPE_NUMBER,227)
#define BOOST_VMD_SUBTYPE_REGISTER_228 (BOOST_VMD_TYPE_NUMBER,228)
#define BOOST_VMD_SUBTYPE_REGISTER_229 (BOOST_VMD_TYPE_NUMBER,229)
#define BOOST_VMD_SUBTYPE_REGISTER_230 (BOOST_VMD_TYPE_NUMBER,230)
#define BOOST_VMD_SUBTYPE_REGISTER_231 (BOOST_VMD_TYPE_NUMBER,231)
#define BOOST_VMD_SUBTYPE_REGISTER_232 (BOOST_VMD_TYPE_NUMBER,232)
#define BOOST_VMD_SUBTYPE_REGISTER_233 (BOOST_VMD_TYPE_NUMBER,233)
#define BOOST_VMD_SUBTYPE_REGISTER_234 (BOOST_VMD_TYPE_NUMBER,234)
#define BOOST_VMD_SUBTYPE_REGISTER_235 (BOOST_VMD_TYPE_NUMBER,235)
#define BOOST_VMD_SUBTYPE_REGISTER_236 (BOOST_VMD_TYPE_NUMBER,236)
#define BOOST_VMD_SUBTYPE_REGISTER_237 (BOOST_VMD_TYPE_NUMBER,237)
#define BOOST_VMD_SUBTYPE_REGISTER_238 (BOOST_VMD_TYPE_NUMBER,238)
#define BOOST_VMD_SUBTYPE_REGISTER_239 (BOOST_VMD_TYPE_NUMBER,239)
#define BOOST_VMD_SUBTYPE_REGISTER_240 (BOOST_VMD_TYPE_NUMBER,240)
#define BOOST_VMD_SUBTYPE_REGISTER_241 (BOOST_VMD_TYPE_NUMBER,241)
#define BOOST_VMD_SUBTYPE_REGISTER_242 (BOOST_VMD_TYPE_NUMBER,242)
#define BOOST_VMD_SUBTYPE_REGISTER_243 (BOOST_VMD_TYPE_NUMBER,243)
#define BOOST_VMD_SUBTYPE_REGISTER_244 (BOOST_VMD_TYPE_NUMBER,244)
#define BOOST_VMD_SUBTYPE_REGISTER_245 (BOOST_VMD_TYPE_NUMBER,245)
#define BOOST_VMD_SUBTYPE_REGISTER_246 (BOOST_VMD_TYPE_NUMBER,246)
#define BOOST_VMD_SUBTYPE_REGISTER_247 (BOOST_VMD_TYPE_NUMBER,247)
#define BOOST_VMD_SUBTYPE_REGISTER_248 (BOOST_VMD_TYPE_NUMBER,248)
#define BOOST_VMD_SUBTYPE_REGISTER_249 (BOOST_VMD_TYPE_NUMBER,249)
#define BOOST_VMD_SUBTYPE_REGISTER_250 (BOOST_VMD_TYPE_NUMBER,250)
#define BOOST_VMD_SUBTYPE_REGISTER_251 (BOOST_VMD_TYPE_NUMBER,251)
#define BOOST_VMD_SUBTYPE_REGISTER_252 (BOOST_VMD_TYPE_NUMBER,252)
#define BOOST_VMD_SUBTYPE_REGISTER_253 (BOOST_VMD_TYPE_NUMBER,253)
#define BOOST_VMD_SUBTYPE_REGISTER_254 (BOOST_VMD_TYPE_NUMBER,254)
#define BOOST_VMD_SUBTYPE_REGISTER_255 (BOOST_VMD_TYPE_NUMBER,255)
#define BOOST_VMD_SUBTYPE_REGISTER_256 (BOOST_VMD_TYPE_NUMBER,256)

#if BOOST_PP_LIMIT_MAG > 256

#define BOOST_VMD_SUBTYPE_REGISTER_257 (BOOST_VMD_TYPE_NUMBER,257)
#define BOOST_VMD_SUBTYPE_REGISTER_258 (BOOST_VMD_TYPE_NUMBER,258)
#define BOOST_VMD_SUBTYPE_REGISTER_259 (BOOST_VMD_TYPE_NUMBER,259)
#define BOOST_VMD_SUBTYPE_REGISTER_260 (BOOST_VMD_TYPE_NUMBER,260)
#define BOOST_VMD_SUBTYPE_REGISTER_261 (BOOST_VMD_TYPE_NUMBER,261)
#define BOOST_VMD_SUBTYPE_REGISTER_262 (BOOST_VMD_TYPE_NUMBER,262)
#define BOOST_VMD_SUBTYPE_REGISTER_263 (BOOST_VMD_TYPE_NUMBER,263)
#define BOOST_VMD_SUBTYPE_REGISTER_264 (BOOST_VMD_TYPE_NUMBER,264)
#define BOOST_VMD_SUBTYPE_REGISTER_265 (BOOST_VMD_TYPE_NUMBER,265)
#define BOOST_VMD_SUBTYPE_REGISTER_266 (BOOST_VMD_TYPE_NUMBER,266)
#define BOOST_VMD_SUBTYPE_REGISTER_267 (BOOST_VMD_TYPE_NUMBER,267)
#define BOOST_VMD_SUBTYPE_REGISTER_268 (BOOST_VMD_TYPE_NUMBER,268)
#define BOOST_VMD_SUBTYPE_REGISTER_269 (BOOST_VMD_TYPE_NUMBER,269)
#define BOOST_VMD_SUBTYPE_REGISTER_270 (BOOST_VMD_TYPE_NUMBER,270)
#define BOOST_VMD_SUBTYPE_REGISTER_271 (BOOST_VMD_TYPE_NUMBER,271)
#define BOOST_VMD_SUBTYPE_REGISTER_272 (BOOST_VMD_TYPE_NUMBER,272)
#define BOOST_VMD_SUBTYPE_REGISTER_273 (BOOST_VMD_TYPE_NUMBER,273)
#define BOOST_VMD_SUBTYPE_REGISTER_274 (BOOST_VMD_TYPE_NUMBER,274)
#define BOOST_VMD_SUBTYPE_REGISTER_275 (BOOST_VMD_TYPE_NUMBER,275)
#define BOOST_VMD_SUBTYPE_REGISTER_276 (BOOST_VMD_TYPE_NUMBER,276)
#define BOOST_VMD_SUBTYPE_REGISTER_277 (BOOST_VMD_TYPE_NUMBER,277)
#define BOOST_VMD_SUBTYPE_REGISTER_278 (BOOST_VMD_TYPE_NUMBER,278)
#define BOOST_VMD_SUBTYPE_REGISTER_279 (BOOST_VMD_TYPE_NUMBER,279)
#define BOOST_VMD_SUBTYPE_REGISTER_280 (BOOST_VMD_TYPE_NUMBER,280)
#define BOOST_VMD_SUBTYPE_REGISTER_281 (BOOST_VMD_TYPE_NUMBER,281)
#define BOOST_VMD_SUBTYPE_REGISTER_282 (BOOST_VMD_TYPE_NUMBER,282)
#define BOOST_VMD_SUBTYPE_REGISTER_283 (BOOST_VMD_TYPE_NUMBER,283)
#define BOOST_VMD_SUBTYPE_REGISTER_284 (BOOST_VMD_TYPE_NUMBER,284)
#define BOOST_VMD_SUBTYPE_REGISTER_285 (BOOST_VMD_TYPE_NUMBER,285)
#define BOOST_VMD_SUBTYPE_REGISTER_286 (BOOST_VMD_TYPE_NUMBER,286)
#define BOOST_VMD_SUBTYPE_REGISTER_287 (BOOST_VMD_TYPE_NUMBER,287)
#define BOOST_VMD_SUBTYPE_REGISTER_288 (BOOST_VMD_TYPE_NUMBER,288)
#define BOOST_VMD_SUBTYPE_REGISTER_289 (BOOST_VMD_TYPE_NUMBER,289)
#define BOOST_VMD_SUBTYPE_REGISTER_290 (BOOST_VMD_TYPE_NUMBER,290)
#define BOOST_VMD_SUBTYPE_REGISTER_291 (BOOST_VMD_TYPE_NUMBER,291)
#define BOOST_VMD_SUBTYPE_REGISTER_292 (BOOST_VMD_TYPE_NUMBER,292)
#define BOOST_VMD_SUBTYPE_REGISTER_293 (BOOST_VMD_TYPE_NUMBER,293)
#define BOOST_VMD_SUBTYPE_REGISTER_294 (BOOST_VMD_TYPE_NUMBER,294)
#define BOOST_VMD_SUBTYPE_REGISTER_295 (BOOST_VMD_TYPE_NUMBER,295)
#define BOOST_VMD_SUBTYPE_REGISTER_296 (BOOST_VMD_TYPE_NUMBER,296)
#define BOOST_VMD_SUBTYPE_REGISTER_297 (BOOST_VMD_TYPE_NUMBER,297)
#define BOOST_VMD_SUBTYPE_REGISTER_298 (BOOST_VMD_TYPE_NUMBER,298)
#define BOOST_VMD_SUBTYPE_REGISTER_299 (BOOST_VMD_TYPE_NUMBER,299)
#define BOOST_VMD_SUBTYPE_REGISTER_300 (BOOST_VMD_TYPE_NUMBER,300)
#define BOOST_VMD_SUBTYPE_REGISTER_301 (BOOST_VMD_TYPE_NUMBER,301)
#define BOOST_VMD_SUBTYPE_REGISTER_302 (BOOST_VMD_TYPE_NUMBER,302)
#define BOOST_VMD_SUBTYPE_REGISTER_303 (BOOST_VMD_TYPE_NUMBER,303)
#define BOOST_VMD_SUBTYPE_REGISTER_304 (BOOST_VMD_TYPE_NUMBER,304)
#define BOOST_VMD_SUBTYPE_REGISTER_305 (BOOST_VMD_TYPE_NUMBER,305)
#define BOOST_VMD_SUBTYPE_REGISTER_306 (BOOST_VMD_TYPE_NUMBER,306)
#define BOOST_VMD_SUBTYPE_REGISTER_307 (BOOST_VMD_TYPE_NUMBER,307)
#define BOOST_VMD_SUBTYPE_REGISTER_308 (BOOST_VMD_TYPE_NUMBER,308)
#define BOOST_VMD_SUBTYPE_REGISTER_309 (BOOST_VMD_TYPE_NUMBER,309)
#define BOOST_VMD_SUBTYPE_REGISTER_310 (BOOST_VMD_TYPE_NUMBER,310)
#define BOOST_VMD_SUBTYPE_REGISTER_311 (BOOST_VMD_TYPE_NUMBER,311)
#define BOOST_VMD_SUBTYPE_REGISTER_312 (BOOST_VMD_TYPE_NUMBER,312)
#define BOOST_VMD_SUBTYPE_REGISTER_313 (BOOST_VMD_TYPE_NUMBER,313)
#define BOOST_VMD_SUBTYPE_REGISTER_314 (BOOST_VMD_TYPE_NUMBER,314)
#define BOOST_VMD_SUBTYPE_REGISTER_315 (BOOST_VMD_TYPE_NUMBER,315)
#define BOOST_VMD_SUBTYPE_REGISTER_316 (BOOST_VMD_TYPE_NUMBER,316)
#define BOOST_VMD_SUBTYPE_REGISTER_317 (BOOST_VMD_TYPE_NUMBER,317)
#define BOOST_VMD_SUBTYPE_REGISTER_318 (BOOST_VMD_TYPE_NUMBER,318)
#define BOOST_VMD_SUBTYPE_REGISTER_319 (BOOST_VMD_TYPE_NUMBER,319)
#define BOOST_VMD_SUBTYPE_REGISTER_320 (BOOST_VMD_TYPE_NUMBER,320)
#define BOOST_VMD_SUBTYPE_REGISTER_321 (BOOST_VMD_TYPE_NUMBER,321)
#define BOOST_VMD_SUBTYPE_REGISTER_322 (BOOST_VMD_TYPE_NUMBER,322)
#define BOOST_VMD_SUBTYPE_REGISTER_323 (BOOST_VMD_TYPE_NUMBER,323)
#define BOOST_VMD_SUBTYPE_REGISTER_324 (BOOST_VMD_TYPE_NUMBER,324)
#define BOOST_VMD_SUBTYPE_REGISTER_325 (BOOST_VMD_TYPE_NUMBER,325)
#define BOOST_VMD_SUBTYPE_REGISTER_326 (BOOST_VMD_TYPE_NUMBER,326)
#define BOOST_VMD_SUBTYPE_REGISTER_327 (BOOST_VMD_TYPE_NUMBER,327)
#define BOOST_VMD_SUBTYPE_REGISTER_328 (BOOST_VMD_TYPE_NUMBER,328)
#define BOOST_VMD_SUBTYPE_REGISTER_329 (BOOST_VMD_TYPE_NUMBER,329)
#define BOOST_VMD_SUBTYPE_REGISTER_330 (BOOST_VMD_TYPE_NUMBER,330)
#define BOOST_VMD_SUBTYPE_REGISTER_331 (BOOST_VMD_TYPE_NUMBER,331)
#define BOOST_VMD_SUBTYPE_REGISTER_332 (BOOST_VMD_TYPE_NUMBER,332)
#define BOOST_VMD_SUBTYPE_REGISTER_333 (BOOST_VMD_TYPE_NUMBER,333)
#define BOOST_VMD_SUBTYPE_REGISTER_334 (BOOST_VMD_TYPE_NUMBER,334)
#define BOOST_VMD_SUBTYPE_REGISTER_335 (BOOST_VMD_TYPE_NUMBER,335)
#define BOOST_VMD_SUBTYPE_REGISTER_336 (BOOST_VMD_TYPE_NUMBER,336)
#define BOOST_VMD_SUBTYPE_REGISTER_337 (BOOST_VMD_TYPE_NUMBER,337)
#define BOOST_VMD_SUBTYPE_REGISTER_338 (BOOST_VMD_TYPE_NUMBER,338)
#define BOOST_VMD_SUBTYPE_REGISTER_339 (BOOST_VMD_TYPE_NUMBER,339)
#define BOOST_VMD_SUBTYPE_REGISTER_340 (BOOST_VMD_TYPE_NUMBER,340)
#define BOOST_VMD_SUBTYPE_REGISTER_341 (BOOST_VMD_TYPE_NUMBER,341)
#define BOOST_VMD_SUBTYPE_REGISTER_342 (BOOST_VMD_TYPE_NUMBER,342)
#define BOOST_VMD_SUBTYPE_REGISTER_343 (BOOST_VMD_TYPE_NUMBER,343)
#define BOOST_VMD_SUBTYPE_REGISTER_344 (BOOST_VMD_TYPE_NUMBER,344)
#define BOOST_VMD_SUBTYPE_REGISTER_345 (BOOST_VMD_TYPE_NUMBER,345)
#define BOOST_VMD_SUBTYPE_REGISTER_346 (BOOST_VMD_TYPE_NUMBER,346)
#define BOOST_VMD_SUBTYPE_REGISTER_347 (BOOST_VMD_TYPE_NUMBER,347)
#define BOOST_VMD_SUBTYPE_REGISTER_348 (BOOST_VMD_TYPE_NUMBER,348)
#define BOOST_VMD_SUBTYPE_REGISTER_349 (BOOST_VMD_TYPE_NUMBER,349)
#define BOOST_VMD_SUBTYPE_REGISTER_350 (BOOST_VMD_TYPE_NUMBER,350)
#define BOOST_VMD_SUBTYPE_REGISTER_351 (BOOST_VMD_TYPE_NUMBER,351)
#define BOOST_VMD_SUBTYPE_REGISTER_352 (BOOST_VMD_TYPE_NUMBER,352)
#define BOOST_VMD_SUBTYPE_REGISTER_353 (BOOST_VMD_TYPE_NUMBER,353)
#define BOOST_VMD_SUBTYPE_REGISTER_354 (BOOST_VMD_TYPE_NUMBER,354)
#define BOOST_VMD_SUBTYPE_REGISTER_355 (BOOST_VMD_TYPE_NUMBER,355)
#define BOOST_VMD_SUBTYPE_REGISTER_356 (BOOST_VMD_TYPE_NUMBER,356)
#define BOOST_VMD_SUBTYPE_REGISTER_357 (BOOST_VMD_TYPE_NUMBER,357)
#define BOOST_VMD_SUBTYPE_REGISTER_358 (BOOST_VMD_TYPE_NUMBER,358)
#define BOOST_VMD_SUBTYPE_REGISTER_359 (BOOST_VMD_TYPE_NUMBER,359)
#define BOOST_VMD_SUBTYPE_REGISTER_360 (BOOST_VMD_TYPE_NUMBER,360)
#define BOOST_VMD_SUBTYPE_REGISTER_361 (BOOST_VMD_TYPE_NUMBER,361)
#define BOOST_VMD_SUBTYPE_REGISTER_362 (BOOST_VMD_TYPE_NUMBER,362)
#define BOOST_VMD_SUBTYPE_REGISTER_363 (BOOST_VMD_TYPE_NUMBER,363)
#define BOOST_VMD_SUBTYPE_REGISTER_364 (BOOST_VMD_TYPE_NUMBER,364)
#define BOOST_VMD_SUBTYPE_REGISTER_365 (BOOST_VMD_TYPE_NUMBER,365)
#define BOOST_VMD_SUBTYPE_REGISTER_366 (BOOST_VMD_TYPE_NUMBER,366)
#define BOOST_VMD_SUBTYPE_REGISTER_367 (BOOST_VMD_TYPE_NUMBER,367)
#define BOOST_VMD_SUBTYPE_REGISTER_368 (BOOST_VMD_TYPE_NUMBER,368)
#define BOOST_VMD_SUBTYPE_REGISTER_369 (BOOST_VMD_TYPE_NUMBER,369)
#define BOOST_VMD_SUBTYPE_REGISTER_370 (BOOST_VMD_TYPE_NUMBER,370)
#define BOOST_VMD_SUBTYPE_REGISTER_371 (BOOST_VMD_TYPE_NUMBER,371)
#define BOOST_VMD_SUBTYPE_REGISTER_372 (BOOST_VMD_TYPE_NUMBER,372)
#define BOOST_VMD_SUBTYPE_REGISTER_373 (BOOST_VMD_TYPE_NUMBER,373)
#define BOOST_VMD_SUBTYPE_REGISTER_374 (BOOST_VMD_TYPE_NUMBER,374)
#define BOOST_VMD_SUBTYPE_REGISTER_375 (BOOST_VMD_TYPE_NUMBER,375)
#define BOOST_VMD_SUBTYPE_REGISTER_376 (BOOST_VMD_TYPE_NUMBER,376)
#define BOOST_VMD_SUBTYPE_REGISTER_377 (BOOST_VMD_TYPE_NUMBER,377)
#define BOOST_VMD_SUBTYPE_REGISTER_378 (BOOST_VMD_TYPE_NUMBER,378)
#define BOOST_VMD_SUBTYPE_REGISTER_379 (BOOST_VMD_TYPE_NUMBER,379)
#define BOOST_VMD_SUBTYPE_REGISTER_380 (BOOST_VMD_TYPE_NUMBER,380)
#define BOOST_VMD_SUBTYPE_REGISTER_381 (BOOST_VMD_TYPE_NUMBER,381)
#define BOOST_VMD_SUBTYPE_REGISTER_382 (BOOST_VMD_TYPE_NUMBER,382)
#define BOOST_VMD_SUBTYPE_REGISTER_383 (BOOST_VMD_TYPE_NUMBER,383)
#define BOOST_VMD_SUBTYPE_REGISTER_384 (BOOST_VMD_TYPE_NUMBER,384)
#define BOOST_VMD_SUBTYPE_REGISTER_385 (BOOST_VMD_TYPE_NUMBER,385)
#define BOOST_VMD_SUBTYPE_REGISTER_386 (BOOST_VMD_TYPE_NUMBER,386)
#define BOOST_VMD_SUBTYPE_REGISTER_387 (BOOST_VMD_TYPE_NUMBER,387)
#define BOOST_VMD_SUBTYPE_REGISTER_388 (BOOST_VMD_TYPE_NUMBER,388)
#define BOOST_VMD_SUBTYPE_REGISTER_389 (BOOST_VMD_TYPE_NUMBER,389)
#define BOOST_VMD_SUBTYPE_REGISTER_390 (BOOST_VMD_TYPE_NUMBER,390)
#define BOOST_VMD_SUBTYPE_REGISTER_391 (BOOST_VMD_TYPE_NUMBER,391)
#define BOOST_VMD_SUBTYPE_REGISTER_392 (BOOST_VMD_TYPE_NUMBER,392)
#define BOOST_VMD_SUBTYPE_REGISTER_393 (BOOST_VMD_TYPE_NUMBER,393)
#define BOOST_VMD_SUBTYPE_REGISTER_394 (BOOST_VMD_TYPE_NUMBER,394)
#define BOOST_VMD_SUBTYPE_REGISTER_395 (BOOST_VMD_TYPE_NUMBER,395)
#define BOOST_VMD_SUBTYPE_REGISTER_396 (BOOST_VMD_TYPE_NUMBER,396)
#define BOOST_VMD_SUBTYPE_REGISTER_397 (BOOST_VMD_TYPE_NUMBER,397)
#define BOOST_VMD_SUBTYPE_REGISTER_398 (BOOST_VMD_TYPE_NUMBER,398)
#define BOOST_VMD_SUBTYPE_REGISTER_399 (BOOST_VMD_TYPE_NUMBER,399)
#define BOOST_VMD_SUBTYPE_REGISTER_400 (BOOST_VMD_TYPE_NUMBER,400)
#define BOOST_VMD_SUBTYPE_REGISTER_401 (BOOST_VMD_TYPE_NUMBER,401)
#define BOOST_VMD_SUBTYPE_REGISTER_402 (BOOST_VMD_TYPE_NUMBER,402)
#define BOOST_VMD_SUBTYPE_REGISTER_403 (BOOST_VMD_TYPE_NUMBER,403)
#define BOOST_VMD_SUBTYPE_REGISTER_404 (BOOST_VMD_TYPE_NUMBER,404)
#define BOOST_VMD_SUBTYPE_REGISTER_405 (BOOST_VMD_TYPE_NUMBER,405)
#define BOOST_VMD_SUBTYPE_REGISTER_406 (BOOST_VMD_TYPE_NUMBER,406)
#define BOOST_VMD_SUBTYPE_REGISTER_407 (BOOST_VMD_TYPE_NUMBER,407)
#define BOOST_VMD_SUBTYPE_REGISTER_408 (BOOST_VMD_TYPE_NUMBER,408)
#define BOOST_VMD_SUBTYPE_REGISTER_409 (BOOST_VMD_TYPE_NUMBER,409)
#define BOOST_VMD_SUBTYPE_REGISTER_410 (BOOST_VMD_TYPE_NUMBER,410)
#define BOOST_VMD_SUBTYPE_REGISTER_411 (BOOST_VMD_TYPE_NUMBER,411)
#define BOOST_VMD_SUBTYPE_REGISTER_412 (BOOST_VMD_TYPE_NUMBER,412)
#define BOOST_VMD_SUBTYPE_REGISTER_413 (BOOST_VMD_TYPE_NUMBER,413)
#define BOOST_VMD_SUBTYPE_REGISTER_414 (BOOST_VMD_TYPE_NUMBER,414)
#define BOOST_VMD_SUBTYPE_REGISTER_415 (BOOST_VMD_TYPE_NUMBER,415)
#define BOOST_VMD_SUBTYPE_REGISTER_416 (BOOST_VMD_TYPE_NUMBER,416)
#define BOOST_VMD_SUBTYPE_REGISTER_417 (BOOST_VMD_TYPE_NUMBER,417)
#define BOOST_VMD_SUBTYPE_REGISTER_418 (BOOST_VMD_TYPE_NUMBER,418)
#define BOOST_VMD_SUBTYPE_REGISTER_419 (BOOST_VMD_TYPE_NUMBER,419)
#define BOOST_VMD_SUBTYPE_REGISTER_420 (BOOST_VMD_TYPE_NUMBER,420)
#define BOOST_VMD_SUBTYPE_REGISTER_421 (BOOST_VMD_TYPE_NUMBER,421)
#define BOOST_VMD_SUBTYPE_REGISTER_422 (BOOST_VMD_TYPE_NUMBER,422)
#define BOOST_VMD_SUBTYPE_REGISTER_423 (BOOST_VMD_TYPE_NUMBER,423)
#define BOOST_VMD_SUBTYPE_REGISTER_424 (BOOST_VMD_TYPE_NUMBER,424)
#define BOOST_VMD_SUBTYPE_REGISTER_425 (BOOST_VMD_TYPE_NUMBER,425)
#define BOOST_VMD_SUBTYPE_REGISTER_426 (BOOST_VMD_TYPE_NUMBER,426)
#define BOOST_VMD_SUBTYPE_REGISTER_427 (BOOST_VMD_TYPE_NUMBER,427)
#define BOOST_VMD_SUBTYPE_REGISTER_428 (BOOST_VMD_TYPE_NUMBER,428)
#define BOOST_VMD_SUBTYPE_REGISTER_429 (BOOST_VMD_TYPE_NUMBER,429)
#define BOOST_VMD_SUBTYPE_REGISTER_430 (BOOST_VMD_TYPE_NUMBER,430)
#define BOOST_VMD_SUBTYPE_REGISTER_431 (BOOST_VMD_TYPE_NUMBER,431)
#define BOOST_VMD_SUBTYPE_REGISTER_432 (BOOST_VMD_TYPE_NUMBER,432)
#define BOOST_VMD_SUBTYPE_REGISTER_433 (BOOST_VMD_TYPE_NUMBER,433)
#define BOOST_VMD_SUBTYPE_REGISTER_434 (BOOST_VMD_TYPE_NUMBER,434)
#define BOOST_VMD_SUBTYPE_REGISTER_435 (BOOST_VMD_TYPE_NUMBER,435)
#define BOOST_VMD_SUBTYPE_REGISTER_436 (BOOST_VMD_TYPE_NUMBER,436)
#define BOOST_VMD_SUBTYPE_REGISTER_437 (BOOST_VMD_TYPE_NUMBER,437)
#define BOOST_VMD_SUBTYPE_REGISTER_438 (BOOST_VMD_TYPE_NUMBER,438)
#define BOOST_VMD_SUBTYPE_REGISTER_439 (BOOST_VMD_TYPE_NUMBER,439)
#define BOOST_VMD_SUBTYPE_REGISTER_440 (BOOST_VMD_TYPE_NUMBER,440)
#define BOOST_VMD_SUBTYPE_REGISTER_441 (BOOST_VMD_TYPE_NUMBER,441)
#define BOOST_VMD_SUBTYPE_REGISTER_442 (BOOST_VMD_TYPE_NUMBER,442)
#define BOOST_VMD_SUBTYPE_REGISTER_443 (BOOST_VMD_TYPE_NUMBER,443)
#define BOOST_VMD_SUBTYPE_REGISTER_444 (BOOST_VMD_TYPE_NUMBER,444)
#define BOOST_VMD_SUBTYPE_REGISTER_445 (BOOST_VMD_TYPE_NUMBER,445)
#define BOOST_VMD_SUBTYPE_REGISTER_446 (BOOST_VMD_TYPE_NUMBER,446)
#define BOOST_VMD_SUBTYPE_REGISTER_447 (BOOST_VMD_TYPE_NUMBER,447)
#define BOOST_VMD_SUBTYPE_REGISTER_448 (BOOST_VMD_TYPE_NUMBER,448)
#define BOOST_VMD_SUBTYPE_REGISTER_449 (BOOST_VMD_TYPE_NUMBER,449)
#define BOOST_VMD_SUBTYPE_REGISTER_450 (BOOST_VMD_TYPE_NUMBER,450)
#define BOOST_VMD_SUBTYPE_REGISTER_451 (BOOST_VMD_TYPE_NUMBER,451)
#define BOOST_VMD_SUBTYPE_REGISTER_452 (BOOST_VMD_TYPE_NUMBER,452)
#define BOOST_VMD_SUBTYPE_REGISTER_453 (BOOST_VMD_TYPE_NUMBER,453)
#define BOOST_VMD_SUBTYPE_REGISTER_454 (BOOST_VMD_TYPE_NUMBER,454)
#define BOOST_VMD_SUBTYPE_REGISTER_455 (BOOST_VMD_TYPE_NUMBER,455)
#define BOOST_VMD_SUBTYPE_REGISTER_456 (BOOST_VMD_TYPE_NUMBER,456)
#define BOOST_VMD_SUBTYPE_REGISTER_457 (BOOST_VMD_TYPE_NUMBER,457)
#define BOOST_VMD_SUBTYPE_REGISTER_458 (BOOST_VMD_TYPE_NUMBER,458)
#define BOOST_VMD_SUBTYPE_REGISTER_459 (BOOST_VMD_TYPE_NUMBER,459)
#define BOOST_VMD_SUBTYPE_REGISTER_460 (BOOST_VMD_TYPE_NUMBER,460)
#define BOOST_VMD_SUBTYPE_REGISTER_461 (BOOST_VMD_TYPE_NUMBER,461)
#define BOOST_VMD_SUBTYPE_REGISTER_462 (BOOST_VMD_TYPE_NUMBER,462)
#define BOOST_VMD_SUBTYPE_REGISTER_463 (BOOST_VMD_TYPE_NUMBER,463)
#define BOOST_VMD_SUBTYPE_REGISTER_464 (BOOST_VMD_TYPE_NUMBER,464)
#define BOOST_VMD_SUBTYPE_REGISTER_465 (BOOST_VMD_TYPE_NUMBER,465)
#define BOOST_VMD_SUBTYPE_REGISTER_466 (BOOST_VMD_TYPE_NUMBER,466)
#define BOOST_VMD_SUBTYPE_REGISTER_467 (BOOST_VMD_TYPE_NUMBER,467)
#define BOOST_VMD_SUBTYPE_REGISTER_468 (BOOST_VMD_TYPE_NUMBER,468)
#define BOOST_VMD_SUBTYPE_REGISTER_469 (BOOST_VMD_TYPE_NUMBER,469)
#define BOOST_VMD_SUBTYPE_REGISTER_470 (BOOST_VMD_TYPE_NUMBER,470)
#define BOOST_VMD_SUBTYPE_REGISTER_471 (BOOST_VMD_TYPE_NUMBER,471)
#define BOOST_VMD_SUBTYPE_REGISTER_472 (BOOST_VMD_TYPE_NUMBER,472)
#define BOOST_VMD_SUBTYPE_REGISTER_473 (BOOST_VMD_TYPE_NUMBER,473)
#define BOOST_VMD_SUBTYPE_REGISTER_474 (BOOST_VMD_TYPE_NUMBER,474)
#define BOOST_VMD_SUBTYPE_REGISTER_475 (BOOST_VMD_TYPE_NUMBER,475)
#define BOOST_VMD_SUBTYPE_REGISTER_476 (BOOST_VMD_TYPE_NUMBER,476)
#define BOOST_VMD_SUBTYPE_REGISTER_477 (BOOST_VMD_TYPE_NUMBER,477)
#define BOOST_VMD_SUBTYPE_REGISTER_478 (BOOST_VMD_TYPE_NUMBER,478)
#define BOOST_VMD_SUBTYPE_REGISTER_479 (BOOST_VMD_TYPE_NUMBER,479)
#define BOOST_VMD_SUBTYPE_REGISTER_480 (BOOST_VMD_TYPE_NUMBER,480)
#define BOOST_VMD_SUBTYPE_REGISTER_481 (BOOST_VMD_TYPE_NUMBER,481)
#define BOOST_VMD_SUBTYPE_REGISTER_482 (BOOST_VMD_TYPE_NUMBER,482)
#define BOOST_VMD_SUBTYPE_REGISTER_483 (BOOST_VMD_TYPE_NUMBER,483)
#define BOOST_VMD_SUBTYPE_REGISTER_484 (BOOST_VMD_TYPE_NUMBER,484)
#define BOOST_VMD_SUBTYPE_REGISTER_485 (BOOST_VMD_TYPE_NUMBER,485)
#define BOOST_VMD_SUBTYPE_REGISTER_486 (BOOST_VMD_TYPE_NUMBER,486)
#define BOOST_VMD_SUBTYPE_REGISTER_487 (BOOST_VMD_TYPE_NUMBER,487)
#define BOOST_VMD_SUBTYPE_REGISTER_488 (BOOST_VMD_TYPE_NUMBER,488)
#define BOOST_VMD_SUBTYPE_REGISTER_489 (BOOST_VMD_TYPE_NUMBER,489)
#define BOOST_VMD_SUBTYPE_REGISTER_490 (BOOST_VMD_TYPE_NUMBER,490)
#define BOOST_VMD_SUBTYPE_REGISTER_491 (BOOST_VMD_TYPE_NUMBER,491)
#define BOOST_VMD_SUBTYPE_REGISTER_492 (BOOST_VMD_TYPE_NUMBER,492)
#define BOOST_VMD_SUBTYPE_REGISTER_493 (BOOST_VMD_TYPE_NUMBER,493)
#define BOOST_VMD_SUBTYPE_REGISTER_494 (BOOST_VMD_TYPE_NUMBER,494)
#define BOOST_VMD_SUBTYPE_REGISTER_495 (BOOST_VMD_TYPE_NUMBER,495)
#define BOOST_VMD_SUBTYPE_REGISTER_496 (BOOST_VMD_TYPE_NUMBER,496)
#define BOOST_VMD_SUBTYPE_REGISTER_497 (BOOST_VMD_TYPE_NUMBER,497)
#define BOOST_VMD_SUBTYPE_REGISTER_498 (BOOST_VMD_TYPE_NUMBER,498)
#define BOOST_VMD_SUBTYPE_REGISTER_499 (BOOST_VMD_TYPE_NUMBER,499)
#define BOOST_VMD_SUBTYPE_REGISTER_500 (BOOST_VMD_TYPE_NUMBER,500)
#define BOOST_VMD_SUBTYPE_REGISTER_501 (BOOST_VMD_TYPE_NUMBER,501)
#define BOOST_VMD_SUBTYPE_REGISTER_502 (BOOST_VMD_TYPE_NUMBER,502)
#define BOOST_VMD_SUBTYPE_REGISTER_503 (BOOST_VMD_TYPE_NUMBER,503)
#define BOOST_VMD_SUBTYPE_REGISTER_504 (BOOST_VMD_TYPE_NUMBER,504)
#define BOOST_VMD_SUBTYPE_REGISTER_505 (BOOST_VMD_TYPE_NUMBER,505)
#define BOOST_VMD_SUBTYPE_REGISTER_506 (BOOST_VMD_TYPE_NUMBER,506)
#define BOOST_VMD_SUBTYPE_REGISTER_507 (BOOST_VMD_TYPE_NUMBER,507)
#define BOOST_VMD_SUBTYPE_REGISTER_508 (BOOST_VMD_TYPE_NUMBER,508)
#define BOOST_VMD_SUBTYPE_REGISTER_509 (BOOST_VMD_TYPE_NUMBER,509)
#define BOOST_VMD_SUBTYPE_REGISTER_510 (BOOST_VMD_TYPE_NUMBER,510)
#define BOOST_VMD_SUBTYPE_REGISTER_511 (BOOST_VMD_TYPE_NUMBER,511)
#define BOOST_VMD_SUBTYPE_REGISTER_512 (BOOST_VMD_TYPE_NUMBER,512)

#endif

#if BOOST_PP_LIMIT_MAG > 512

#define BOOST_VMD_SUBTYPE_REGISTER_513 (BOOST_VMD_TYPE_NUMBER,513)
#define BOOST_VMD_SUBTYPE_REGISTER_514 (BOOST_VMD_TYPE_NUMBER,514)
#define BOOST_VMD_SUBTYPE_REGISTER_515 (BOOST_VMD_TYPE_NUMBER,515)
#define BOOST_VMD_SUBTYPE_REGISTER_516 (BOOST_VMD_TYPE_NUMBER,516)
#define BOOST_VMD_SUBTYPE_REGISTER_517 (BOOST_VMD_TYPE_NUMBER,517)
#define BOOST_VMD_SUBTYPE_REGISTER_518 (BOOST_VMD_TYPE_NUMBER,518)
#define BOOST_VMD_SUBTYPE_REGISTER_519 (BOOST_VMD_TYPE_NUMBER,519)
#define BOOST_VMD_SUBTYPE_REGISTER_520 (BOOST_VMD_TYPE_NUMBER,520)
#define BOOST_VMD_SUBTYPE_REGISTER_521 (BOOST_VMD_TYPE_NUMBER,521)
#define BOOST_VMD_SUBTYPE_REGISTER_522 (BOOST_VMD_TYPE_NUMBER,522)
#define BOOST_VMD_SUBTYPE_REGISTER_523 (BOOST_VMD_TYPE_NUMBER,523)
#define BOOST_VMD_SUBTYPE_REGISTER_524 (BOOST_VMD_TYPE_NUMBER,524)
#define BOOST_VMD_SUBTYPE_REGISTER_525 (BOOST_VMD_TYPE_NUMBER,525)
#define BOOST_VMD_SUBTYPE_REGISTER_526 (BOOST_VMD_TYPE_NUMBER,526)
#define BOOST_VMD_SUBTYPE_REGISTER_527 (BOOST_VMD_TYPE_NUMBER,527)
#define BOOST_VMD_SUBTYPE_REGISTER_528 (BOOST_VMD_TYPE_NUMBER,528)
#define BOOST_VMD_SUBTYPE_REGISTER_529 (BOOST_VMD_TYPE_NUMBER,529)
#define BOOST_VMD_SUBTYPE_REGISTER_530 (BOOST_VMD_TYPE_NUMBER,530)
#define BOOST_VMD_SUBTYPE_REGISTER_531 (BOOST_VMD_TYPE_NUMBER,531)
#define BOOST_VMD_SUBTYPE_REGISTER_532 (BOOST_VMD_TYPE_NUMBER,532)
#define BOOST_VMD_SUBTYPE_REGISTER_533 (BOOST_VMD_TYPE_NUMBER,533)
#define BOOST_VMD_SUBTYPE_REGISTER_534 (BOOST_VMD_TYPE_NUMBER,534)
#define BOOST_VMD_SUBTYPE_REGISTER_535 (BOOST_VMD_TYPE_NUMBER,535)
#define BOOST_VMD_SUBTYPE_REGISTER_536 (BOOST_VMD_TYPE_NUMBER,536)
#define BOOST_VMD_SUBTYPE_REGISTER_537 (BOOST_VMD_TYPE_NUMBER,537)
#define BOOST_VMD_SUBTYPE_REGISTER_538 (BOOST_VMD_TYPE_NUMBER,538)
#define BOOST_VMD_SUBTYPE_REGISTER_539 (BOOST_VMD_TYPE_NUMBER,539)
#define BOOST_VMD_SUBTYPE_REGISTER_540 (BOOST_VMD_TYPE_NUMBER,540)
#define BOOST_VMD_SUBTYPE_REGISTER_541 (BOOST_VMD_TYPE_NUMBER,541)
#define BOOST_VMD_SUBTYPE_REGISTER_542 (BOOST_VMD_TYPE_NUMBER,542)
#define BOOST_VMD_SUBTYPE_REGISTER_543 (BOOST_VMD_TYPE_NUMBER,543)
#define BOOST_VMD_SUBTYPE_REGISTER_544 (BOOST_VMD_TYPE_NUMBER,544)
#define BOOST_VMD_SUBTYPE_REGISTER_545 (BOOST_VMD_TYPE_NUMBER,545)
#define BOOST_VMD_SUBTYPE_REGISTER_546 (BOOST_VMD_TYPE_NUMBER,546)
#define BOOST_VMD_SUBTYPE_REGISTER_547 (BOOST_VMD_TYPE_NUMBER,547)
#define BOOST_VMD_SUBTYPE_REGISTER_548 (BOOST_VMD_TYPE_NUMBER,548)
#define BOOST_VMD_SUBTYPE_REGISTER_549 (BOOST_VMD_TYPE_NUMBER,549)
#define BOOST_VMD_SUBTYPE_REGISTER_550 (BOOST_VMD_TYPE_NUMBER,550)
#define BOOST_VMD_SUBTYPE_REGISTER_551 (BOOST_VMD_TYPE_NUMBER,551)
#define BOOST_VMD_SUBTYPE_REGISTER_552 (BOOST_VMD_TYPE_NUMBER,552)
#define BOOST_VMD_SUBTYPE_REGISTER_553 (BOOST_VMD_TYPE_NUMBER,553)
#define BOOST_VMD_SUBTYPE_REGISTER_554 (BOOST_VMD_TYPE_NUMBER,554)
#define BOOST_VMD_SUBTYPE_REGISTER_555 (BOOST_VMD_TYPE_NUMBER,555)
#define BOOST_VMD_SUBTYPE_REGISTER_556 (BOOST_VMD_TYPE_NUMBER,556)
#define BOOST_VMD_SUBTYPE_REGISTER_557 (BOOST_VMD_TYPE_NUMBER,557)
#define BOOST_VMD_SUBTYPE_REGISTER_558 (BOOST_VMD_TYPE_NUMBER,558)
#define BOOST_VMD_SUBTYPE_REGISTER_559 (BOOST_VMD_TYPE_NUMBER,559)
#define BOOST_VMD_SUBTYPE_REGISTER_560 (BOOST_VMD_TYPE_NUMBER,560)
#define BOOST_VMD_SUBTYPE_REGISTER_561 (BOOST_VMD_TYPE_NUMBER,561)
#define BOOST_VMD_SUBTYPE_REGISTER_562 (BOOST_VMD_TYPE_NUMBER,562)
#define BOOST_VMD_SUBTYPE_REGISTER_563 (BOOST_VMD_TYPE_NUMBER,563)
#define BOOST_VMD_SUBTYPE_REGISTER_564 (BOOST_VMD_TYPE_NUMBER,564)
#define BOOST_VMD_SUBTYPE_REGISTER_565 (BOOST_VMD_TYPE_NUMBER,565)
#define BOOST_VMD_SUBTYPE_REGISTER_566 (BOOST_VMD_TYPE_NUMBER,566)
#define BOOST_VMD_SUBTYPE_REGISTER_567 (BOOST_VMD_TYPE_NUMBER,567)
#define BOOST_VMD_SUBTYPE_REGISTER_568 (BOOST_VMD_TYPE_NUMBER,568)
#define BOOST_VMD_SUBTYPE_REGISTER_569 (BOOST_VMD_TYPE_NUMBER,569)
#define BOOST_VMD_SUBTYPE_REGISTER_570 (BOOST_VMD_TYPE_NUMBER,570)
#define BOOST_VMD_SUBTYPE_REGISTER_571 (BOOST_VMD_TYPE_NUMBER,571)
#define BOOST_VMD_SUBTYPE_REGISTER_572 (BOOST_VMD_TYPE_NUMBER,572)
#define BOOST_VMD_SUBTYPE_REGISTER_573 (BOOST_VMD_TYPE_NUMBER,573)
#define BOOST_VMD_SUBTYPE_REGISTER_574 (BOOST_VMD_TYPE_NUMBER,574)
#define BOOST_VMD_SUBTYPE_REGISTER_575 (BOOST_VMD_TYPE_NUMBER,575)
#define BOOST_VMD_SUBTYPE_REGISTER_576 (BOOST_VMD_TYPE_NUMBER,576)
#define BOOST_VMD_SUBTYPE_REGISTER_577 (BOOST_VMD_TYPE_NUMBER,577)
#define BOOST_VMD_SUBTYPE_REGISTER_578 (BOOST_VMD_TYPE_NUMBER,578)
#define BOOST_VMD_SUBTYPE_REGISTER_579 (BOOST_VMD_TYPE_NUMBER,579)
#define BOOST_VMD_SUBTYPE_REGISTER_580 (BOOST_VMD_TYPE_NUMBER,580)
#define BOOST_VMD_SUBTYPE_REGISTER_581 (BOOST_VMD_TYPE_NUMBER,581)
#define BOOST_VMD_SUBTYPE_REGISTER_582 (BOOST_VMD_TYPE_NUMBER,582)
#define BOOST_VMD_SUBTYPE_REGISTER_583 (BOOST_VMD_TYPE_NUMBER,583)
#define BOOST_VMD_SUBTYPE_REGISTER_584 (BOOST_VMD_TYPE_NUMBER,584)
#define BOOST_VMD_SUBTYPE_REGISTER_585 (BOOST_VMD_TYPE_NUMBER,585)
#define BOOST_VMD_SUBTYPE_REGISTER_586 (BOOST_VMD_TYPE_NUMBER,586)
#define BOOST_VMD_SUBTYPE_REGISTER_587 (BOOST_VMD_TYPE_NUMBER,587)
#define BOOST_VMD_SUBTYPE_REGISTER_588 (BOOST_VMD_TYPE_NUMBER,588)
#define BOOST_VMD_SUBTYPE_REGISTER_589 (BOOST_VMD_TYPE_NUMBER,589)
#define BOOST_VMD_SUBTYPE_REGISTER_590 (BOOST_VMD_TYPE_NUMBER,590)
#define BOOST_VMD_SUBTYPE_REGISTER_591 (BOOST_VMD_TYPE_NUMBER,591)
#define BOOST_VMD_SUBTYPE_REGISTER_592 (BOOST_VMD_TYPE_NUMBER,592)
#define BOOST_VMD_SUBTYPE_REGISTER_593 (BOOST_VMD_TYPE_NUMBER,593)
#define BOOST_VMD_SUBTYPE_REGISTER_594 (BOOST_VMD_TYPE_NUMBER,594)
#define BOOST_VMD_SUBTYPE_REGISTER_595 (BOOST_VMD_TYPE_NUMBER,595)
#define BOOST_VMD_SUBTYPE_REGISTER_596 (BOOST_VMD_TYPE_NUMBER,596)
#define BOOST_VMD_SUBTYPE_REGISTER_597 (BOOST_VMD_TYPE_NUMBER,597)
#define BOOST_VMD_SUBTYPE_REGISTER_598 (BOOST_VMD_TYPE_NUMBER,598)
#define BOOST_VMD_SUBTYPE_REGISTER_599 (BOOST_VMD_TYPE_NUMBER,599)
#define BOOST_VMD_SUBTYPE_REGISTER_600 (BOOST_VMD_TYPE_NUMBER,600)
#define BOOST_VMD_SUBTYPE_REGISTER_601 (BOOST_VMD_TYPE_NUMBER,601)
#define BOOST_VMD_SUBTYPE_REGISTER_602 (BOOST_VMD_TYPE_NUMBER,602)
#define BOOST_VMD_SUBTYPE_REGISTER_603 (BOOST_VMD_TYPE_NUMBER,603)
#define BOOST_VMD_SUBTYPE_REGISTER_604 (BOOST_VMD_TYPE_NUMBER,604)
#define BOOST_VMD_SUBTYPE_REGISTER_605 (BOOST_VMD_TYPE_NUMBER,605)
#define BOOST_VMD_SUBTYPE_REGISTER_606 (BOOST_VMD_TYPE_NUMBER,606)
#define BOOST_VMD_SUBTYPE_REGISTER_607 (BOOST_VMD_TYPE_NUMBER,607)
#define BOOST_VMD_SUBTYPE_REGISTER_608 (BOOST_VMD_TYPE_NUMBER,608)
#define BOOST_VMD_SUBTYPE_REGISTER_609 (BOOST_VMD_TYPE_NUMBER,609)
#define BOOST_VMD_SUBTYPE_REGISTER_610 (BOOST_VMD_TYPE_NUMBER,610)
#define BOOST_VMD_SUBTYPE_REGISTER_611 (BOOST_VMD_TYPE_NUMBER,611)
#define BOOST_VMD_SUBTYPE_REGISTER_612 (BOOST_VMD_TYPE_NUMBER,612)
#define BOOST_VMD_SUBTYPE_REGISTER_613 (BOOST_VMD_TYPE_NUMBER,613)
#define BOOST_VMD_SUBTYPE_REGISTER_614 (BOOST_VMD_TYPE_NUMBER,614)
#define BOOST_VMD_SUBTYPE_REGISTER_615 (BOOST_VMD_TYPE_NUMBER,615)
#define BOOST_VMD_SUBTYPE_REGISTER_616 (BOOST_VMD_TYPE_NUMBER,616)
#define BOOST_VMD_SUBTYPE_REGISTER_617 (BOOST_VMD_TYPE_NUMBER,617)
#define BOOST_VMD_SUBTYPE_REGISTER_618 (BOOST_VMD_TYPE_NUMBER,618)
#define BOOST_VMD_SUBTYPE_REGISTER_619 (BOOST_VMD_TYPE_NUMBER,619)
#define BOOST_VMD_SUBTYPE_REGISTER_620 (BOOST_VMD_TYPE_NUMBER,620)
#define BOOST_VMD_SUBTYPE_REGISTER_621 (BOOST_VMD_TYPE_NUMBER,621)
#define BOOST_VMD_SUBTYPE_REGISTER_622 (BOOST_VMD_TYPE_NUMBER,622)
#define BOOST_VMD_SUBTYPE_REGISTER_623 (BOOST_VMD_TYPE_NUMBER,623)
#define BOOST_VMD_SUBTYPE_REGISTER_624 (BOOST_VMD_TYPE_NUMBER,624)
#define BOOST_VMD_SUBTYPE_REGISTER_625 (BOOST_VMD_TYPE_NUMBER,625)
#define BOOST_VMD_SUBTYPE_REGISTER_626 (BOOST_VMD_TYPE_NUMBER,626)
#define BOOST_VMD_SUBTYPE_REGISTER_627 (BOOST_VMD_TYPE_NUMBER,627)
#define BOOST_VMD_SUBTYPE_REGISTER_628 (BOOST_VMD_TYPE_NUMBER,628)
#define BOOST_VMD_SUBTYPE_REGISTER_629 (BOOST_VMD_TYPE_NUMBER,629)
#define BOOST_VMD_SUBTYPE_REGISTER_630 (BOOST_VMD_TYPE_NUMBER,630)
#define BOOST_VMD_SUBTYPE_REGISTER_631 (BOOST_VMD_TYPE_NUMBER,631)
#define BOOST_VMD_SUBTYPE_REGISTER_632 (BOOST_VMD_TYPE_NUMBER,632)
#define BOOST_VMD_SUBTYPE_REGISTER_633 (BOOST_VMD_TYPE_NUMBER,633)
#define BOOST_VMD_SUBTYPE_REGISTER_634 (BOOST_VMD_TYPE_NUMBER,634)
#define BOOST_VMD_SUBTYPE_REGISTER_635 (BOOST_VMD_TYPE_NUMBER,635)
#define BOOST_VMD_SUBTYPE_REGISTER_636 (BOOST_VMD_TYPE_NUMBER,636)
#define BOOST_VMD_SUBTYPE_REGISTER_637 (BOOST_VMD_TYPE_NUMBER,637)
#define BOOST_VMD_SUBTYPE_REGISTER_638 (BOOST_VMD_TYPE_NUMBER,638)
#define BOOST_VMD_SUBTYPE_REGISTER_639 (BOOST_VMD_TYPE_NUMBER,639)
#define BOOST_VMD_SUBTYPE_REGISTER_640 (BOOST_VMD_TYPE_NUMBER,640)
#define BOOST_VMD_SUBTYPE_REGISTER_641 (BOOST_VMD_TYPE_NUMBER,641)
#define BOOST_VMD_SUBTYPE_REGISTER_642 (BOOST_VMD_TYPE_NUMBER,642)
#define BOOST_VMD_SUBTYPE_REGISTER_643 (BOOST_VMD_TYPE_NUMBER,643)
#define BOOST_VMD_SUBTYPE_REGISTER_644 (BOOST_VMD_TYPE_NUMBER,644)
#define BOOST_VMD_SUBTYPE_REGISTER_645 (BOOST_VMD_TYPE_NUMBER,645)
#define BOOST_VMD_SUBTYPE_REGISTER_646 (BOOST_VMD_TYPE_NUMBER,646)
#define BOOST_VMD_SUBTYPE_REGISTER_647 (BOOST_VMD_TYPE_NUMBER,647)
#define BOOST_VMD_SUBTYPE_REGISTER_648 (BOOST_VMD_TYPE_NUMBER,648)
#define BOOST_VMD_SUBTYPE_REGISTER_649 (BOOST_VMD_TYPE_NUMBER,649)
#define BOOST_VMD_SUBTYPE_REGISTER_650 (BOOST_VMD_TYPE_NUMBER,650)
#define BOOST_VMD_SUBTYPE_REGISTER_651 (BOOST_VMD_TYPE_NUMBER,651)
#define BOOST_VMD_SUBTYPE_REGISTER_652 (BOOST_VMD_TYPE_NUMBER,652)
#define BOOST_VMD_SUBTYPE_REGISTER_653 (BOOST_VMD_TYPE_NUMBER,653)
#define BOOST_VMD_SUBTYPE_REGISTER_654 (BOOST_VMD_TYPE_NUMBER,654)
#define BOOST_VMD_SUBTYPE_REGISTER_655 (BOOST_VMD_TYPE_NUMBER,655)
#define BOOST_VMD_SUBTYPE_REGISTER_656 (BOOST_VMD_TYPE_NUMBER,656)
#define BOOST_VMD_SUBTYPE_REGISTER_657 (BOOST_VMD_TYPE_NUMBER,657)
#define BOOST_VMD_SUBTYPE_REGISTER_658 (BOOST_VMD_TYPE_NUMBER,658)
#define BOOST_VMD_SUBTYPE_REGISTER_659 (BOOST_VMD_TYPE_NUMBER,659)
#define BOOST_VMD_SUBTYPE_REGISTER_660 (BOOST_VMD_TYPE_NUMBER,660)
#define BOOST_VMD_SUBTYPE_REGISTER_661 (BOOST_VMD_TYPE_NUMBER,661)
#define BOOST_VMD_SUBTYPE_REGISTER_662 (BOOST_VMD_TYPE_NUMBER,662)
#define BOOST_VMD_SUBTYPE_REGISTER_663 (BOOST_VMD_TYPE_NUMBER,663)
#define BOOST_VMD_SUBTYPE_REGISTER_664 (BOOST_VMD_TYPE_NUMBER,664)
#define BOOST_VMD_SUBTYPE_REGISTER_665 (BOOST_VMD_TYPE_NUMBER,665)
#define BOOST_VMD_SUBTYPE_REGISTER_666 (BOOST_VMD_TYPE_NUMBER,666)
#define BOOST_VMD_SUBTYPE_REGISTER_667 (BOOST_VMD_TYPE_NUMBER,667)
#define BOOST_VMD_SUBTYPE_REGISTER_668 (BOOST_VMD_TYPE_NUMBER,668)
#define BOOST_VMD_SUBTYPE_REGISTER_669 (BOOST_VMD_TYPE_NUMBER,669)
#define BOOST_VMD_SUBTYPE_REGISTER_670 (BOOST_VMD_TYPE_NUMBER,670)
#define BOOST_VMD_SUBTYPE_REGISTER_671 (BOOST_VMD_TYPE_NUMBER,671)
#define BOOST_VMD_SUBTYPE_REGISTER_672 (BOOST_VMD_TYPE_NUMBER,672)
#define BOOST_VMD_SUBTYPE_REGISTER_673 (BOOST_VMD_TYPE_NUMBER,673)
#define BOOST_VMD_SUBTYPE_REGISTER_674 (BOOST_VMD_TYPE_NUMBER,674)
#define BOOST_VMD_SUBTYPE_REGISTER_675 (BOOST_VMD_TYPE_NUMBER,675)
#define BOOST_VMD_SUBTYPE_REGISTER_676 (BOOST_VMD_TYPE_NUMBER,676)
#define BOOST_VMD_SUBTYPE_REGISTER_677 (BOOST_VMD_TYPE_NUMBER,677)
#define BOOST_VMD_SUBTYPE_REGISTER_678 (BOOST_VMD_TYPE_NUMBER,678)
#define BOOST_VMD_SUBTYPE_REGISTER_679 (BOOST_VMD_TYPE_NUMBER,679)
#define BOOST_VMD_SUBTYPE_REGISTER_680 (BOOST_VMD_TYPE_NUMBER,680)
#define BOOST_VMD_SUBTYPE_REGISTER_681 (BOOST_VMD_TYPE_NUMBER,681)
#define BOOST_VMD_SUBTYPE_REGISTER_682 (BOOST_VMD_TYPE_NUMBER,682)
#define BOOST_VMD_SUBTYPE_REGISTER_683 (BOOST_VMD_TYPE_NUMBER,683)
#define BOOST_VMD_SUBTYPE_REGISTER_684 (BOOST_VMD_TYPE_NUMBER,684)
#define BOOST_VMD_SUBTYPE_REGISTER_685 (BOOST_VMD_TYPE_NUMBER,685)
#define BOOST_VMD_SUBTYPE_REGISTER_686 (BOOST_VMD_TYPE_NUMBER,686)
#define BOOST_VMD_SUBTYPE_REGISTER_687 (BOOST_VMD_TYPE_NUMBER,687)
#define BOOST_VMD_SUBTYPE_REGISTER_688 (BOOST_VMD_TYPE_NUMBER,688)
#define BOOST_VMD_SUBTYPE_REGISTER_689 (BOOST_VMD_TYPE_NUMBER,689)
#define BOOST_VMD_SUBTYPE_REGISTER_690 (BOOST_VMD_TYPE_NUMBER,690)
#define BOOST_VMD_SUBTYPE_REGISTER_691 (BOOST_VMD_TYPE_NUMBER,691)
#define BOOST_VMD_SUBTYPE_REGISTER_692 (BOOST_VMD_TYPE_NUMBER,692)
#define BOOST_VMD_SUBTYPE_REGISTER_693 (BOOST_VMD_TYPE_NUMBER,693)
#define BOOST_VMD_SUBTYPE_REGISTER_694 (BOOST_VMD_TYPE_NUMBER,694)
#define BOOST_VMD_SUBTYPE_REGISTER_695 (BOOST_VMD_TYPE_NUMBER,695)
#define BOOST_VMD_SUBTYPE_REGISTER_696 (BOOST_VMD_TYPE_NUMBER,696)
#define BOOST_VMD_SUBTYPE_REGISTER_697 (BOOST_VMD_TYPE_NUMBER,697)
#define BOOST_VMD_SUBTYPE_REGISTER_698 (BOOST_VMD_TYPE_NUMBER,698)
#define BOOST_VMD_SUBTYPE_REGISTER_699 (BOOST_VMD_TYPE_NUMBER,699)
#define BOOST_VMD_SUBTYPE_REGISTER_700 (BOOST_VMD_TYPE_NUMBER,700)
#define BOOST_VMD_SUBTYPE_REGISTER_701 (BOOST_VMD_TYPE_NUMBER,701)
#define BOOST_VMD_SUBTYPE_REGISTER_702 (BOOST_VMD_TYPE_NUMBER,702)
#define BOOST_VMD_SUBTYPE_REGISTER_703 (BOOST_VMD_TYPE_NUMBER,703)
#define BOOST_VMD_SUBTYPE_REGISTER_704 (BOOST_VMD_TYPE_NUMBER,704)
#define BOOST_VMD_SUBTYPE_REGISTER_705 (BOOST_VMD_TYPE_NUMBER,705)
#define BOOST_VMD_SUBTYPE_REGISTER_706 (BOOST_VMD_TYPE_NUMBER,706)
#define BOOST_VMD_SUBTYPE_REGISTER_707 (BOOST_VMD_TYPE_NUMBER,707)
#define BOOST_VMD_SUBTYPE_REGISTER_708 (BOOST_VMD_TYPE_NUMBER,708)
#define BOOST_VMD_SUBTYPE_REGISTER_709 (BOOST_VMD_TYPE_NUMBER,709)
#define BOOST_VMD_SUBTYPE_REGISTER_710 (BOOST_VMD_TYPE_NUMBER,710)
#define BOOST_VMD_SUBTYPE_REGISTER_711 (BOOST_VMD_TYPE_NUMBER,711)
#define BOOST_VMD_SUBTYPE_REGISTER_712 (BOOST_VMD_TYPE_NUMBER,712)
#define BOOST_VMD_SUBTYPE_REGISTER_713 (BOOST_VMD_TYPE_NUMBER,713)
#define BOOST_VMD_SUBTYPE_REGISTER_714 (BOOST_VMD_TYPE_NUMBER,714)
#define BOOST_VMD_SUBTYPE_REGISTER_715 (BOOST_VMD_TYPE_NUMBER,715)
#define BOOST_VMD_SUBTYPE_REGISTER_716 (BOOST_VMD_TYPE_NUMBER,716)
#define BOOST_VMD_SUBTYPE_REGISTER_717 (BOOST_VMD_TYPE_NUMBER,717)
#define BOOST_VMD_SUBTYPE_REGISTER_718 (BOOST_VMD_TYPE_NUMBER,718)
#define BOOST_VMD_SUBTYPE_REGISTER_719 (BOOST_VMD_TYPE_NUMBER,719)
#define BOOST_VMD_SUBTYPE_REGISTER_720 (BOOST_VMD_TYPE_NUMBER,720)
#define BOOST_VMD_SUBTYPE_REGISTER_721 (BOOST_VMD_TYPE_NUMBER,721)
#define BOOST_VMD_SUBTYPE_REGISTER_722 (BOOST_VMD_TYPE_NUMBER,722)
#define BOOST_VMD_SUBTYPE_REGISTER_723 (BOOST_VMD_TYPE_NUMBER,723)
#define BOOST_VMD_SUBTYPE_REGISTER_724 (BOOST_VMD_TYPE_NUMBER,724)
#define BOOST_VMD_SUBTYPE_REGISTER_725 (BOOST_VMD_TYPE_NUMBER,725)
#define BOOST_VMD_SUBTYPE_REGISTER_726 (BOOST_VMD_TYPE_NUMBER,726)
#define BOOST_VMD_SUBTYPE_REGISTER_727 (BOOST_VMD_TYPE_NUMBER,727)
#define BOOST_VMD_SUBTYPE_REGISTER_728 (BOOST_VMD_TYPE_NUMBER,728)
#define BOOST_VMD_SUBTYPE_REGISTER_729 (BOOST_VMD_TYPE_NUMBER,729)
#define BOOST_VMD_SUBTYPE_REGISTER_730 (BOOST_VMD_TYPE_NUMBER,730)
#define BOOST_VMD_SUBTYPE_REGISTER_731 (BOOST_VMD_TYPE_NUMBER,731)
#define BOOST_VMD_SUBTYPE_REGISTER_732 (BOOST_VMD_TYPE_NUMBER,732)
#define BOOST_VMD_SUBTYPE_REGISTER_733 (BOOST_VMD_TYPE_NUMBER,733)
#define BOOST_VMD_SUBTYPE_REGISTER_734 (BOOST_VMD_TYPE_NUMBER,734)
#define BOOST_VMD_SUBTYPE_REGISTER_735 (BOOST_VMD_TYPE_NUMBER,735)
#define BOOST_VMD_SUBTYPE_REGISTER_736 (BOOST_VMD_TYPE_NUMBER,736)
#define BOOST_VMD_SUBTYPE_REGISTER_737 (BOOST_VMD_TYPE_NUMBER,737)
#define BOOST_VMD_SUBTYPE_REGISTER_738 (BOOST_VMD_TYPE_NUMBER,738)
#define BOOST_VMD_SUBTYPE_REGISTER_739 (BOOST_VMD_TYPE_NUMBER,739)
#define BOOST_VMD_SUBTYPE_REGISTER_740 (BOOST_VMD_TYPE_NUMBER,740)
#define BOOST_VMD_SUBTYPE_REGISTER_741 (BOOST_VMD_TYPE_NUMBER,741)
#define BOOST_VMD_SUBTYPE_REGISTER_742 (BOOST_VMD_TYPE_NUMBER,742)
#define BOOST_VMD_SUBTYPE_REGISTER_743 (BOOST_VMD_TYPE_NUMBER,743)
#define BOOST_VMD_SUBTYPE_REGISTER_744 (BOOST_VMD_TYPE_NUMBER,744)
#define BOOST_VMD_SUBTYPE_REGISTER_745 (BOOST_VMD_TYPE_NUMBER,745)
#define BOOST_VMD_SUBTYPE_REGISTER_746 (BOOST_VMD_TYPE_NUMBER,746)
#define BOOST_VMD_SUBTYPE_REGISTER_747 (BOOST_VMD_TYPE_NUMBER,747)
#define BOOST_VMD_SUBTYPE_REGISTER_748 (BOOST_VMD_TYPE_NUMBER,748)
#define BOOST_VMD_SUBTYPE_REGISTER_749 (BOOST_VMD_TYPE_NUMBER,749)
#define BOOST_VMD_SUBTYPE_REGISTER_750 (BOOST_VMD_TYPE_NUMBER,750)
#define BOOST_VMD_SUBTYPE_REGISTER_751 (BOOST_VMD_TYPE_NUMBER,751)
#define BOOST_VMD_SUBTYPE_REGISTER_752 (BOOST_VMD_TYPE_NUMBER,752)
#define BOOST_VMD_SUBTYPE_REGISTER_753 (BOOST_VMD_TYPE_NUMBER,753)
#define BOOST_VMD_SUBTYPE_REGISTER_754 (BOOST_VMD_TYPE_NUMBER,754)
#define BOOST_VMD_SUBTYPE_REGISTER_755 (BOOST_VMD_TYPE_NUMBER,755)
#define BOOST_VMD_SUBTYPE_REGISTER_756 (BOOST_VMD_TYPE_NUMBER,756)
#define BOOST_VMD_SUBTYPE_REGISTER_757 (BOOST_VMD_TYPE_NUMBER,757)
#define BOOST_VMD_SUBTYPE_REGISTER_758 (BOOST_VMD_TYPE_NUMBER,758)
#define BOOST_VMD_SUBTYPE_REGISTER_759 (BOOST_VMD_TYPE_NUMBER,759)
#define BOOST_VMD_SUBTYPE_REGISTER_760 (BOOST_VMD_TYPE_NUMBER,760)
#define BOOST_VMD_SUBTYPE_REGISTER_761 (BOOST_VMD_TYPE_NUMBER,761)
#define BOOST_VMD_SUBTYPE_REGISTER_762 (BOOST_VMD_TYPE_NUMBER,762)
#define BOOST_VMD_SUBTYPE_REGISTER_763 (BOOST_VMD_TYPE_NUMBER,763)
#define BOOST_VMD_SUBTYPE_REGISTER_764 (BOOST_VMD_TYPE_NUMBER,764)
#define BOOST_VMD_SUBTYPE_REGISTER_765 (BOOST_VMD_TYPE_NUMBER,765)
#define BOOST_VMD_SUBTYPE_REGISTER_766 (BOOST_VMD_TYPE_NUMBER,766)
#define BOOST_VMD_SUBTYPE_REGISTER_767 (BOOST_VMD_TYPE_NUMBER,767)
#define BOOST_VMD_SUBTYPE_REGISTER_768 (BOOST_VMD_TYPE_NUMBER,768)
#define BOOST_VMD_SUBTYPE_REGISTER_769 (BOOST_VMD_TYPE_NUMBER,769)
#define BOOST_VMD_SUBTYPE_REGISTER_770 (BOOST_VMD_TYPE_NUMBER,770)
#define BOOST_VMD_SUBTYPE_REGISTER_771 (BOOST_VMD_TYPE_NUMBER,771)
#define BOOST_VMD_SUBTYPE_REGISTER_772 (BOOST_VMD_TYPE_NUMBER,772)
#define BOOST_VMD_SUBTYPE_REGISTER_773 (BOOST_VMD_TYPE_NUMBER,773)
#define BOOST_VMD_SUBTYPE_REGISTER_774 (BOOST_VMD_TYPE_NUMBER,774)
#define BOOST_VMD_SUBTYPE_REGISTER_775 (BOOST_VMD_TYPE_NUMBER,775)
#define BOOST_VMD_SUBTYPE_REGISTER_776 (BOOST_VMD_TYPE_NUMBER,776)
#define BOOST_VMD_SUBTYPE_REGISTER_777 (BOOST_VMD_TYPE_NUMBER,777)
#define BOOST_VMD_SUBTYPE_REGISTER_778 (BOOST_VMD_TYPE_NUMBER,778)
#define BOOST_VMD_SUBTYPE_REGISTER_779 (BOOST_VMD_TYPE_NUMBER,779)
#define BOOST_VMD_SUBTYPE_REGISTER_780 (BOOST_VMD_TYPE_NUMBER,780)
#define BOOST_VMD_SUBTYPE_REGISTER_781 (BOOST_VMD_TYPE_NUMBER,781)
#define BOOST_VMD_SUBTYPE_REGISTER_782 (BOOST_VMD_TYPE_NUMBER,782)
#define BOOST_VMD_SUBTYPE_REGISTER_783 (BOOST_VMD_TYPE_NUMBER,783)
#define BOOST_VMD_SUBTYPE_REGISTER_784 (BOOST_VMD_TYPE_NUMBER,784)
#define BOOST_VMD_SUBTYPE_REGISTER_785 (BOOST_VMD_TYPE_NUMBER,785)
#define BOOST_VMD_SUBTYPE_REGISTER_786 (BOOST_VMD_TYPE_NUMBER,786)
#define BOOST_VMD_SUBTYPE_REGISTER_787 (BOOST_VMD_TYPE_NUMBER,787)
#define BOOST_VMD_SUBTYPE_REGISTER_788 (BOOST_VMD_TYPE_NUMBER,788)
#define BOOST_VMD_SUBTYPE_REGISTER_789 (BOOST_VMD_TYPE_NUMBER,789)
#define BOOST_VMD_SUBTYPE_REGISTER_790 (BOOST_VMD_TYPE_NUMBER,790)
#define BOOST_VMD_SUBTYPE_REGISTER_791 (BOOST_VMD_TYPE_NUMBER,791)
#define BOOST_VMD_SUBTYPE_REGISTER_792 (BOOST_VMD_TYPE_NUMBER,792)
#define BOOST_VMD_SUBTYPE_REGISTER_793 (BOOST_VMD_TYPE_NUMBER,793)
#define BOOST_VMD_SUBTYPE_REGISTER_794 (BOOST_VMD_TYPE_NUMBER,794)
#define BOOST_VMD_SUBTYPE_REGISTER_795 (BOOST_VMD_TYPE_NUMBER,795)
#define BOOST_VMD_SUBTYPE_REGISTER_796 (BOOST_VMD_TYPE_NUMBER,796)
#define BOOST_VMD_SUBTYPE_REGISTER_797 (BOOST_VMD_TYPE_NUMBER,797)
#define BOOST_VMD_SUBTYPE_REGISTER_798 (BOOST_VMD_TYPE_NUMBER,798)
#define BOOST_VMD_SUBTYPE_REGISTER_799 (BOOST_VMD_TYPE_NUMBER,799)
#define BOOST_VMD_SUBTYPE_REGISTER_800 (BOOST_VMD_TYPE_NUMBER,800)
#define BOOST_VMD_SUBTYPE_REGISTER_801 (BOOST_VMD_TYPE_NUMBER,801)
#define BOOST_VMD_SUBTYPE_REGISTER_802 (BOOST_VMD_TYPE_NUMBER,802)
#define BOOST_VMD_SUBTYPE_REGISTER_803 (BOOST_VMD_TYPE_NUMBER,803)
#define BOOST_VMD_SUBTYPE_REGISTER_804 (BOOST_VMD_TYPE_NUMBER,804)
#define BOOST_VMD_SUBTYPE_REGISTER_805 (BOOST_VMD_TYPE_NUMBER,805)
#define BOOST_VMD_SUBTYPE_REGISTER_806 (BOOST_VMD_TYPE_NUMBER,806)
#define BOOST_VMD_SUBTYPE_REGISTER_807 (BOOST_VMD_TYPE_NUMBER,807)
#define BOOST_VMD_SUBTYPE_REGISTER_808 (BOOST_VMD_TYPE_NUMBER,808)
#define BOOST_VMD_SUBTYPE_REGISTER_809 (BOOST_VMD_TYPE_NUMBER,809)
#define BOOST_VMD_SUBTYPE_REGISTER_810 (BOOST_VMD_TYPE_NUMBER,810)
#define BOOST_VMD_SUBTYPE_REGISTER_811 (BOOST_VMD_TYPE_NUMBER,811)
#define BOOST_VMD_SUBTYPE_REGISTER_812 (BOOST_VMD_TYPE_NUMBER,812)
#define BOOST_VMD_SUBTYPE_REGISTER_813 (BOOST_VMD_TYPE_NUMBER,813)
#define BOOST_VMD_SUBTYPE_REGISTER_814 (BOOST_VMD_TYPE_NUMBER,814)
#define BOOST_VMD_SUBTYPE_REGISTER_815 (BOOST_VMD_TYPE_NUMBER,815)
#define BOOST_VMD_SUBTYPE_REGISTER_816 (BOOST_VMD_TYPE_NUMBER,816)
#define BOOST_VMD_SUBTYPE_REGISTER_817 (BOOST_VMD_TYPE_NUMBER,817)
#define BOOST_VMD_SUBTYPE_REGISTER_818 (BOOST_VMD_TYPE_NUMBER,818)
#define BOOST_VMD_SUBTYPE_REGISTER_819 (BOOST_VMD_TYPE_NUMBER,819)
#define BOOST_VMD_SUBTYPE_REGISTER_820 (BOOST_VMD_TYPE_NUMBER,820)
#define BOOST_VMD_SUBTYPE_REGISTER_821 (BOOST_VMD_TYPE_NUMBER,821)
#define BOOST_VMD_SUBTYPE_REGISTER_822 (BOOST_VMD_TYPE_NUMBER,822)
#define BOOST_VMD_SUBTYPE_REGISTER_823 (BOOST_VMD_TYPE_NUMBER,823)
#define BOOST_VMD_SUBTYPE_REGISTER_824 (BOOST_VMD_TYPE_NUMBER,824)
#define BOOST_VMD_SUBTYPE_REGISTER_825 (BOOST_VMD_TYPE_NUMBER,825)
#define BOOST_VMD_SUBTYPE_REGISTER_826 (BOOST_VMD_TYPE_NUMBER,826)
#define BOOST_VMD_SUBTYPE_REGISTER_827 (BOOST_VMD_TYPE_NUMBER,827)
#define BOOST_VMD_SUBTYPE_REGISTER_828 (BOOST_VMD_TYPE_NUMBER,828)
#define BOOST_VMD_SUBTYPE_REGISTER_829 (BOOST_VMD_TYPE_NUMBER,829)
#define BOOST_VMD_SUBTYPE_REGISTER_830 (BOOST_VMD_TYPE_NUMBER,830)
#define BOOST_VMD_SUBTYPE_REGISTER_831 (BOOST_VMD_TYPE_NUMBER,831)
#define BOOST_VMD_SUBTYPE_REGISTER_832 (BOOST_VMD_TYPE_NUMBER,832)
#define BOOST_VMD_SUBTYPE_REGISTER_833 (BOOST_VMD_TYPE_NUMBER,833)
#define BOOST_VMD_SUBTYPE_REGISTER_834 (BOOST_VMD_TYPE_NUMBER,834)
#define BOOST_VMD_SUBTYPE_REGISTER_835 (BOOST_VMD_TYPE_NUMBER,835)
#define BOOST_VMD_SUBTYPE_REGISTER_836 (BOOST_VMD_TYPE_NUMBER,836)
#define BOOST_VMD_SUBTYPE_REGISTER_837 (BOOST_VMD_TYPE_NUMBER,837)
#define BOOST_VMD_SUBTYPE_REGISTER_838 (BOOST_VMD_TYPE_NUMBER,838)
#define BOOST_VMD_SUBTYPE_REGISTER_839 (BOOST_VMD_TYPE_NUMBER,839)
#define BOOST_VMD_SUBTYPE_REGISTER_840 (BOOST_VMD_TYPE_NUMBER,840)
#define BOOST_VMD_SUBTYPE_REGISTER_841 (BOOST_VMD_TYPE_NUMBER,841)
#define BOOST_VMD_SUBTYPE_REGISTER_842 (BOOST_VMD_TYPE_NUMBER,842)
#define BOOST_VMD_SUBTYPE_REGISTER_843 (BOOST_VMD_TYPE_NUMBER,843)
#define BOOST_VMD_SUBTYPE_REGISTER_844 (BOOST_VMD_TYPE_NUMBER,844)
#define BOOST_VMD_SUBTYPE_REGISTER_845 (BOOST_VMD_TYPE_NUMBER,845)
#define BOOST_VMD_SUBTYPE_REGISTER_846 (BOOST_VMD_TYPE_NUMBER,846)
#define BOOST_VMD_SUBTYPE_REGISTER_847 (BOOST_VMD_TYPE_NUMBER,847)
#define BOOST_VMD_SUBTYPE_REGISTER_848 (BOOST_VMD_TYPE_NUMBER,848)
#define BOOST_VMD_SUBTYPE_REGISTER_849 (BOOST_VMD_TYPE_NUMBER,849)
#define BOOST_VMD_SUBTYPE_REGISTER_850 (BOOST_VMD_TYPE_NUMBER,850)
#define BOOST_VMD_SUBTYPE_REGISTER_851 (BOOST_VMD_TYPE_NUMBER,851)
#define BOOST_VMD_SUBTYPE_REGISTER_852 (BOOST_VMD_TYPE_NUMBER,852)
#define BOOST_VMD_SUBTYPE_REGISTER_853 (BOOST_VMD_TYPE_NUMBER,853)
#define BOOST_VMD_SUBTYPE_REGISTER_854 (BOOST_VMD_TYPE_NUMBER,854)
#define BOOST_VMD_SUBTYPE_REGISTER_855 (BOOST_VMD_TYPE_NUMBER,855)
#define BOOST_VMD_SUBTYPE_REGISTER_856 (BOOST_VMD_TYPE_NUMBER,856)
#define BOOST_VMD_SUBTYPE_REGISTER_857 (BOOST_VMD_TYPE_NUMBER,857)
#define BOOST_VMD_SUBTYPE_REGISTER_858 (BOOST_VMD_TYPE_NUMBER,858)
#define BOOST_VMD_SUBTYPE_REGISTER_859 (BOOST_VMD_TYPE_NUMBER,859)
#define BOOST_VMD_SUBTYPE_REGISTER_860 (BOOST_VMD_TYPE_NUMBER,860)
#define BOOST_VMD_SUBTYPE_REGISTER_861 (BOOST_VMD_TYPE_NUMBER,861)
#define BOOST_VMD_SUBTYPE_REGISTER_862 (BOOST_VMD_TYPE_NUMBER,862)
#define BOOST_VMD_SUBTYPE_REGISTER_863 (BOOST_VMD_TYPE_NUMBER,863)
#define BOOST_VMD_SUBTYPE_REGISTER_864 (BOOST_VMD_TYPE_NUMBER,864)
#define BOOST_VMD_SUBTYPE_REGISTER_865 (BOOST_VMD_TYPE_NUMBER,865)
#define BOOST_VMD_SUBTYPE_REGISTER_866 (BOOST_VMD_TYPE_NUMBER,866)
#define BOOST_VMD_SUBTYPE_REGISTER_867 (BOOST_VMD_TYPE_NUMBER,867)
#define BOOST_VMD_SUBTYPE_REGISTER_868 (BOOST_VMD_TYPE_NUMBER,868)
#define BOOST_VMD_SUBTYPE_REGISTER_869 (BOOST_VMD_TYPE_NUMBER,869)
#define BOOST_VMD_SUBTYPE_REGISTER_870 (BOOST_VMD_TYPE_NUMBER,870)
#define BOOST_VMD_SUBTYPE_REGISTER_871 (BOOST_VMD_TYPE_NUMBER,871)
#define BOOST_VMD_SUBTYPE_REGISTER_872 (BOOST_VMD_TYPE_NUMBER,872)
#define BOOST_VMD_SUBTYPE_REGISTER_873 (BOOST_VMD_TYPE_NUMBER,873)
#define BOOST_VMD_SUBTYPE_REGISTER_874 (BOOST_VMD_TYPE_NUMBER,874)
#define BOOST_VMD_SUBTYPE_REGISTER_875 (BOOST_VMD_TYPE_NUMBER,875)
#define BOOST_VMD_SUBTYPE_REGISTER_876 (BOOST_VMD_TYPE_NUMBER,876)
#define BOOST_VMD_SUBTYPE_REGISTER_877 (BOOST_VMD_TYPE_NUMBER,877)
#define BOOST_VMD_SUBTYPE_REGISTER_878 (BOOST_VMD_TYPE_NUMBER,878)
#define BOOST_VMD_SUBTYPE_REGISTER_879 (BOOST_VMD_TYPE_NUMBER,879)
#define BOOST_VMD_SUBTYPE_REGISTER_880 (BOOST_VMD_TYPE_NUMBER,880)
#define BOOST_VMD_SUBTYPE_REGISTER_881 (BOOST_VMD_TYPE_NUMBER,881)
#define BOOST_VMD_SUBTYPE_REGISTER_882 (BOOST_VMD_TYPE_NUMBER,882)
#define BOOST_VMD_SUBTYPE_REGISTER_883 (BOOST_VMD_TYPE_NUMBER,883)
#define BOOST_VMD_SUBTYPE_REGISTER_884 (BOOST_VMD_TYPE_NUMBER,884)
#define BOOST_VMD_SUBTYPE_REGISTER_885 (BOOST_VMD_TYPE_NUMBER,885)
#define BOOST_VMD_SUBTYPE_REGISTER_886 (BOOST_VMD_TYPE_NUMBER,886)
#define BOOST_VMD_SUBTYPE_REGISTER_887 (BOOST_VMD_TYPE_NUMBER,887)
#define BOOST_VMD_SUBTYPE_REGISTER_888 (BOOST_VMD_TYPE_NUMBER,888)
#define BOOST_VMD_SUBTYPE_REGISTER_889 (BOOST_VMD_TYPE_NUMBER,889)
#define BOOST_VMD_SUBTYPE_REGISTER_890 (BOOST_VMD_TYPE_NUMBER,890)
#define BOOST_VMD_SUBTYPE_REGISTER_891 (BOOST_VMD_TYPE_NUMBER,891)
#define BOOST_VMD_SUBTYPE_REGISTER_892 (BOOST_VMD_TYPE_NUMBER,892)
#define BOOST_VMD_SUBTYPE_REGISTER_893 (BOOST_VMD_TYPE_NUMBER,893)
#define BOOST_VMD_SUBTYPE_REGISTER_894 (BOOST_VMD_TYPE_NUMBER,894)
#define BOOST_VMD_SUBTYPE_REGISTER_895 (BOOST_VMD_TYPE_NUMBER,895)
#define BOOST_VMD_SUBTYPE_REGISTER_896 (BOOST_VMD_TYPE_NUMBER,896)
#define BOOST_VMD_SUBTYPE_REGISTER_897 (BOOST_VMD_TYPE_NUMBER,897)
#define BOOST_VMD_SUBTYPE_REGISTER_898 (BOOST_VMD_TYPE_NUMBER,898)
#define BOOST_VMD_SUBTYPE_REGISTER_899 (BOOST_VMD_TYPE_NUMBER,899)
#define BOOST_VMD_SUBTYPE_REGISTER_900 (BOOST_VMD_TYPE_NUMBER,900)
#define BOOST_VMD_SUBTYPE_REGISTER_901 (BOOST_VMD_TYPE_NUMBER,901)
#define BOOST_VMD_SUBTYPE_REGISTER_902 (BOOST_VMD_TYPE_NUMBER,902)
#define BOOST_VMD_SUBTYPE_REGISTER_903 (BOOST_VMD_TYPE_NUMBER,903)
#define BOOST_VMD_SUBTYPE_REGISTER_904 (BOOST_VMD_TYPE_NUMBER,904)
#define BOOST_VMD_SUBTYPE_REGISTER_905 (BOOST_VMD_TYPE_NUMBER,905)
#define BOOST_VMD_SUBTYPE_REGISTER_906 (BOOST_VMD_TYPE_NUMBER,906)
#define BOOST_VMD_SUBTYPE_REGISTER_907 (BOOST_VMD_TYPE_NUMBER,907)
#define BOOST_VMD_SUBTYPE_REGISTER_908 (BOOST_VMD_TYPE_NUMBER,908)
#define BOOST_VMD_SUBTYPE_REGISTER_909 (BOOST_VMD_TYPE_NUMBER,909)
#define BOOST_VMD_SUBTYPE_REGISTER_910 (BOOST_VMD_TYPE_NUMBER,910)
#define BOOST_VMD_SUBTYPE_REGISTER_911 (BOOST_VMD_TYPE_NUMBER,911)
#define BOOST_VMD_SUBTYPE_REGISTER_912 (BOOST_VMD_TYPE_NUMBER,912)
#define BOOST_VMD_SUBTYPE_REGISTER_913 (BOOST_VMD_TYPE_NUMBER,913)
#define BOOST_VMD_SUBTYPE_REGISTER_914 (BOOST_VMD_TYPE_NUMBER,914)
#define BOOST_VMD_SUBTYPE_REGISTER_915 (BOOST_VMD_TYPE_NUMBER,915)
#define BOOST_VMD_SUBTYPE_REGISTER_916 (BOOST_VMD_TYPE_NUMBER,916)
#define BOOST_VMD_SUBTYPE_REGISTER_917 (BOOST_VMD_TYPE_NUMBER,917)
#define BOOST_VMD_SUBTYPE_REGISTER_918 (BOOST_VMD_TYPE_NUMBER,918)
#define BOOST_VMD_SUBTYPE_REGISTER_919 (BOOST_VMD_TYPE_NUMBER,919)
#define BOOST_VMD_SUBTYPE_REGISTER_920 (BOOST_VMD_TYPE_NUMBER,920)
#define BOOST_VMD_SUBTYPE_REGISTER_921 (BOOST_VMD_TYPE_NUMBER,921)
#define BOOST_VMD_SUBTYPE_REGISTER_922 (BOOST_VMD_TYPE_NUMBER,922)
#define BOOST_VMD_SUBTYPE_REGISTER_923 (BOOST_VMD_TYPE_NUMBER,923)
#define BOOST_VMD_SUBTYPE_REGISTER_924 (BOOST_VMD_TYPE_NUMBER,924)
#define BOOST_VMD_SUBTYPE_REGISTER_925 (BOOST_VMD_TYPE_NUMBER,925)
#define BOOST_VMD_SUBTYPE_REGISTER_926 (BOOST_VMD_TYPE_NUMBER,926)
#define BOOST_VMD_SUBTYPE_REGISTER_927 (BOOST_VMD_TYPE_NUMBER,927)
#define BOOST_VMD_SUBTYPE_REGISTER_928 (BOOST_VMD_TYPE_NUMBER,928)
#define BOOST_VMD_SUBTYPE_REGISTER_929 (BOOST_VMD_TYPE_NUMBER,929)
#define BOOST_VMD_SUBTYPE_REGISTER_930 (BOOST_VMD_TYPE_NUMBER,930)
#define BOOST_VMD_SUBTYPE_REGISTER_931 (BOOST_VMD_TYPE_NUMBER,931)
#define BOOST_VMD_SUBTYPE_REGISTER_932 (BOOST_VMD_TYPE_NUMBER,932)
#define BOOST_VMD_SUBTYPE_REGISTER_933 (BOOST_VMD_TYPE_NUMBER,933)
#define BOOST_VMD_SUBTYPE_REGISTER_934 (BOOST_VMD_TYPE_NUMBER,934)
#define BOOST_VMD_SUBTYPE_REGISTER_935 (BOOST_VMD_TYPE_NUMBER,935)
#define BOOST_VMD_SUBTYPE_REGISTER_936 (BOOST_VMD_TYPE_NUMBER,936)
#define BOOST_VMD_SUBTYPE_REGISTER_937 (BOOST_VMD_TYPE_NUMBER,937)
#define BOOST_VMD_SUBTYPE_REGISTER_938 (BOOST_VMD_TYPE_NUMBER,938)
#define BOOST_VMD_SUBTYPE_REGISTER_939 (BOOST_VMD_TYPE_NUMBER,939)
#define BOOST_VMD_SUBTYPE_REGISTER_940 (BOOST_VMD_TYPE_NUMBER,940)
#define BOOST_VMD_SUBTYPE_REGISTER_941 (BOOST_VMD_TYPE_NUMBER,941)
#define BOOST_VMD_SUBTYPE_REGISTER_942 (BOOST_VMD_TYPE_NUMBER,942)
#define BOOST_VMD_SUBTYPE_REGISTER_943 (BOOST_VMD_TYPE_NUMBER,943)
#define BOOST_VMD_SUBTYPE_REGISTER_944 (BOOST_VMD_TYPE_NUMBER,944)
#define BOOST_VMD_SUBTYPE_REGISTER_945 (BOOST_VMD_TYPE_NUMBER,945)
#define BOOST_VMD_SUBTYPE_REGISTER_946 (BOOST_VMD_TYPE_NUMBER,946)
#define BOOST_VMD_SUBTYPE_REGISTER_947 (BOOST_VMD_TYPE_NUMBER,947)
#define BOOST_VMD_SUBTYPE_REGISTER_948 (BOOST_VMD_TYPE_NUMBER,948)
#define BOOST_VMD_SUBTYPE_REGISTER_949 (BOOST_VMD_TYPE_NUMBER,949)
#define BOOST_VMD_SUBTYPE_REGISTER_950 (BOOST_VMD_TYPE_NUMBER,950)
#define BOOST_VMD_SUBTYPE_REGISTER_951 (BOOST_VMD_TYPE_NUMBER,951)
#define BOOST_VMD_SUBTYPE_REGISTER_952 (BOOST_VMD_TYPE_NUMBER,952)
#define BOOST_VMD_SUBTYPE_REGISTER_953 (BOOST_VMD_TYPE_NUMBER,953)
#define BOOST_VMD_SUBTYPE_REGISTER_954 (BOOST_VMD_TYPE_NUMBER,954)
#define BOOST_VMD_SUBTYPE_REGISTER_955 (BOOST_VMD_TYPE_NUMBER,955)
#define BOOST_VMD_SUBTYPE_REGISTER_956 (BOOST_VMD_TYPE_NUMBER,956)
#define BOOST_VMD_SUBTYPE_REGISTER_957 (BOOST_VMD_TYPE_NUMBER,957)
#define BOOST_VMD_SUBTYPE_REGISTER_958 (BOOST_VMD_TYPE_NUMBER,958)
#define BOOST_VMD_SUBTYPE_REGISTER_959 (BOOST_VMD_TYPE_NUMBER,959)
#define BOOST_VMD_SUBTYPE_REGISTER_960 (BOOST_VMD_TYPE_NUMBER,960)
#define BOOST_VMD_SUBTYPE_REGISTER_961 (BOOST_VMD_TYPE_NUMBER,961)
#define BOOST_VMD_SUBTYPE_REGISTER_962 (BOOST_VMD_TYPE_NUMBER,962)
#define BOOST_VMD_SUBTYPE_REGISTER_963 (BOOST_VMD_TYPE_NUMBER,963)
#define BOOST_VMD_SUBTYPE_REGISTER_964 (BOOST_VMD_TYPE_NUMBER,964)
#define BOOST_VMD_SUBTYPE_REGISTER_965 (BOOST_VMD_TYPE_NUMBER,965)
#define BOOST_VMD_SUBTYPE_REGISTER_966 (BOOST_VMD_TYPE_NUMBER,966)
#define BOOST_VMD_SUBTYPE_REGISTER_967 (BOOST_VMD_TYPE_NUMBER,967)
#define BOOST_VMD_SUBTYPE_REGISTER_968 (BOOST_VMD_TYPE_NUMBER,968)
#define BOOST_VMD_SUBTYPE_REGISTER_969 (BOOST_VMD_TYPE_NUMBER,969)
#define BOOST_VMD_SUBTYPE_REGISTER_970 (BOOST_VMD_TYPE_NUMBER,970)
#define BOOST_VMD_SUBTYPE_REGISTER_971 (BOOST_VMD_TYPE_NUMBER,971)
#define BOOST_VMD_SUBTYPE_REGISTER_972 (BOOST_VMD_TYPE_NUMBER,972)
#define BOOST_VMD_SUBTYPE_REGISTER_973 (BOOST_VMD_TYPE_NUMBER,973)
#define BOOST_VMD_SUBTYPE_REGISTER_974 (BOOST_VMD_TYPE_NUMBER,974)
#define BOOST_VMD_SUBTYPE_REGISTER_975 (BOOST_VMD_TYPE_NUMBER,975)
#define BOOST_VMD_SUBTYPE_REGISTER_976 (BOOST_VMD_TYPE_NUMBER,976)
#define BOOST_VMD_SUBTYPE_REGISTER_977 (BOOST_VMD_TYPE_NUMBER,977)
#define BOOST_VMD_SUBTYPE_REGISTER_978 (BOOST_VMD_TYPE_NUMBER,978)
#define BOOST_VMD_SUBTYPE_REGISTER_979 (BOOST_VMD_TYPE_NUMBER,979)
#define BOOST_VMD_SUBTYPE_REGISTER_980 (BOOST_VMD_TYPE_NUMBER,980)
#define BOOST_VMD_SUBTYPE_REGISTER_981 (BOOST_VMD_TYPE_NUMBER,981)
#define BOOST_VMD_SUBTYPE_REGISTER_982 (BOOST_VMD_TYPE_NUMBER,982)
#define BOOST_VMD_SUBTYPE_REGISTER_983 (BOOST_VMD_TYPE_NUMBER,983)
#define BOOST_VMD_SUBTYPE_REGISTER_984 (BOOST_VMD_TYPE_NUMBER,984)
#define BOOST_VMD_SUBTYPE_REGISTER_985 (BOOST_VMD_TYPE_NUMBER,985)
#define BOOST_VMD_SUBTYPE_REGISTER_986 (BOOST_VMD_TYPE_NUMBER,986)
#define BOOST_VMD_SUBTYPE_REGISTER_987 (BOOST_VMD_TYPE_NUMBER,987)
#define BOOST_VMD_SUBTYPE_REGISTER_988 (BOOST_VMD_TYPE_NUMBER,988)
#define BOOST_VMD_SUBTYPE_REGISTER_989 (BOOST_VMD_TYPE_NUMBER,989)
#define BOOST_VMD_SUBTYPE_REGISTER_990 (BOOST_VMD_TYPE_NUMBER,990)
#define BOOST_VMD_SUBTYPE_REGISTER_991 (BOOST_VMD_TYPE_NUMBER,991)
#define BOOST_VMD_SUBTYPE_REGISTER_992 (BOOST_VMD_TYPE_NUMBER,992)
#define BOOST_VMD_SUBTYPE_REGISTER_993 (BOOST_VMD_TYPE_NUMBER,993)
#define BOOST_VMD_SUBTYPE_REGISTER_994 (BOOST_VMD_TYPE_NUMBER,994)
#define BOOST_VMD_SUBTYPE_REGISTER_995 (BOOST_VMD_TYPE_NUMBER,995)
#define BOOST_VMD_SUBTYPE_REGISTER_996 (BOOST_VMD_TYPE_NUMBER,996)
#define BOOST_VMD_SUBTYPE_REGISTER_997 (BOOST_VMD_TYPE_NUMBER,997)
#define BOOST_VMD_SUBTYPE_REGISTER_998 (BOOST_VMD_TYPE_NUMBER,998)
#define BOOST_VMD_SUBTYPE_REGISTER_999 (BOOST_VMD_TYPE_NUMBER,999)
#define BOOST_VMD_SUBTYPE_REGISTER_1000 (BOOST_VMD_TYPE_NUMBER,1000)
#define BOOST_VMD_SUBTYPE_REGISTER_1001 (BOOST_VMD_TYPE_NUMBER,1001)
#define BOOST_VMD_SUBTYPE_REGISTER_1002 (BOOST_VMD_TYPE_NUMBER,1002)
#define BOOST_VMD_SUBTYPE_REGISTER_1003 (BOOST_VMD_TYPE_NUMBER,1003)
#define BOOST_VMD_SUBTYPE_REGISTER_1004 (BOOST_VMD_TYPE_NUMBER,1004)
#define BOOST_VMD_SUBTYPE_REGISTER_1005 (BOOST_VMD_TYPE_NUMBER,1005)
#define BOOST_VMD_SUBTYPE_REGISTER_1006 (BOOST_VMD_TYPE_NUMBER,1006)
#define BOOST_VMD_SUBTYPE_REGISTER_1007 (BOOST_VMD_TYPE_NUMBER,1007)
#define BOOST_VMD_SUBTYPE_REGISTER_1008 (BOOST_VMD_TYPE_NUMBER,1008)
#define BOOST_VMD_SUBTYPE_REGISTER_1009 (BOOST_VMD_TYPE_NUMBER,1009)
#define BOOST_VMD_SUBTYPE_REGISTER_1010 (BOOST_VMD_TYPE_NUMBER,1010)
#define BOOST_VMD_SUBTYPE_REGISTER_1011 (BOOST_VMD_TYPE_NUMBER,1011)
#define BOOST_VMD_SUBTYPE_REGISTER_1012 (BOOST_VMD_TYPE_NUMBER,1012)
#define BOOST_VMD_SUBTYPE_REGISTER_1013 (BOOST_VMD_TYPE_NUMBER,1013)
#define BOOST_VMD_SUBTYPE_REGISTER_1014 (BOOST_VMD_TYPE_NUMBER,1014)
#define BOOST_VMD_SUBTYPE_REGISTER_1015 (BOOST_VMD_TYPE_NUMBER,1015)
#define BOOST_VMD_SUBTYPE_REGISTER_1016 (BOOST_VMD_TYPE_NUMBER,1016)
#define BOOST_VMD_SUBTYPE_REGISTER_1017 (BOOST_VMD_TYPE_NUMBER,1017)
#define BOOST_VMD_SUBTYPE_REGISTER_1018 (BOOST_VMD_TYPE_NUMBER,1018)
#define BOOST_VMD_SUBTYPE_REGISTER_1019 (BOOST_VMD_TYPE_NUMBER,1019)
#define BOOST_VMD_SUBTYPE_REGISTER_1020 (BOOST_VMD_TYPE_NUMBER,1020)
#define BOOST_VMD_SUBTYPE_REGISTER_1021 (BOOST_VMD_TYPE_NUMBER,1021)
#define BOOST_VMD_SUBTYPE_REGISTER_1022 (BOOST_VMD_TYPE_NUMBER,1022)
#define BOOST_VMD_SUBTYPE_REGISTER_1023 (BOOST_VMD_TYPE_NUMBER,1023)
#define BOOST_VMD_SUBTYPE_REGISTER_1024 (BOOST_VMD_TYPE_NUMBER,1024)

#endif

#endif /* BOOST_VMD_DETAIL_IS_NUMBER_REGISTRATION_HPP */
